/* valaccodememberaccessmodule.c generated by valac, the Vala compiler
 * generated from valaccodememberaccessmodule.vala, do not modify */

/* valaccodememberaccessmodule.vala
 *
 * Copyright (C) 2006-2010  Jürg Billeter
 * Copyright (C) 2006-2008  Raffaele Sandrini
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 *	Raffaele Sandrini <raffaele@sandrini.ch>
 */

#include "valacodegen.h"
#include <vala.h>
#include <glib.h>
#include <valaccode.h>
#include <stdlib.h>
#include <string.h>
#include <valagee.h>
#include <glib-object.h>

#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
#define _vala_target_value_unref0(var) ((var == NULL) ? NULL : (var = (vala_target_value_unref (var), NULL)))
#define _vala_iterable_unref0(var) ((var == NULL) ? NULL : (var = (vala_iterable_unref (var), NULL)))

static gpointer vala_ccode_member_access_module_parent_class = NULL;

static void vala_ccode_member_access_module_real_visit_member_access (ValaCodeVisitor* base,
                                                               ValaMemberAccess* expr);
static ValaTargetValue* vala_ccode_member_access_module_real_get_local_cvalue (ValaCCodeBaseModule* base,
                                                                        ValaLocalVariable* local);
static ValaTargetValue* vala_ccode_member_access_module_real_get_parameter_cvalue (ValaCCodeBaseModule* base,
                                                                            ValaParameter* param);
static ValaTargetValue* vala_ccode_member_access_module_real_get_field_cvalue (ValaCCodeBaseModule* base,
                                                                        ValaField* field,
                                                                        ValaTargetValue* instance);
static ValaTargetValue* vala_ccode_member_access_module_real_load_variable (ValaCCodeBaseModule* base,
                                                                     ValaVariable* variable,
                                                                     ValaTargetValue* value,
                                                                     ValaExpression* expr);
static ValaTargetValue* vala_ccode_member_access_module_real_load_local (ValaCodeGenerator* base,
                                                                  ValaLocalVariable* local,
                                                                  ValaExpression* expr);
static ValaTargetValue* vala_ccode_member_access_module_real_load_parameter (ValaCodeGenerator* base,
                                                                      ValaParameter* param,
                                                                      ValaExpression* expr);
static ValaTargetValue* vala_ccode_member_access_module_real_load_this_parameter (ValaCCodeBaseModule* base,
                                                                           ValaTypeSymbol* sym);
static ValaTargetValue* vala_ccode_member_access_module_real_load_field (ValaCodeGenerator* base,
                                                                  ValaField* field,
                                                                  ValaTargetValue* instance,
                                                                  ValaExpression* expr);
static GType vala_ccode_member_access_module_get_type_once (void);

static gpointer
_vala_ccode_node_ref0 (gpointer self)
{
	return self ? vala_ccode_node_ref (self) : NULL;
}

static gpointer
_vala_code_node_ref0 (gpointer self)
{
	return self ? vala_code_node_ref (self) : NULL;
}

static gpointer
_vala_target_value_ref0 (gpointer self)
{
	return self ? vala_target_value_ref (self) : NULL;
}

static void
vala_ccode_member_access_module_real_visit_member_access (ValaCodeVisitor* base,
                                                          ValaMemberAccess* expr)
{
	ValaCCodeMemberAccessModule * self;
	ValaCCodeExpression* pub_inst = NULL;
	ValaExpression* _tmp0_;
	ValaExpression* _tmp1_;
	ValaArrayType* array_type = NULL;
	ValaDataType* _tmp6_;
	ValaDataType* _tmp7_;
	ValaArrayType* _tmp8_;
	ValaDelegateType* delegate_type = NULL;
	ValaDataType* _tmp9_;
	ValaDataType* _tmp10_;
	ValaDelegateType* _tmp11_;
	ValaSymbol* _tmp12_;
	ValaSymbol* _tmp13_;
	ValaSymbol* _tmp950_;
	ValaSymbol* _tmp951_;
	self = (ValaCCodeMemberAccessModule*) base;
	g_return_if_fail (expr != NULL);
	pub_inst = NULL;
	_tmp0_ = vala_member_access_get_inner (expr);
	_tmp1_ = _tmp0_;
	if (_tmp1_ != NULL) {
		ValaExpression* _tmp2_;
		ValaExpression* _tmp3_;
		ValaCCodeExpression* _tmp4_;
		ValaCCodeExpression* _tmp5_;
		_tmp2_ = vala_member_access_get_inner (expr);
		_tmp3_ = _tmp2_;
		_tmp4_ = vala_get_cvalue (_tmp3_);
		_tmp5_ = _vala_ccode_node_ref0 (_tmp4_);
		_vala_ccode_node_unref0 (pub_inst);
		pub_inst = _tmp5_;
	}
	_tmp6_ = vala_expression_get_value_type ((ValaExpression*) expr);
	_tmp7_ = _tmp6_;
	_tmp8_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, VALA_TYPE_ARRAY_TYPE) ? ((ValaArrayType*) _tmp7_) : NULL);
	array_type = _tmp8_;
	_tmp9_ = vala_expression_get_value_type ((ValaExpression*) expr);
	_tmp10_ = _tmp9_;
	_tmp11_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, VALA_TYPE_DELEGATE_TYPE) ? ((ValaDelegateType*) _tmp10_) : NULL);
	delegate_type = _tmp11_;
	_tmp12_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
	_tmp13_ = _tmp12_;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, VALA_TYPE_METHOD)) {
		ValaMethod* m = NULL;
		ValaSymbol* _tmp14_;
		ValaSymbol* _tmp15_;
		ValaMethod* _tmp16_;
		gboolean _tmp17_ = FALSE;
		gboolean _tmp18_ = FALSE;
		gboolean _tmp19_ = FALSE;
		ValaMethod* _tmp20_;
		ValaExpression* _tmp35_;
		ValaExpression* _tmp36_;
		ValaMethod* _tmp77_;
		ValaMethod* _tmp78_;
		ValaMethod* _tmp79_;
		ValaCCodeConstant* _tmp157_;
		ValaCCodeConstant* _tmp158_;
		ValaMethod* _tmp159_;
		ValaMemberBinding _tmp160_;
		ValaMemberBinding _tmp161_;
		_tmp14_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
		_tmp15_ = _tmp14_;
		_tmp16_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, VALA_TYPE_METHOD, ValaMethod));
		m = _tmp16_;
		_tmp20_ = m;
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, VALA_TYPE_DYNAMIC_METHOD)) {
			_tmp19_ = TRUE;
		} else {
			ValaMethod* _tmp21_;
			_tmp21_ = m;
			_tmp19_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, VALA_TYPE_ARRAY_MOVE_METHOD);
		}
		if (_tmp19_) {
			_tmp18_ = TRUE;
		} else {
			ValaMethod* _tmp22_;
			_tmp22_ = m;
			_tmp18_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, VALA_TYPE_ARRAY_RESIZE_METHOD);
		}
		if (_tmp18_) {
			_tmp17_ = TRUE;
		} else {
			ValaMethod* _tmp23_;
			_tmp23_ = m;
			_tmp17_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, VALA_TYPE_ARRAY_COPY_METHOD);
		}
		if (!_tmp17_) {
			ValaMethod* _tmp24_;
			ValaCCodeFile* _tmp25_;
			gboolean _tmp26_ = FALSE;
			ValaMethod* _tmp27_;
			gboolean _tmp28_;
			gboolean _tmp29_;
			_tmp24_ = m;
			_tmp25_ = ((ValaCCodeBaseModule*) self)->cfile;
			vala_ccode_base_module_generate_method_declaration ((ValaCCodeBaseModule*) self, _tmp24_, _tmp25_);
			_tmp27_ = m;
			_tmp28_ = vala_symbol_get_external ((ValaSymbol*) _tmp27_);
			_tmp29_ = _tmp28_;
			if (!_tmp29_) {
				ValaMethod* _tmp30_;
				gboolean _tmp31_;
				gboolean _tmp32_;
				_tmp30_ = m;
				_tmp31_ = vala_symbol_get_external_package ((ValaSymbol*) _tmp30_);
				_tmp32_ = _tmp31_;
				_tmp26_ = _tmp32_;
			} else {
				_tmp26_ = FALSE;
			}
			if (_tmp26_) {
				ValaMethod* _tmp33_;
				_tmp33_ = m;
				if (vala_ccode_base_module_add_generated_external_symbol ((ValaCCodeBaseModule*) self, (ValaSymbol*) _tmp33_)) {
					ValaMethod* _tmp34_;
					_tmp34_ = m;
					vala_code_visitor_visit_method ((ValaCodeVisitor*) self, _tmp34_);
				}
			}
		}
		_tmp35_ = vala_member_access_get_inner (expr);
		_tmp36_ = _tmp35_;
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp36_, VALA_TYPE_BASE_ACCESS)) {
			ValaCCodeExpression* vcast = NULL;
			ValaMethod* _tmp37_;
			ValaMethod* _tmp38_;
			ValaMethod* _tmp39_;
			ValaCCodeExpression* _tmp70_;
			vcast = NULL;
			_tmp37_ = m;
			_tmp38_ = vala_method_get_base_method (_tmp37_);
			_tmp39_ = _tmp38_;
			if (_tmp39_ != NULL) {
				ValaClass* base_class = NULL;
				ValaMethod* _tmp40_;
				ValaMethod* _tmp41_;
				ValaMethod* _tmp42_;
				ValaSymbol* _tmp43_;
				ValaSymbol* _tmp44_;
				ValaClass* _tmp45_;
				gchar* _tmp46_;
				gchar* _tmp47_;
				ValaCCodeIdentifier* _tmp48_;
				ValaCCodeIdentifier* _tmp49_;
				ValaCCodeFunctionCall* _tmp50_;
				ValaCCodeExpression* _tmp51_;
				ValaClass* _tmp52_;
				ValaClass* _tmp53_;
				gchar* _tmp54_;
				gchar* _tmp55_;
				gchar* _tmp56_;
				gchar* _tmp57_;
				ValaCCodeIdentifier* _tmp58_;
				ValaCCodeIdentifier* _tmp59_;
				_tmp40_ = m;
				_tmp41_ = vala_method_get_base_method (_tmp40_);
				_tmp42_ = _tmp41_;
				_tmp43_ = vala_symbol_get_parent_symbol ((ValaSymbol*) _tmp42_);
				_tmp44_ = _tmp43_;
				base_class = G_TYPE_CHECK_INSTANCE_CAST (_tmp44_, VALA_TYPE_CLASS, ValaClass);
				_tmp45_ = base_class;
				_tmp46_ = vala_get_ccode_class_type_function (_tmp45_);
				_tmp47_ = _tmp46_;
				_tmp48_ = vala_ccode_identifier_new (_tmp47_);
				_tmp49_ = _tmp48_;
				_tmp50_ = vala_ccode_function_call_new ((ValaCCodeExpression*) _tmp49_);
				_vala_ccode_node_unref0 (vcast);
				vcast = (ValaCCodeExpression*) _tmp50_;
				_vala_ccode_node_unref0 (_tmp49_);
				_g_free0 (_tmp47_);
				_tmp51_ = vcast;
				_tmp52_ = vala_ccode_base_module_get_current_class ((ValaCCodeBaseModule*) self);
				_tmp53_ = _tmp52_;
				_tmp54_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp53_, NULL);
				_tmp55_ = _tmp54_;
				_tmp56_ = g_strdup_printf ("%s_parent_class", _tmp55_);
				_tmp57_ = _tmp56_;
				_tmp58_ = vala_ccode_identifier_new (_tmp57_);
				_tmp59_ = _tmp58_;
				vala_ccode_function_call_add_argument (G_TYPE_CHECK_INSTANCE_CAST (_tmp51_, VALA_TYPE_CCODE_FUNCTION_CALL, ValaCCodeFunctionCall), (ValaCCodeExpression*) _tmp59_);
				_vala_ccode_node_unref0 (_tmp59_);
				_g_free0 (_tmp57_);
				_g_free0 (_tmp55_);
			} else {
				ValaMethod* _tmp60_;
				ValaMethod* _tmp61_;
				ValaMethod* _tmp62_;
				_tmp60_ = m;
				_tmp61_ = vala_method_get_base_interface_method (_tmp60_);
				_tmp62_ = _tmp61_;
				if (_tmp62_ != NULL) {
					ValaInterface* base_iface = NULL;
					ValaMethod* _tmp63_;
					ValaMethod* _tmp64_;
					ValaMethod* _tmp65_;
					ValaSymbol* _tmp66_;
					ValaSymbol* _tmp67_;
					ValaInterface* _tmp68_;
					ValaCCodeExpression* _tmp69_;
					_tmp63_ = m;
					_tmp64_ = vala_method_get_base_interface_method (_tmp63_);
					_tmp65_ = _tmp64_;
					_tmp66_ = vala_symbol_get_parent_symbol ((ValaSymbol*) _tmp65_);
					_tmp67_ = _tmp66_;
					base_iface = G_TYPE_CHECK_INSTANCE_CAST (_tmp67_, VALA_TYPE_INTERFACE, ValaInterface);
					_tmp68_ = base_iface;
					_tmp69_ = vala_ccode_base_module_get_this_interface_cexpression ((ValaCCodeBaseModule*) self, _tmp68_, NULL);
					_vala_ccode_node_unref0 (vcast);
					vcast = _tmp69_;
				}
			}
			_tmp70_ = vcast;
			if (_tmp70_ != NULL) {
				ValaCCodeExpression* _tmp71_;
				ValaMethod* _tmp72_;
				gchar* _tmp73_;
				gchar* _tmp74_;
				ValaCCodeMemberAccess* _tmp75_;
				ValaCCodeMemberAccess* _tmp76_;
				_tmp71_ = vcast;
				_tmp72_ = m;
				_tmp73_ = vala_get_ccode_vfunc_name (_tmp72_);
				_tmp74_ = _tmp73_;
				_tmp75_ = vala_ccode_member_access_new_pointer (_tmp71_, _tmp74_);
				_tmp76_ = _tmp75_;
				vala_set_cvalue ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp76_);
				_vala_ccode_node_unref0 (_tmp76_);
				_g_free0 (_tmp74_);
				_vala_ccode_node_unref0 (vcast);
				_vala_code_node_unref0 (m);
				_vala_code_node_unref0 (delegate_type);
				_vala_code_node_unref0 (array_type);
				_vala_ccode_node_unref0 (pub_inst);
				return;
			}
			_vala_ccode_node_unref0 (vcast);
		}
		_tmp77_ = m;
		_tmp78_ = vala_method_get_base_method (_tmp77_);
		_tmp79_ = _tmp78_;
		if (_tmp79_ != NULL) {
			ValaMethod* _tmp80_;
			ValaMethod* _tmp81_;
			ValaMethod* _tmp82_;
			_tmp80_ = m;
			_tmp81_ = vala_method_get_base_method (_tmp80_);
			_tmp82_ = _tmp81_;
			if (vala_get_ccode_no_wrapper (_tmp82_)) {
				ValaClass* base_class = NULL;
				ValaMethod* _tmp83_;
				ValaMethod* _tmp84_;
				ValaMethod* _tmp85_;
				ValaSymbol* _tmp86_;
				ValaSymbol* _tmp87_;
				ValaClass* _tmp88_;
				gboolean _tmp89_;
				gboolean _tmp90_;
				_tmp83_ = m;
				_tmp84_ = vala_method_get_base_method (_tmp83_);
				_tmp85_ = _tmp84_;
				_tmp86_ = vala_symbol_get_parent_symbol ((ValaSymbol*) _tmp85_);
				_tmp87_ = _tmp86_;
				base_class = G_TYPE_CHECK_INSTANCE_CAST (_tmp87_, VALA_TYPE_CLASS, ValaClass);
				_tmp88_ = base_class;
				_tmp89_ = vala_class_get_is_compact (_tmp88_);
				_tmp90_ = _tmp89_;
				if (!_tmp90_) {
					ValaCCodeExpression* vclass = NULL;
					ValaClass* _tmp91_;
					ValaExpression* _tmp92_;
					ValaExpression* _tmp93_;
					ValaTargetValue* _tmp94_;
					ValaTargetValue* _tmp95_;
					ValaCCodeExpression* _tmp96_;
					ValaCCodeExpression* _tmp97_;
					ValaMethod* _tmp98_;
					gchar* _tmp99_;
					gchar* _tmp100_;
					ValaCCodeMemberAccess* _tmp101_;
					ValaCCodeMemberAccess* _tmp102_;
					_tmp91_ = base_class;
					_tmp92_ = vala_member_access_get_inner (expr);
					_tmp93_ = _tmp92_;
					_tmp94_ = vala_expression_get_target_value (_tmp93_);
					_tmp95_ = _tmp94_;
					_tmp96_ = vala_ccode_base_module_get_this_class_cexpression ((ValaCCodeBaseModule*) self, _tmp91_, _tmp95_);
					vclass = _tmp96_;
					_tmp97_ = vclass;
					_tmp98_ = m;
					_tmp99_ = vala_get_ccode_vfunc_name (_tmp98_);
					_tmp100_ = _tmp99_;
					_tmp101_ = vala_ccode_member_access_new_pointer (_tmp97_, _tmp100_);
					_tmp102_ = _tmp101_;
					vala_set_cvalue ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp102_);
					_vala_ccode_node_unref0 (_tmp102_);
					_g_free0 (_tmp100_);
					_vala_ccode_node_unref0 (vclass);
				} else {
					ValaCCodeExpression* _tmp103_;
					ValaMethod* _tmp104_;
					gchar* _tmp105_;
					gchar* _tmp106_;
					ValaCCodeMemberAccess* _tmp107_;
					ValaCCodeMemberAccess* _tmp108_;
					_tmp103_ = pub_inst;
					_tmp104_ = m;
					_tmp105_ = vala_get_ccode_vfunc_name (_tmp104_);
					_tmp106_ = _tmp105_;
					_tmp107_ = vala_ccode_member_access_new_pointer (_tmp103_, _tmp106_);
					_tmp108_ = _tmp107_;
					vala_set_cvalue ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp108_);
					_vala_ccode_node_unref0 (_tmp108_);
					_g_free0 (_tmp106_);
				}
			} else {
				ValaMethod* _tmp109_;
				ValaMethod* _tmp110_;
				ValaMethod* _tmp111_;
				gchar* _tmp112_;
				gchar* _tmp113_;
				ValaCCodeIdentifier* _tmp114_;
				ValaCCodeIdentifier* _tmp115_;
				_tmp109_ = m;
				_tmp110_ = vala_method_get_base_method (_tmp109_);
				_tmp111_ = _tmp110_;
				_tmp112_ = vala_get_ccode_name ((ValaCodeNode*) _tmp111_);
				_tmp113_ = _tmp112_;
				_tmp114_ = vala_ccode_identifier_new (_tmp113_);
				_tmp115_ = _tmp114_;
				vala_set_cvalue ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp115_);
				_vala_ccode_node_unref0 (_tmp115_);
				_g_free0 (_tmp113_);
			}
		} else {
			ValaMethod* _tmp116_;
			ValaMethod* _tmp117_;
			ValaMethod* _tmp118_;
			_tmp116_ = m;
			_tmp117_ = vala_method_get_base_interface_method (_tmp116_);
			_tmp118_ = _tmp117_;
			if (_tmp118_ != NULL) {
				ValaMethod* _tmp119_;
				ValaMethod* _tmp120_;
				ValaMethod* _tmp121_;
				_tmp119_ = m;
				_tmp120_ = vala_method_get_base_interface_method (_tmp119_);
				_tmp121_ = _tmp120_;
				if (vala_get_ccode_no_wrapper (_tmp121_)) {
					ValaInterface* base_iface = NULL;
					ValaMethod* _tmp122_;
					ValaMethod* _tmp123_;
					ValaMethod* _tmp124_;
					ValaSymbol* _tmp125_;
					ValaSymbol* _tmp126_;
					ValaCCodeExpression* vclass = NULL;
					ValaInterface* _tmp127_;
					ValaExpression* _tmp128_;
					ValaExpression* _tmp129_;
					ValaTargetValue* _tmp130_;
					ValaTargetValue* _tmp131_;
					ValaCCodeExpression* _tmp132_;
					ValaCCodeExpression* _tmp133_;
					ValaMethod* _tmp134_;
					gchar* _tmp135_;
					gchar* _tmp136_;
					ValaCCodeMemberAccess* _tmp137_;
					ValaCCodeMemberAccess* _tmp138_;
					_tmp122_ = m;
					_tmp123_ = vala_method_get_base_interface_method (_tmp122_);
					_tmp124_ = _tmp123_;
					_tmp125_ = vala_symbol_get_parent_symbol ((ValaSymbol*) _tmp124_);
					_tmp126_ = _tmp125_;
					base_iface = G_TYPE_CHECK_INSTANCE_CAST (_tmp126_, VALA_TYPE_INTERFACE, ValaInterface);
					_tmp127_ = base_iface;
					_tmp128_ = vala_member_access_get_inner (expr);
					_tmp129_ = _tmp128_;
					_tmp130_ = vala_expression_get_target_value (_tmp129_);
					_tmp131_ = _tmp130_;
					_tmp132_ = vala_ccode_base_module_get_this_interface_cexpression ((ValaCCodeBaseModule*) self, _tmp127_, _tmp131_);
					vclass = _tmp132_;
					_tmp133_ = vclass;
					_tmp134_ = m;
					_tmp135_ = vala_get_ccode_vfunc_name (_tmp134_);
					_tmp136_ = _tmp135_;
					_tmp137_ = vala_ccode_member_access_new_pointer (_tmp133_, _tmp136_);
					_tmp138_ = _tmp137_;
					vala_set_cvalue ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp138_);
					_vala_ccode_node_unref0 (_tmp138_);
					_g_free0 (_tmp136_);
					_vala_ccode_node_unref0 (vclass);
				} else {
					ValaMethod* _tmp139_;
					ValaMethod* _tmp140_;
					ValaMethod* _tmp141_;
					gchar* _tmp142_;
					gchar* _tmp143_;
					ValaCCodeIdentifier* _tmp144_;
					ValaCCodeIdentifier* _tmp145_;
					_tmp139_ = m;
					_tmp140_ = vala_method_get_base_interface_method (_tmp139_);
					_tmp141_ = _tmp140_;
					_tmp142_ = vala_get_ccode_name ((ValaCodeNode*) _tmp141_);
					_tmp143_ = _tmp142_;
					_tmp144_ = vala_ccode_identifier_new (_tmp143_);
					_tmp145_ = _tmp144_;
					vala_set_cvalue ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp145_);
					_vala_ccode_node_unref0 (_tmp145_);
					_g_free0 (_tmp143_);
				}
			} else {
				ValaMethod* _tmp146_;
				_tmp146_ = m;
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp146_, VALA_TYPE_CREATION_METHOD)) {
					ValaMethod* _tmp147_;
					gchar* _tmp148_;
					gchar* _tmp149_;
					ValaCCodeIdentifier* _tmp150_;
					ValaCCodeIdentifier* _tmp151_;
					_tmp147_ = m;
					_tmp148_ = vala_get_ccode_real_name ((ValaSymbol*) _tmp147_);
					_tmp149_ = _tmp148_;
					_tmp150_ = vala_ccode_identifier_new (_tmp149_);
					_tmp151_ = _tmp150_;
					vala_set_cvalue ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp151_);
					_vala_ccode_node_unref0 (_tmp151_);
					_g_free0 (_tmp149_);
				} else {
					ValaMethod* _tmp152_;
					gchar* _tmp153_;
					gchar* _tmp154_;
					ValaCCodeIdentifier* _tmp155_;
					ValaCCodeIdentifier* _tmp156_;
					_tmp152_ = m;
					_tmp153_ = vala_get_ccode_name ((ValaCodeNode*) _tmp152_);
					_tmp154_ = _tmp153_;
					_tmp155_ = vala_ccode_identifier_new (_tmp154_);
					_tmp156_ = _tmp155_;
					vala_set_cvalue ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp156_);
					_vala_ccode_node_unref0 (_tmp156_);
					_g_free0 (_tmp154_);
				}
			}
		}
		_tmp157_ = vala_ccode_constant_new ("NULL");
		_tmp158_ = _tmp157_;
		vala_set_delegate_target_destroy_notify ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp158_);
		_vala_ccode_node_unref0 (_tmp158_);
		_tmp159_ = m;
		_tmp160_ = vala_method_get_binding (_tmp159_);
		_tmp161_ = _tmp160_;
		if (_tmp161_ == VALA_MEMBER_BINDING_STATIC) {
			ValaCCodeConstant* _tmp162_;
			ValaCCodeConstant* _tmp163_;
			_tmp162_ = vala_ccode_constant_new ("NULL");
			_tmp163_ = _tmp162_;
			vala_set_delegate_target ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp163_);
			_vala_ccode_node_unref0 (_tmp163_);
		} else {
			ValaMethod* _tmp164_;
			gboolean _tmp165_;
			gboolean _tmp166_;
			_tmp164_ = m;
			_tmp165_ = vala_method_get_is_async_callback (_tmp164_);
			_tmp166_ = _tmp165_;
			if (_tmp166_) {
				ValaMethod* _tmp167_;
				ValaMethod* _tmp168_;
				gboolean _tmp169_;
				gboolean _tmp170_;
				_tmp167_ = vala_ccode_base_module_get_current_method ((ValaCCodeBaseModule*) self);
				_tmp168_ = _tmp167_;
				_tmp169_ = vala_method_get_closure (_tmp168_);
				_tmp170_ = _tmp169_;
				if (_tmp170_) {
					ValaBlock* block = NULL;
					ValaMethod* _tmp171_;
					ValaSymbol* _tmp172_;
					ValaSymbol* _tmp173_;
					ValaBlock* _tmp174_;
					ValaBlock* _tmp175_;
					ValaBlock* _tmp176_;
					ValaBlock* _tmp177_;
					gchar* _tmp178_;
					gchar* _tmp179_;
					ValaCCodeExpression* _tmp180_;
					ValaCCodeExpression* _tmp181_;
					ValaCCodeMemberAccess* _tmp182_;
					ValaCCodeMemberAccess* _tmp183_;
					_tmp171_ = m;
					_tmp172_ = vala_symbol_get_parent_symbol ((ValaSymbol*) _tmp171_);
					_tmp173_ = _tmp172_;
					_tmp174_ = vala_subroutine_get_body ((ValaSubroutine*) G_TYPE_CHECK_INSTANCE_CAST (_tmp173_, VALA_TYPE_METHOD, ValaMethod));
					_tmp175_ = _tmp174_;
					_tmp176_ = _vala_code_node_ref0 (_tmp175_);
					block = _tmp176_;
					_tmp177_ = block;
					_tmp178_ = g_strdup_printf ("_data%d_", vala_ccode_base_module_get_block_id ((ValaCCodeBaseModule*) self, _tmp177_));
					_tmp179_ = _tmp178_;
					_tmp180_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp179_);
					_tmp181_ = _tmp180_;
					_tmp182_ = vala_ccode_member_access_new_pointer (_tmp181_, "_async_data_");
					_tmp183_ = _tmp182_;
					vala_set_delegate_target ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp183_);
					_vala_ccode_node_unref0 (_tmp183_);
					_vala_ccode_node_unref0 (_tmp181_);
					_g_free0 (_tmp179_);
					_vala_code_node_unref0 (block);
				} else {
					ValaCCodeIdentifier* _tmp184_;
					ValaCCodeIdentifier* _tmp185_;
					_tmp184_ = vala_ccode_identifier_new ("_data_");
					_tmp185_ = _tmp184_;
					vala_set_delegate_target ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp185_);
					_vala_ccode_node_unref0 (_tmp185_);
				}
			} else {
				gboolean _tmp186_ = FALSE;
				ValaExpression* _tmp187_;
				ValaExpression* _tmp188_;
				_tmp187_ = vala_member_access_get_inner (expr);
				_tmp188_ = _tmp187_;
				if (_tmp188_ != NULL) {
					gboolean _tmp189_;
					gboolean _tmp190_;
					_tmp189_ = vala_member_access_get_prototype_access (expr);
					_tmp190_ = _tmp189_;
					_tmp186_ = !_tmp190_;
				} else {
					_tmp186_ = FALSE;
				}
				if (_tmp186_) {
					ValaCCodeExpression* delegate_target = NULL;
					ValaExpression* _tmp191_;
					ValaExpression* _tmp192_;
					ValaCCodeExpression* _tmp193_;
					ValaDataType* _tmp194_;
					ValaDataType* _tmp195_;
					ValaDelegateType* _tmp196_;
					gboolean _tmp197_ = FALSE;
					gboolean _tmp198_ = FALSE;
					gboolean _tmp199_ = FALSE;
					ValaDataType* _tmp200_;
					ValaDataType* _tmp201_;
					gboolean _tmp202_;
					gboolean _tmp203_;
					ValaCCodeExpression* _tmp241_;
					_tmp191_ = vala_member_access_get_inner (expr);
					_tmp192_ = _tmp191_;
					_tmp193_ = vala_ccode_base_module_get_ccodenode ((ValaCCodeBaseModule*) self, _tmp192_);
					delegate_target = G_TYPE_CHECK_INSTANCE_CAST (_tmp193_, VALA_TYPE_CCODE_EXPRESSION, ValaCCodeExpression);
					_tmp194_ = vala_expression_get_target_type ((ValaExpression*) expr);
					_tmp195_ = _tmp194_;
					_tmp196_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp195_, VALA_TYPE_DELEGATE_TYPE) ? ((ValaDelegateType*) _tmp195_) : NULL);
					_vala_code_node_unref0 (delegate_type);
					delegate_type = _tmp196_;
					_tmp200_ = vala_expression_get_value_type ((ValaExpression*) expr);
					_tmp201_ = _tmp200_;
					_tmp202_ = vala_data_type_get_value_owned (_tmp201_);
					_tmp203_ = _tmp202_;
					if (_tmp203_) {
						_tmp199_ = TRUE;
					} else {
						gboolean _tmp204_ = FALSE;
						ValaDelegateType* _tmp205_;
						_tmp205_ = delegate_type;
						if (_tmp205_ != NULL) {
							ValaDelegateType* _tmp206_;
							gboolean _tmp207_;
							gboolean _tmp208_;
							_tmp206_ = delegate_type;
							_tmp207_ = vala_delegate_type_get_is_called_once (_tmp206_);
							_tmp208_ = _tmp207_;
							_tmp204_ = _tmp208_;
						} else {
							_tmp204_ = FALSE;
						}
						_tmp199_ = _tmp204_;
					}
					if (_tmp199_) {
						ValaExpression* _tmp209_;
						ValaExpression* _tmp210_;
						ValaDataType* _tmp211_;
						ValaDataType* _tmp212_;
						ValaTypeSymbol* _tmp213_;
						ValaTypeSymbol* _tmp214_;
						_tmp209_ = vala_member_access_get_inner (expr);
						_tmp210_ = _tmp209_;
						_tmp211_ = vala_expression_get_value_type (_tmp210_);
						_tmp212_ = _tmp211_;
						_tmp213_ = vala_data_type_get_type_symbol (_tmp212_);
						_tmp214_ = _tmp213_;
						_tmp198_ = _tmp214_ != NULL;
					} else {
						_tmp198_ = FALSE;
					}
					if (_tmp198_) {
						ValaExpression* _tmp215_;
						ValaExpression* _tmp216_;
						ValaDataType* _tmp217_;
						ValaDataType* _tmp218_;
						ValaTypeSymbol* _tmp219_;
						ValaTypeSymbol* _tmp220_;
						_tmp215_ = vala_member_access_get_inner (expr);
						_tmp216_ = _tmp215_;
						_tmp217_ = vala_expression_get_value_type (_tmp216_);
						_tmp218_ = _tmp217_;
						_tmp219_ = vala_data_type_get_type_symbol (_tmp218_);
						_tmp220_ = _tmp219_;
						_tmp197_ = vala_is_reference_counting (_tmp220_);
					} else {
						_tmp197_ = FALSE;
					}
					if (_tmp197_) {
						ValaCCodeFunctionCall* ref_call = NULL;
						ValaExpression* _tmp221_;
						ValaExpression* _tmp222_;
						ValaDataType* _tmp223_;
						ValaDataType* _tmp224_;
						ValaSourceReference* _tmp225_;
						ValaSourceReference* _tmp226_;
						ValaCCodeExpression* _tmp227_;
						ValaCCodeExpression* _tmp228_;
						ValaCCodeFunctionCall* _tmp229_;
						ValaCCodeFunctionCall* _tmp230_;
						ValaCCodeFunctionCall* _tmp231_;
						ValaCCodeExpression* _tmp232_;
						ValaCCodeFunctionCall* _tmp233_;
						ValaCCodeExpression* _tmp234_;
						ValaExpression* _tmp235_;
						ValaExpression* _tmp236_;
						ValaDataType* _tmp237_;
						ValaDataType* _tmp238_;
						ValaCCodeExpression* _tmp239_;
						ValaCCodeExpression* _tmp240_;
						_tmp221_ = vala_member_access_get_inner (expr);
						_tmp222_ = _tmp221_;
						_tmp223_ = vala_expression_get_value_type (_tmp222_);
						_tmp224_ = _tmp223_;
						_tmp225_ = vala_code_node_get_source_reference ((ValaCodeNode*) expr);
						_tmp226_ = _tmp225_;
						_tmp227_ = vala_ccode_base_module_get_dup_func_expression ((ValaCCodeBaseModule*) self, _tmp224_, _tmp226_, FALSE);
						_tmp228_ = _tmp227_;
						_tmp229_ = vala_ccode_function_call_new (_tmp228_);
						_tmp230_ = _tmp229_;
						_vala_ccode_node_unref0 (_tmp228_);
						ref_call = _tmp230_;
						_tmp231_ = ref_call;
						_tmp232_ = delegate_target;
						vala_ccode_function_call_add_argument (_tmp231_, _tmp232_);
						_tmp233_ = ref_call;
						_tmp234_ = _vala_ccode_node_ref0 ((ValaCCodeExpression*) _tmp233_);
						_vala_ccode_node_unref0 (delegate_target);
						delegate_target = _tmp234_;
						_tmp235_ = vala_member_access_get_inner (expr);
						_tmp236_ = _tmp235_;
						_tmp237_ = vala_expression_get_value_type (_tmp236_);
						_tmp238_ = _tmp237_;
						_tmp239_ = vala_ccode_base_module_get_destroy_func_expression ((ValaCCodeBaseModule*) self, _tmp238_, FALSE);
						_tmp240_ = _tmp239_;
						vala_set_delegate_target_destroy_notify ((ValaExpression*) expr, _tmp240_);
						_vala_ccode_node_unref0 (_tmp240_);
						_vala_ccode_node_unref0 (ref_call);
					}
					_tmp241_ = delegate_target;
					vala_set_delegate_target ((ValaExpression*) expr, _tmp241_);
					_vala_ccode_node_unref0 (delegate_target);
				}
			}
		}
		_vala_code_node_unref0 (m);
	} else {
		ValaSymbol* _tmp242_;
		ValaSymbol* _tmp243_;
		_tmp242_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
		_tmp243_ = _tmp242_;
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp243_, VALA_TYPE_ARRAY_LENGTH_FIELD)) {
			ValaExpression* _tmp244_;
			ValaExpression* _tmp245_;
			ValaCCodeExpression* _tmp246_;
			ValaCCodeExpression* _tmp247_;
			_tmp244_ = vala_member_access_get_inner (expr);
			_tmp245_ = _tmp244_;
			_tmp246_ = vala_ccode_base_module_get_array_length_cexpression ((ValaCCodeBaseModule*) self, _tmp245_, 1);
			_tmp247_ = _tmp246_;
			vala_set_cvalue ((ValaExpression*) expr, _tmp247_);
			_vala_ccode_node_unref0 (_tmp247_);
		} else {
			ValaSymbol* _tmp248_;
			ValaSymbol* _tmp249_;
			_tmp248_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
			_tmp249_ = _tmp248_;
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp249_, VALA_TYPE_DELEGATE_TARGET_FIELD)) {
				ValaCCodeExpression* delegate_target_destroy_notify = NULL;
				ValaCCodeExpression* _tmp250_ = NULL;
				ValaExpression* _tmp251_;
				ValaExpression* _tmp252_;
				ValaCCodeExpression* _tmp253_ = NULL;
				ValaCCodeExpression* _tmp254_;
				_tmp251_ = vala_member_access_get_inner (expr);
				_tmp252_ = _tmp251_;
				_tmp254_ = vala_ccode_base_module_get_delegate_target_cexpression ((ValaCCodeBaseModule*) self, _tmp252_, &_tmp253_);
				_vala_ccode_node_unref0 (delegate_target_destroy_notify);
				delegate_target_destroy_notify = _tmp253_;
				_tmp250_ = _tmp254_;
				if (_tmp250_ == NULL) {
					ValaCCodeConstant* _tmp255_;
					_tmp255_ = vala_ccode_constant_new ("NULL");
					_vala_ccode_node_unref0 (_tmp250_);
					_tmp250_ = (ValaCCodeExpression*) _tmp255_;
				}
				vala_set_cvalue ((ValaExpression*) expr, _tmp250_);
				_vala_ccode_node_unref0 (_tmp250_);
				_vala_ccode_node_unref0 (delegate_target_destroy_notify);
			} else {
				ValaSymbol* _tmp256_;
				ValaSymbol* _tmp257_;
				_tmp256_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
				_tmp257_ = _tmp256_;
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp257_, VALA_TYPE_DELEGATE_DESTROY_FIELD)) {
					ValaCCodeExpression* delegate_target_destroy_notify = NULL;
					ValaExpression* _tmp258_;
					ValaExpression* _tmp259_;
					ValaCCodeExpression* _tmp260_ = NULL;
					ValaCCodeExpression* _tmp261_;
					ValaCCodeExpression* _tmp262_;
					ValaCCodeExpression* _tmp263_ = NULL;
					ValaCCodeExpression* _tmp264_;
					ValaCCodeExpression* _tmp265_;
					_tmp258_ = vala_member_access_get_inner (expr);
					_tmp259_ = _tmp258_;
					_tmp261_ = vala_ccode_base_module_get_delegate_target_cexpression ((ValaCCodeBaseModule*) self, _tmp259_, &_tmp260_);
					_vala_ccode_node_unref0 (delegate_target_destroy_notify);
					delegate_target_destroy_notify = _tmp260_;
					_tmp262_ = _tmp261_;
					_vala_ccode_node_unref0 (_tmp262_);
					_tmp264_ = delegate_target_destroy_notify;
					_tmp265_ = _vala_ccode_node_ref0 (_tmp264_);
					_tmp263_ = _tmp265_;
					if (_tmp263_ == NULL) {
						ValaCCodeConstant* _tmp266_;
						_tmp266_ = vala_ccode_constant_new ("NULL");
						_vala_ccode_node_unref0 (_tmp263_);
						_tmp263_ = (ValaCCodeExpression*) _tmp266_;
					}
					vala_set_cvalue ((ValaExpression*) expr, _tmp263_);
					_vala_ccode_node_unref0 (_tmp263_);
					_vala_ccode_node_unref0 (delegate_target_destroy_notify);
				} else {
					ValaSymbol* _tmp267_;
					ValaSymbol* _tmp268_;
					_tmp267_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
					_tmp268_ = _tmp267_;
					if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp268_, VALA_TYPE_GENERIC_DUP_FIELD)) {
						ValaExpression* _tmp269_;
						ValaExpression* _tmp270_;
						ValaDataType* _tmp271_;
						ValaDataType* _tmp272_;
						ValaSourceReference* _tmp273_;
						ValaSourceReference* _tmp274_;
						ValaCCodeExpression* _tmp275_;
						ValaCCodeExpression* _tmp276_;
						_tmp269_ = vala_member_access_get_inner (expr);
						_tmp270_ = _tmp269_;
						_tmp271_ = vala_expression_get_value_type (_tmp270_);
						_tmp272_ = _tmp271_;
						_tmp273_ = vala_code_node_get_source_reference ((ValaCodeNode*) expr);
						_tmp274_ = _tmp273_;
						_tmp275_ = vala_ccode_base_module_get_dup_func_expression ((ValaCCodeBaseModule*) self, _tmp272_, _tmp274_, FALSE);
						_tmp276_ = _tmp275_;
						vala_set_cvalue ((ValaExpression*) expr, _tmp276_);
						_vala_ccode_node_unref0 (_tmp276_);
					} else {
						ValaSymbol* _tmp277_;
						ValaSymbol* _tmp278_;
						_tmp277_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
						_tmp278_ = _tmp277_;
						if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp278_, VALA_TYPE_GENERIC_DESTROY_FIELD)) {
							ValaExpression* _tmp279_;
							ValaExpression* _tmp280_;
							ValaDataType* _tmp281_;
							ValaDataType* _tmp282_;
							ValaCCodeExpression* _tmp283_;
							ValaCCodeExpression* _tmp284_;
							_tmp279_ = vala_member_access_get_inner (expr);
							_tmp280_ = _tmp279_;
							_tmp281_ = vala_expression_get_value_type (_tmp280_);
							_tmp282_ = _tmp281_;
							_tmp283_ = vala_ccode_base_module_get_destroy_func_expression ((ValaCCodeBaseModule*) self, _tmp282_, FALSE);
							_tmp284_ = _tmp283_;
							vala_set_cvalue ((ValaExpression*) expr, _tmp284_);
							_vala_ccode_node_unref0 (_tmp284_);
						} else {
							ValaSymbol* _tmp285_;
							ValaSymbol* _tmp286_;
							_tmp285_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
							_tmp286_ = _tmp285_;
							if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp286_, VALA_TYPE_FIELD)) {
								ValaField* field = NULL;
								ValaSymbol* _tmp287_;
								ValaSymbol* _tmp288_;
								ValaField* _tmp289_;
								gboolean _tmp290_;
								gboolean _tmp291_;
								_tmp287_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
								_tmp288_ = _tmp287_;
								_tmp289_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp288_, VALA_TYPE_FIELD, ValaField));
								field = _tmp289_;
								_tmp290_ = vala_expression_get_lvalue ((ValaExpression*) expr);
								_tmp291_ = _tmp290_;
								if (_tmp291_) {
									ValaTargetValue* _tmp292_ = NULL;
									ValaExpression* _tmp293_;
									ValaExpression* _tmp294_;
									ValaField* _tmp299_;
									ValaTargetValue* _tmp300_;
									ValaTargetValue* _tmp301_;
									_tmp293_ = vala_member_access_get_inner (expr);
									_tmp294_ = _tmp293_;
									if (_tmp294_ != NULL) {
										ValaExpression* _tmp295_;
										ValaExpression* _tmp296_;
										ValaTargetValue* _tmp297_;
										ValaTargetValue* _tmp298_;
										_tmp295_ = vala_member_access_get_inner (expr);
										_tmp296_ = _tmp295_;
										_tmp297_ = vala_expression_get_target_value (_tmp296_);
										_tmp298_ = _tmp297_;
										_tmp292_ = _tmp298_;
									} else {
										_tmp292_ = NULL;
									}
									_tmp299_ = field;
									_tmp300_ = vala_ccode_base_module_get_field_cvalue ((ValaCCodeBaseModule*) self, _tmp299_, _tmp292_);
									_tmp301_ = _tmp300_;
									vala_expression_set_target_value ((ValaExpression*) expr, _tmp301_);
									_vala_target_value_unref0 (_tmp301_);
								} else {
									ValaTargetValue* _tmp302_ = NULL;
									ValaExpression* _tmp303_;
									ValaExpression* _tmp304_;
									ValaField* _tmp309_;
									ValaTargetValue* _tmp310_;
									ValaTargetValue* _tmp311_;
									_tmp303_ = vala_member_access_get_inner (expr);
									_tmp304_ = _tmp303_;
									if (_tmp304_ != NULL) {
										ValaExpression* _tmp305_;
										ValaExpression* _tmp306_;
										ValaTargetValue* _tmp307_;
										ValaTargetValue* _tmp308_;
										_tmp305_ = vala_member_access_get_inner (expr);
										_tmp306_ = _tmp305_;
										_tmp307_ = vala_expression_get_target_value (_tmp306_);
										_tmp308_ = _tmp307_;
										_tmp302_ = _tmp308_;
									} else {
										_tmp302_ = NULL;
									}
									_tmp309_ = field;
									_tmp310_ = vala_code_generator_load_field ((ValaCodeGenerator*) self, _tmp309_, _tmp302_, (ValaExpression*) expr);
									_tmp311_ = _tmp310_;
									vala_expression_set_target_value ((ValaExpression*) expr, _tmp311_);
									_vala_target_value_unref0 (_tmp311_);
								}
								_vala_code_node_unref0 (field);
							} else {
								ValaSymbol* _tmp312_;
								ValaSymbol* _tmp313_;
								_tmp312_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
								_tmp313_ = _tmp312_;
								if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp313_, VALA_TYPE_ENUM_VALUE)) {
									ValaEnumValue* ev = NULL;
									ValaSymbol* _tmp314_;
									ValaSymbol* _tmp315_;
									ValaEnumValue* _tmp316_;
									ValaEnumValue* _tmp317_;
									ValaSymbol* _tmp318_;
									ValaSymbol* _tmp319_;
									ValaCCodeFile* _tmp320_;
									ValaEnumValue* _tmp321_;
									gchar* _tmp322_;
									gchar* _tmp323_;
									ValaCCodeConstant* _tmp324_;
									ValaCCodeConstant* _tmp325_;
									_tmp314_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
									_tmp315_ = _tmp314_;
									_tmp316_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp315_, VALA_TYPE_ENUM_VALUE, ValaEnumValue));
									ev = _tmp316_;
									_tmp317_ = ev;
									_tmp318_ = vala_symbol_get_parent_symbol ((ValaSymbol*) _tmp317_);
									_tmp319_ = _tmp318_;
									_tmp320_ = ((ValaCCodeBaseModule*) self)->cfile;
									vala_ccode_base_module_generate_enum_declaration ((ValaCCodeBaseModule*) self, G_TYPE_CHECK_INSTANCE_CAST (_tmp319_, VALA_TYPE_ENUM, ValaEnum), _tmp320_);
									_tmp321_ = ev;
									_tmp322_ = vala_get_ccode_name ((ValaCodeNode*) _tmp321_);
									_tmp323_ = _tmp322_;
									_tmp324_ = vala_ccode_constant_new (_tmp323_);
									_tmp325_ = _tmp324_;
									vala_set_cvalue ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp325_);
									_vala_ccode_node_unref0 (_tmp325_);
									_g_free0 (_tmp323_);
									_vala_code_node_unref0 (ev);
								} else {
									ValaSymbol* _tmp326_;
									ValaSymbol* _tmp327_;
									_tmp326_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
									_tmp327_ = _tmp326_;
									if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp327_, VALA_TYPE_CONSTANT)) {
										ValaConstant* c = NULL;
										ValaSymbol* _tmp328_;
										ValaSymbol* _tmp329_;
										ValaConstant* _tmp330_;
										gboolean _tmp331_ = FALSE;
										gboolean _tmp332_ = FALSE;
										ValaConstant* _tmp333_;
										ValaSourceReference* _tmp334_;
										ValaSourceReference* _tmp335_;
										ValaConstant* _tmp347_;
										ValaCCodeFile* _tmp348_;
										gchar* fn = NULL;
										ValaConstant* _tmp349_;
										gchar* _tmp350_;
										const gchar* _tmp351_;
										ValaArrayType* _tmp398_;
										_tmp328_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
										_tmp329_ = _tmp328_;
										_tmp330_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp329_, VALA_TYPE_CONSTANT, ValaConstant));
										c = _tmp330_;
										_tmp333_ = c;
										_tmp334_ = vala_code_node_get_source_reference ((ValaCodeNode*) _tmp333_);
										_tmp335_ = _tmp334_;
										if (_tmp335_ != NULL) {
											ValaSourceReference* _tmp336_;
											ValaSourceReference* _tmp337_;
											_tmp336_ = vala_code_node_get_source_reference ((ValaCodeNode*) expr);
											_tmp337_ = _tmp336_;
											_tmp332_ = _tmp337_ != NULL;
										} else {
											_tmp332_ = FALSE;
										}
										if (_tmp332_) {
											ValaConstant* _tmp338_;
											ValaSourceReference* _tmp339_;
											ValaSourceReference* _tmp340_;
											ValaSourceFile* _tmp341_;
											ValaSourceFile* _tmp342_;
											ValaSourceReference* _tmp343_;
											ValaSourceReference* _tmp344_;
											ValaSourceFile* _tmp345_;
											ValaSourceFile* _tmp346_;
											_tmp338_ = c;
											_tmp339_ = vala_code_node_get_source_reference ((ValaCodeNode*) _tmp338_);
											_tmp340_ = _tmp339_;
											_tmp341_ = vala_source_reference_get_file (_tmp340_);
											_tmp342_ = _tmp341_;
											_tmp343_ = vala_code_node_get_source_reference ((ValaCodeNode*) expr);
											_tmp344_ = _tmp343_;
											_tmp345_ = vala_source_reference_get_file (_tmp344_);
											_tmp346_ = _tmp345_;
											_tmp331_ = _tmp342_ == _tmp346_;
										} else {
											_tmp331_ = FALSE;
										}
										_tmp347_ = c;
										_tmp348_ = ((ValaCCodeBaseModule*) self)->cfile;
										vala_ccode_base_module_generate_constant_declaration ((ValaCCodeBaseModule*) self, _tmp347_, _tmp348_, _tmp331_);
										_tmp349_ = c;
										_tmp350_ = vala_symbol_get_full_name ((ValaSymbol*) _tmp349_);
										fn = _tmp350_;
										_tmp351_ = fn;
										if (g_strcmp0 (_tmp351_, "GLib.Log.FILE") == 0) {
											gchar* s = NULL;
											ValaSourceReference* _tmp352_;
											ValaSourceReference* _tmp353_;
											ValaSourceFile* _tmp354_;
											ValaSourceFile* _tmp355_;
											const gchar* _tmp356_;
											const gchar* _tmp357_;
											gchar* _tmp358_;
											const gchar* _tmp359_;
											gchar* _tmp360_;
											gchar* _tmp361_;
											ValaCCodeConstant* _tmp362_;
											ValaCCodeConstant* _tmp363_;
											_tmp352_ = vala_code_node_get_source_reference ((ValaCodeNode*) expr);
											_tmp353_ = _tmp352_;
											_tmp354_ = vala_source_reference_get_file (_tmp353_);
											_tmp355_ = _tmp354_;
											_tmp356_ = vala_source_file_get_filename (_tmp355_);
											_tmp357_ = _tmp356_;
											_tmp358_ = g_path_get_basename (_tmp357_);
											s = _tmp358_;
											_tmp359_ = s;
											_tmp360_ = g_strdup_printf ("\"%s\"", _tmp359_);
											_tmp361_ = _tmp360_;
											_tmp362_ = vala_ccode_constant_new (_tmp361_);
											_tmp363_ = _tmp362_;
											vala_set_cvalue ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp363_);
											_vala_ccode_node_unref0 (_tmp363_);
											_g_free0 (_tmp361_);
											_g_free0 (s);
										} else {
											const gchar* _tmp364_;
											_tmp364_ = fn;
											if (g_strcmp0 (_tmp364_, "GLib.Log.LINE") == 0) {
												gint i = 0;
												ValaSourceReference* _tmp365_;
												ValaSourceReference* _tmp366_;
												ValaSourceLocation _tmp367_ = {0};
												ValaSourceLocation _tmp368_;
												gchar* _tmp369_;
												gchar* _tmp370_;
												ValaCCodeConstant* _tmp371_;
												ValaCCodeConstant* _tmp372_;
												_tmp365_ = vala_code_node_get_source_reference ((ValaCodeNode*) expr);
												_tmp366_ = _tmp365_;
												vala_source_reference_get_begin (_tmp366_, &_tmp367_);
												_tmp368_ = _tmp367_;
												i = _tmp368_.line;
												_tmp369_ = g_strdup_printf ("%d", i);
												_tmp370_ = _tmp369_;
												_tmp371_ = vala_ccode_constant_new (_tmp370_);
												_tmp372_ = _tmp371_;
												vala_set_cvalue ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp372_);
												_vala_ccode_node_unref0 (_tmp372_);
												_g_free0 (_tmp370_);
											} else {
												const gchar* _tmp373_;
												_tmp373_ = fn;
												if (g_strcmp0 (_tmp373_, "GLib.Log.METHOD") == 0) {
													gchar* s = NULL;
													gchar* _tmp374_;
													ValaMethod* _tmp375_;
													ValaMethod* _tmp376_;
													const gchar* _tmp380_;
													gchar* _tmp381_;
													gchar* _tmp382_;
													ValaCCodeConstant* _tmp383_;
													ValaCCodeConstant* _tmp384_;
													_tmp374_ = g_strdup ("");
													s = _tmp374_;
													_tmp375_ = vala_ccode_base_module_get_current_method ((ValaCCodeBaseModule*) self);
													_tmp376_ = _tmp375_;
													if (_tmp376_ != NULL) {
														ValaMethod* _tmp377_;
														ValaMethod* _tmp378_;
														gchar* _tmp379_;
														_tmp377_ = vala_ccode_base_module_get_current_method ((ValaCCodeBaseModule*) self);
														_tmp378_ = _tmp377_;
														_tmp379_ = vala_symbol_get_full_name ((ValaSymbol*) _tmp378_);
														_g_free0 (s);
														s = _tmp379_;
													}
													_tmp380_ = s;
													_tmp381_ = g_strdup_printf ("\"%s\"", _tmp380_);
													_tmp382_ = _tmp381_;
													_tmp383_ = vala_ccode_constant_new (_tmp382_);
													_tmp384_ = _tmp383_;
													vala_set_cvalue ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp384_);
													_vala_ccode_node_unref0 (_tmp384_);
													_g_free0 (_tmp382_);
													_g_free0 (s);
												} else {
													ValaConstant* _tmp385_;
													ValaDataType* _tmp386_;
													ValaDataType* _tmp387_;
													_tmp385_ = c;
													_tmp386_ = vala_constant_get_type_reference (_tmp385_);
													_tmp387_ = _tmp386_;
													if (vala_data_type_is_non_null_simple_type (_tmp387_)) {
														ValaConstant* _tmp388_;
														gchar* _tmp389_;
														gchar* _tmp390_;
														ValaCCodeConstant* _tmp391_;
														ValaCCodeConstant* _tmp392_;
														_tmp388_ = c;
														_tmp389_ = vala_get_ccode_name ((ValaCodeNode*) _tmp388_);
														_tmp390_ = _tmp389_;
														_tmp391_ = vala_ccode_constant_new (_tmp390_);
														_tmp392_ = _tmp391_;
														vala_set_cvalue ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp392_);
														_vala_ccode_node_unref0 (_tmp392_);
														_g_free0 (_tmp390_);
													} else {
														ValaConstant* _tmp393_;
														gchar* _tmp394_;
														gchar* _tmp395_;
														ValaCCodeConstantIdentifier* _tmp396_;
														ValaCCodeConstantIdentifier* _tmp397_;
														_tmp393_ = c;
														_tmp394_ = vala_get_ccode_name ((ValaCodeNode*) _tmp393_);
														_tmp395_ = _tmp394_;
														_tmp396_ = vala_ccode_constant_identifier_new (_tmp395_);
														_tmp397_ = _tmp396_;
														vala_set_cvalue ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp397_);
														_vala_ccode_node_unref0 (_tmp397_);
														_g_free0 (_tmp395_);
													}
												}
											}
										}
										_tmp398_ = array_type;
										if (_tmp398_ != NULL) {
											gchar* sub = NULL;
											gchar* _tmp399_;
											ValaTargetValue* _tmp427_;
											ValaTargetValue* _tmp428_;
											_tmp399_ = g_strdup ("");
											sub = _tmp399_;
											{
												gint i = 0;
												i = 0;
												{
													gboolean _tmp400_ = FALSE;
													_tmp400_ = TRUE;
													while (TRUE) {
														ValaArrayType* _tmp402_;
														gint _tmp403_;
														gint _tmp404_;
														ValaCCodeFunctionCall* ccall = NULL;
														ValaCodeContext* _tmp405_;
														ValaCodeContext* _tmp406_;
														ValaProfile _tmp407_;
														ValaProfile _tmp408_;
														ValaCCodeFunctionCall* _tmp415_;
														ValaConstant* _tmp416_;
														gchar* _tmp417_;
														gchar* _tmp418_;
														const gchar* _tmp419_;
														gchar* _tmp420_;
														gchar* _tmp421_;
														ValaCCodeIdentifier* _tmp422_;
														ValaCCodeIdentifier* _tmp423_;
														ValaCCodeFunctionCall* _tmp424_;
														const gchar* _tmp425_;
														gchar* _tmp426_;
														if (!_tmp400_) {
															gint _tmp401_;
															_tmp401_ = i;
															i = _tmp401_ + 1;
														}
														_tmp400_ = FALSE;
														_tmp402_ = array_type;
														_tmp403_ = vala_array_type_get_rank (_tmp402_);
														_tmp404_ = _tmp403_;
														if (!(i < _tmp404_)) {
															break;
														}
														_tmp405_ = vala_ccode_base_module_get_context ((ValaCCodeBaseModule*) self);
														_tmp406_ = _tmp405_;
														_tmp407_ = vala_code_context_get_profile (_tmp406_);
														_tmp408_ = _tmp407_;
														if (_tmp408_ == VALA_PROFILE_POSIX) {
															ValaCCodeIdentifier* _tmp409_;
															ValaCCodeIdentifier* _tmp410_;
															ValaCCodeFunctionCall* _tmp411_;
															((ValaCCodeBaseModule*) self)->requires_array_n_elements = TRUE;
															_tmp409_ = vala_ccode_identifier_new ("VALA_N_ELEMENTS");
															_tmp410_ = _tmp409_;
															_tmp411_ = vala_ccode_function_call_new ((ValaCCodeExpression*) _tmp410_);
															_vala_ccode_node_unref0 (ccall);
															ccall = _tmp411_;
															_vala_ccode_node_unref0 (_tmp410_);
														} else {
															ValaCCodeIdentifier* _tmp412_;
															ValaCCodeIdentifier* _tmp413_;
															ValaCCodeFunctionCall* _tmp414_;
															_tmp412_ = vala_ccode_identifier_new ("G_N_ELEMENTS");
															_tmp413_ = _tmp412_;
															_tmp414_ = vala_ccode_function_call_new ((ValaCCodeExpression*) _tmp413_);
															_vala_ccode_node_unref0 (ccall);
															ccall = _tmp414_;
															_vala_ccode_node_unref0 (_tmp413_);
														}
														_tmp415_ = ccall;
														_tmp416_ = c;
														_tmp417_ = vala_get_ccode_name ((ValaCodeNode*) _tmp416_);
														_tmp418_ = _tmp417_;
														_tmp419_ = sub;
														_tmp420_ = g_strconcat (_tmp418_, _tmp419_, NULL);
														_tmp421_ = _tmp420_;
														_tmp422_ = vala_ccode_identifier_new (_tmp421_);
														_tmp423_ = _tmp422_;
														vala_ccode_function_call_add_argument (_tmp415_, (ValaCCodeExpression*) _tmp423_);
														_vala_ccode_node_unref0 (_tmp423_);
														_g_free0 (_tmp421_);
														_g_free0 (_tmp418_);
														_tmp424_ = ccall;
														vala_append_array_length ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp424_);
														_tmp425_ = sub;
														_tmp426_ = g_strconcat (_tmp425_, "[0]", NULL);
														_g_free0 (sub);
														sub = _tmp426_;
														_vala_ccode_node_unref0 (ccall);
													}
												}
											}
											_tmp427_ = vala_expression_get_target_value ((ValaExpression*) expr);
											_tmp428_ = _tmp427_;
											G_TYPE_CHECK_INSTANCE_CAST (_tmp428_, VALA_TYPE_GLIB_VALUE, ValaGLibValue)->non_null = TRUE;
											_g_free0 (sub);
										}
										_g_free0 (fn);
										_vala_code_node_unref0 (c);
									} else {
										ValaSymbol* _tmp429_;
										ValaSymbol* _tmp430_;
										_tmp429_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
										_tmp430_ = _tmp429_;
										if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp430_, VALA_TYPE_PROPERTY)) {
											ValaProperty* prop = NULL;
											ValaSymbol* _tmp431_;
											ValaSymbol* _tmp432_;
											ValaProperty* _tmp433_;
											ValaProperty* _tmp434_;
											gboolean _tmp448_ = FALSE;
											ValaCCodeExpression* _tmp449_;
											ValaProperty* base_prop = NULL;
											ValaProperty* _tmp461_;
											ValaProperty* _tmp462_;
											ValaProperty* _tmp463_;
											ValaProperty* _tmp464_;
											gboolean _tmp474_ = FALSE;
											ValaExpression* _tmp475_;
											ValaExpression* _tmp476_;
											ValaProperty* _tmp857_;
											ValaPropertyAccessor* _tmp858_;
											ValaPropertyAccessor* _tmp859_;
											ValaDataType* _tmp860_;
											ValaDataType* _tmp861_;
											ValaTargetValue* _tmp877_;
											ValaTargetValue* _tmp878_;
											ValaTargetValue* _tmp879_;
											ValaTargetValue* _tmp880_;
											_tmp431_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
											_tmp432_ = _tmp431_;
											_tmp433_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp432_, VALA_TYPE_PROPERTY, ValaProperty));
											prop = _tmp433_;
											_tmp434_ = prop;
											if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp434_, VALA_TYPE_DYNAMIC_PROPERTY)) {
												ValaProperty* _tmp435_;
												ValaPropertyAccessor* _tmp436_;
												ValaPropertyAccessor* _tmp437_;
												ValaCCodeFile* _tmp438_;
												gboolean _tmp439_ = FALSE;
												ValaProperty* _tmp440_;
												gboolean _tmp441_;
												gboolean _tmp442_;
												_tmp435_ = prop;
												_tmp436_ = vala_property_get_get_accessor (_tmp435_);
												_tmp437_ = _tmp436_;
												_tmp438_ = ((ValaCCodeBaseModule*) self)->cfile;
												vala_ccode_base_module_generate_property_accessor_declaration ((ValaCCodeBaseModule*) self, _tmp437_, _tmp438_);
												_tmp440_ = prop;
												_tmp441_ = vala_symbol_get_external ((ValaSymbol*) _tmp440_);
												_tmp442_ = _tmp441_;
												if (!_tmp442_) {
													ValaProperty* _tmp443_;
													gboolean _tmp444_;
													gboolean _tmp445_;
													_tmp443_ = prop;
													_tmp444_ = vala_symbol_get_external_package ((ValaSymbol*) _tmp443_);
													_tmp445_ = _tmp444_;
													_tmp439_ = _tmp445_;
												} else {
													_tmp439_ = FALSE;
												}
												if (_tmp439_) {
													ValaProperty* _tmp446_;
													_tmp446_ = prop;
													if (vala_ccode_base_module_add_generated_external_symbol ((ValaCCodeBaseModule*) self, (ValaSymbol*) _tmp446_)) {
														ValaProperty* _tmp447_;
														_tmp447_ = prop;
														vala_code_visitor_visit_property ((ValaCodeVisitor*) self, _tmp447_);
													}
												}
											}
											_tmp449_ = pub_inst;
											if (_tmp449_ == NULL) {
												ValaProperty* _tmp450_;
												ValaMemberBinding _tmp451_;
												ValaMemberBinding _tmp452_;
												_tmp450_ = prop;
												_tmp451_ = vala_property_get_binding (_tmp450_);
												_tmp452_ = _tmp451_;
												_tmp448_ = _tmp452_ == VALA_MEMBER_BINDING_INSTANCE;
											} else {
												_tmp448_ = FALSE;
											}
											if (_tmp448_) {
												ValaProperty* _tmp453_;
												ValaSourceReference* _tmp454_;
												ValaSourceReference* _tmp455_;
												ValaProperty* _tmp456_;
												gchar* _tmp457_;
												gchar* _tmp458_;
												ValaCCodeInvalidExpression* _tmp459_;
												ValaCCodeInvalidExpression* _tmp460_;
												_tmp453_ = prop;
												_tmp454_ = vala_code_node_get_source_reference ((ValaCodeNode*) _tmp453_);
												_tmp455_ = _tmp454_;
												_tmp456_ = prop;
												_tmp457_ = vala_symbol_get_full_name ((ValaSymbol*) _tmp456_);
												_tmp458_ = _tmp457_;
												vala_report_error (_tmp455_, "Invalid access to instance member `%s'", _tmp458_);
												_g_free0 (_tmp458_);
												_tmp459_ = vala_ccode_invalid_expression_new ();
												_tmp460_ = _tmp459_;
												vala_set_cvalue ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp460_);
												_vala_ccode_node_unref0 (_tmp460_);
												_vala_code_node_unref0 (prop);
												_vala_code_node_unref0 (delegate_type);
												_vala_code_node_unref0 (array_type);
												_vala_ccode_node_unref0 (pub_inst);
												return;
											}
											_tmp461_ = prop;
											base_prop = _tmp461_;
											_tmp462_ = prop;
											_tmp463_ = vala_property_get_base_property (_tmp462_);
											_tmp464_ = _tmp463_;
											if (_tmp464_ != NULL) {
												ValaProperty* _tmp465_;
												ValaProperty* _tmp466_;
												ValaProperty* _tmp467_;
												_tmp465_ = prop;
												_tmp466_ = vala_property_get_base_property (_tmp465_);
												_tmp467_ = _tmp466_;
												base_prop = _tmp467_;
											} else {
												ValaProperty* _tmp468_;
												ValaProperty* _tmp469_;
												ValaProperty* _tmp470_;
												_tmp468_ = prop;
												_tmp469_ = vala_property_get_base_interface_property (_tmp468_);
												_tmp470_ = _tmp469_;
												if (_tmp470_ != NULL) {
													ValaProperty* _tmp471_;
													ValaProperty* _tmp472_;
													ValaProperty* _tmp473_;
													_tmp471_ = prop;
													_tmp472_ = vala_property_get_base_interface_property (_tmp471_);
													_tmp473_ = _tmp472_;
													base_prop = _tmp473_;
												}
											}
											_tmp475_ = vala_member_access_get_inner (expr);
											_tmp476_ = _tmp475_;
											if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp476_, VALA_TYPE_BASE_ACCESS)) {
												gboolean _tmp477_ = FALSE;
												ValaProperty* _tmp478_;
												gboolean _tmp479_;
												gboolean _tmp480_;
												_tmp478_ = base_prop;
												_tmp479_ = vala_property_get_is_abstract (_tmp478_);
												_tmp480_ = _tmp479_;
												if (_tmp480_) {
													_tmp477_ = TRUE;
												} else {
													ValaProperty* _tmp481_;
													gboolean _tmp482_;
													gboolean _tmp483_;
													_tmp481_ = base_prop;
													_tmp482_ = vala_property_get_is_virtual (_tmp481_);
													_tmp483_ = _tmp482_;
													_tmp477_ = _tmp483_;
												}
												_tmp474_ = _tmp477_;
											} else {
												_tmp474_ = FALSE;
											}
											if (_tmp474_) {
												ValaCCodeExpression* vcast = NULL;
												ValaProperty* _tmp484_;
												ValaSymbol* _tmp485_;
												ValaSymbol* _tmp486_;
												ValaCCodeExpression* _tmp513_;
												vcast = NULL;
												_tmp484_ = base_prop;
												_tmp485_ = vala_symbol_get_parent_symbol ((ValaSymbol*) _tmp484_);
												_tmp486_ = _tmp485_;
												if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp486_, VALA_TYPE_CLASS)) {
													ValaClass* base_class = NULL;
													ValaProperty* _tmp487_;
													ValaSymbol* _tmp488_;
													ValaSymbol* _tmp489_;
													ValaClass* _tmp490_;
													gchar* _tmp491_;
													gchar* _tmp492_;
													ValaCCodeIdentifier* _tmp493_;
													ValaCCodeIdentifier* _tmp494_;
													ValaCCodeFunctionCall* _tmp495_;
													ValaCCodeExpression* _tmp496_;
													ValaClass* _tmp497_;
													ValaClass* _tmp498_;
													gchar* _tmp499_;
													gchar* _tmp500_;
													gchar* _tmp501_;
													gchar* _tmp502_;
													ValaCCodeIdentifier* _tmp503_;
													ValaCCodeIdentifier* _tmp504_;
													_tmp487_ = base_prop;
													_tmp488_ = vala_symbol_get_parent_symbol ((ValaSymbol*) _tmp487_);
													_tmp489_ = _tmp488_;
													base_class = G_TYPE_CHECK_INSTANCE_CAST (_tmp489_, VALA_TYPE_CLASS, ValaClass);
													_tmp490_ = base_class;
													_tmp491_ = vala_get_ccode_class_type_function (_tmp490_);
													_tmp492_ = _tmp491_;
													_tmp493_ = vala_ccode_identifier_new (_tmp492_);
													_tmp494_ = _tmp493_;
													_tmp495_ = vala_ccode_function_call_new ((ValaCCodeExpression*) _tmp494_);
													_vala_ccode_node_unref0 (vcast);
													vcast = (ValaCCodeExpression*) _tmp495_;
													_vala_ccode_node_unref0 (_tmp494_);
													_g_free0 (_tmp492_);
													_tmp496_ = vcast;
													_tmp497_ = vala_ccode_base_module_get_current_class ((ValaCCodeBaseModule*) self);
													_tmp498_ = _tmp497_;
													_tmp499_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp498_, NULL);
													_tmp500_ = _tmp499_;
													_tmp501_ = g_strdup_printf ("%s_parent_class", _tmp500_);
													_tmp502_ = _tmp501_;
													_tmp503_ = vala_ccode_identifier_new (_tmp502_);
													_tmp504_ = _tmp503_;
													vala_ccode_function_call_add_argument (G_TYPE_CHECK_INSTANCE_CAST (_tmp496_, VALA_TYPE_CCODE_FUNCTION_CALL, ValaCCodeFunctionCall), (ValaCCodeExpression*) _tmp504_);
													_vala_ccode_node_unref0 (_tmp504_);
													_g_free0 (_tmp502_);
													_g_free0 (_tmp500_);
												} else {
													ValaProperty* _tmp505_;
													ValaSymbol* _tmp506_;
													ValaSymbol* _tmp507_;
													_tmp505_ = base_prop;
													_tmp506_ = vala_symbol_get_parent_symbol ((ValaSymbol*) _tmp505_);
													_tmp507_ = _tmp506_;
													if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp507_, VALA_TYPE_INTERFACE)) {
														ValaInterface* base_iface = NULL;
														ValaProperty* _tmp508_;
														ValaSymbol* _tmp509_;
														ValaSymbol* _tmp510_;
														ValaInterface* _tmp511_;
														ValaCCodeExpression* _tmp512_;
														_tmp508_ = base_prop;
														_tmp509_ = vala_symbol_get_parent_symbol ((ValaSymbol*) _tmp508_);
														_tmp510_ = _tmp509_;
														base_iface = G_TYPE_CHECK_INSTANCE_CAST (_tmp510_, VALA_TYPE_INTERFACE, ValaInterface);
														_tmp511_ = base_iface;
														_tmp512_ = vala_ccode_base_module_get_this_interface_cexpression ((ValaCCodeBaseModule*) self, _tmp511_, NULL);
														_vala_ccode_node_unref0 (vcast);
														vcast = _tmp512_;
													}
												}
												_tmp513_ = vcast;
												if (_tmp513_ != NULL) {
													ValaCCodeFunctionCall* ccall = NULL;
													ValaCCodeExpression* _tmp514_;
													ValaProperty* _tmp515_;
													const gchar* _tmp516_;
													const gchar* _tmp517_;
													gchar* _tmp518_;
													gchar* _tmp519_;
													ValaCCodeMemberAccess* _tmp520_;
													ValaCCodeMemberAccess* _tmp521_;
													ValaCCodeFunctionCall* _tmp522_;
													ValaCCodeFunctionCall* _tmp523_;
													ValaCCodeFunctionCall* _tmp524_;
													ValaExpression* _tmp525_;
													ValaExpression* _tmp526_;
													ValaCCodeExpression* _tmp527_;
													ValaProperty* _tmp528_;
													ValaDataType* _tmp529_;
													ValaDataType* _tmp530_;
													_tmp514_ = vcast;
													_tmp515_ = prop;
													_tmp516_ = vala_symbol_get_name ((ValaSymbol*) _tmp515_);
													_tmp517_ = _tmp516_;
													_tmp518_ = g_strdup_printf ("get_%s", _tmp517_);
													_tmp519_ = _tmp518_;
													_tmp520_ = vala_ccode_member_access_new_pointer (_tmp514_, _tmp519_);
													_tmp521_ = _tmp520_;
													_tmp522_ = vala_ccode_function_call_new ((ValaCCodeExpression*) _tmp521_);
													_tmp523_ = _tmp522_;
													_vala_ccode_node_unref0 (_tmp521_);
													_g_free0 (_tmp519_);
													ccall = _tmp523_;
													_tmp524_ = ccall;
													_tmp525_ = vala_member_access_get_inner (expr);
													_tmp526_ = _tmp525_;
													_tmp527_ = vala_get_cvalue (_tmp526_);
													vala_ccode_function_call_add_argument (_tmp524_, _tmp527_);
													_tmp528_ = prop;
													_tmp529_ = vala_property_get_property_type (_tmp528_);
													_tmp530_ = _tmp529_;
													if (vala_data_type_is_real_non_null_struct_type (_tmp530_)) {
														ValaGLibValue* temp_value = NULL;
														ValaProperty* _tmp531_;
														ValaPropertyAccessor* _tmp532_;
														ValaPropertyAccessor* _tmp533_;
														ValaDataType* _tmp534_;
														ValaDataType* _tmp535_;
														ValaTargetValue* _tmp536_;
														ValaGLibValue* _tmp537_;
														ValaTargetValue* _tmp538_;
														ValaTargetValue* _tmp539_;
														ValaCCodeExpression* ctemp = NULL;
														ValaGLibValue* _tmp540_;
														ValaCCodeExpression* _tmp541_;
														ValaCCodeExpression* _tmp542_;
														ValaCCodeFunctionCall* _tmp543_;
														ValaCCodeExpression* _tmp544_;
														ValaCCodeUnaryExpression* _tmp545_;
														ValaCCodeUnaryExpression* _tmp546_;
														ValaCCodeFunction* _tmp547_;
														ValaCCodeFunction* _tmp548_;
														ValaCCodeFunctionCall* _tmp549_;
														_tmp531_ = prop;
														_tmp532_ = vala_property_get_get_accessor (_tmp531_);
														_tmp533_ = _tmp532_;
														_tmp534_ = vala_property_accessor_get_value_type (_tmp533_);
														_tmp535_ = _tmp534_;
														_tmp536_ = vala_ccode_base_module_create_temp_value ((ValaCCodeBaseModule*) self, _tmp535_, FALSE, (ValaCodeNode*) expr, NULL);
														temp_value = G_TYPE_CHECK_INSTANCE_CAST (_tmp536_, VALA_TYPE_GLIB_VALUE, ValaGLibValue);
														_tmp537_ = temp_value;
														_tmp538_ = vala_ccode_base_module_load_temp_value ((ValaCCodeBaseModule*) self, (ValaTargetValue*) _tmp537_);
														_tmp539_ = _tmp538_;
														vala_expression_set_target_value ((ValaExpression*) expr, _tmp539_);
														_vala_target_value_unref0 (_tmp539_);
														_tmp540_ = temp_value;
														_tmp541_ = vala_get_cvalue_ ((ValaTargetValue*) _tmp540_);
														_tmp542_ = _vala_ccode_node_ref0 (_tmp541_);
														ctemp = _tmp542_;
														_tmp543_ = ccall;
														_tmp544_ = ctemp;
														_tmp545_ = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, _tmp544_);
														_tmp546_ = _tmp545_;
														vala_ccode_function_call_add_argument (_tmp543_, (ValaCCodeExpression*) _tmp546_);
														_vala_ccode_node_unref0 (_tmp546_);
														_tmp547_ = vala_ccode_base_module_get_ccode ((ValaCCodeBaseModule*) self);
														_tmp548_ = _tmp547_;
														_tmp549_ = ccall;
														vala_ccode_function_add_expression (_tmp548_, (ValaCCodeExpression*) _tmp549_);
														_vala_ccode_node_unref0 (ctemp);
														_vala_target_value_unref0 (temp_value);
													} else {
														ValaCCodeFunctionCall* _tmp550_;
														_tmp550_ = ccall;
														vala_set_cvalue ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp550_);
													}
													_vala_ccode_node_unref0 (ccall);
												} else {
													ValaSourceReference* _tmp551_;
													ValaSourceReference* _tmp552_;
													ValaProperty* _tmp553_;
													gchar* _tmp554_;
													gchar* _tmp555_;
													_tmp551_ = vala_code_node_get_source_reference ((ValaCodeNode*) expr);
													_tmp552_ = _tmp551_;
													_tmp553_ = base_prop;
													_tmp554_ = vala_symbol_get_full_name ((ValaSymbol*) _tmp553_);
													_tmp555_ = _tmp554_;
													vala_report_error (_tmp552_, "internal: Invalid access to `%s'", _tmp555_);
													_g_free0 (_tmp555_);
												}
												_vala_ccode_node_unref0 (vcast);
											} else {
												gboolean _tmp556_ = FALSE;
												gboolean _tmp557_ = FALSE;
												gboolean _tmp558_ = FALSE;
												gboolean _tmp559_ = FALSE;
												gboolean _tmp560_ = FALSE;
												gboolean _tmp561_ = FALSE;
												gboolean _tmp562_ = FALSE;
												ValaProperty* _tmp563_;
												ValaMemberBinding _tmp564_;
												ValaMemberBinding _tmp565_;
												_tmp563_ = prop;
												_tmp564_ = vala_property_get_binding (_tmp563_);
												_tmp565_ = _tmp564_;
												if (_tmp565_ == VALA_MEMBER_BINDING_INSTANCE) {
													ValaProperty* _tmp566_;
													ValaPropertyAccessor* _tmp567_;
													ValaPropertyAccessor* _tmp568_;
													gboolean _tmp569_;
													gboolean _tmp570_;
													_tmp566_ = prop;
													_tmp567_ = vala_property_get_get_accessor (_tmp566_);
													_tmp568_ = _tmp567_;
													_tmp569_ = vala_property_accessor_get_automatic_body (_tmp568_);
													_tmp570_ = _tmp569_;
													_tmp562_ = _tmp570_;
												} else {
													_tmp562_ = FALSE;
												}
												if (_tmp562_) {
													ValaProperty* _tmp571_;
													ValaPropertyAccessor* _tmp572_;
													ValaPropertyAccessor* _tmp573_;
													ValaDataType* _tmp574_;
													ValaDataType* _tmp575_;
													gboolean _tmp576_;
													gboolean _tmp577_;
													_tmp571_ = prop;
													_tmp572_ = vala_property_get_get_accessor (_tmp571_);
													_tmp573_ = _tmp572_;
													_tmp574_ = vala_property_accessor_get_value_type (_tmp573_);
													_tmp575_ = _tmp574_;
													_tmp576_ = vala_data_type_get_value_owned (_tmp575_);
													_tmp577_ = _tmp576_;
													_tmp561_ = !_tmp577_;
												} else {
													_tmp561_ = FALSE;
												}
												if (_tmp561_) {
													ValaTypeSymbol* _tmp578_;
													ValaTypeSymbol* _tmp579_;
													ValaProperty* _tmp580_;
													ValaSymbol* _tmp581_;
													ValaSymbol* _tmp582_;
													_tmp578_ = vala_ccode_base_module_get_current_type_symbol ((ValaCCodeBaseModule*) self);
													_tmp579_ = _tmp578_;
													_tmp580_ = prop;
													_tmp581_ = vala_symbol_get_parent_symbol ((ValaSymbol*) _tmp580_);
													_tmp582_ = _tmp581_;
													_tmp560_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp579_, VALA_TYPE_SYMBOL, ValaSymbol) == _tmp582_;
												} else {
													_tmp560_ = FALSE;
												}
												if (_tmp560_) {
													ValaTypeSymbol* _tmp583_;
													ValaTypeSymbol* _tmp584_;
													_tmp583_ = vala_ccode_base_module_get_current_type_symbol ((ValaCCodeBaseModule*) self);
													_tmp584_ = _tmp583_;
													_tmp559_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp584_, VALA_TYPE_CLASS);
												} else {
													_tmp559_ = FALSE;
												}
												if (_tmp559_) {
													ValaProperty* _tmp585_;
													ValaProperty* _tmp586_;
													ValaProperty* _tmp587_;
													_tmp585_ = prop;
													_tmp586_ = vala_property_get_base_property (_tmp585_);
													_tmp587_ = _tmp586_;
													_tmp558_ = _tmp587_ == NULL;
												} else {
													_tmp558_ = FALSE;
												}
												if (_tmp558_) {
													ValaProperty* _tmp588_;
													ValaProperty* _tmp589_;
													ValaProperty* _tmp590_;
													_tmp588_ = prop;
													_tmp589_ = vala_property_get_base_interface_property (_tmp588_);
													_tmp590_ = _tmp589_;
													_tmp557_ = _tmp590_ == NULL;
												} else {
													_tmp557_ = FALSE;
												}
												if (_tmp557_) {
													gboolean _tmp591_ = FALSE;
													ValaProperty* _tmp592_;
													ValaDataType* _tmp593_;
													ValaDataType* _tmp594_;
													_tmp592_ = prop;
													_tmp593_ = vala_property_get_property_type (_tmp592_);
													_tmp594_ = _tmp593_;
													if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp594_, VALA_TYPE_ARRAY_TYPE)) {
														_tmp591_ = TRUE;
													} else {
														ValaProperty* _tmp595_;
														ValaDataType* _tmp596_;
														ValaDataType* _tmp597_;
														_tmp595_ = prop;
														_tmp596_ = vala_property_get_property_type (_tmp595_);
														_tmp597_ = _tmp596_;
														_tmp591_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp597_, VALA_TYPE_DELEGATE_TYPE);
													}
													_tmp556_ = !_tmp591_;
												} else {
													_tmp556_ = FALSE;
												}
												if (_tmp556_) {
													ValaCCodeExpression* inst = NULL;
													ValaCCodeExpression* _tmp598_;
													ValaCCodeExpression* _tmp599_;
													ValaTypeSymbol* _tmp600_;
													ValaTypeSymbol* _tmp601_;
													gboolean _tmp602_;
													gboolean _tmp603_;
													ValaCCodeExpression* _tmp606_;
													ValaProperty* _tmp607_;
													ValaField* _tmp608_;
													ValaField* _tmp609_;
													gchar* _tmp610_;
													gchar* _tmp611_;
													ValaCCodeMemberAccess* _tmp612_;
													ValaCCodeMemberAccess* _tmp613_;
													_tmp598_ = pub_inst;
													_tmp599_ = _vala_ccode_node_ref0 (_tmp598_);
													inst = _tmp599_;
													_tmp600_ = vala_ccode_base_module_get_current_type_symbol ((ValaCCodeBaseModule*) self);
													_tmp601_ = _tmp600_;
													_tmp602_ = vala_class_get_is_compact (G_TYPE_CHECK_INSTANCE_CAST (_tmp601_, VALA_TYPE_CLASS, ValaClass));
													_tmp603_ = _tmp602_;
													if (!_tmp603_) {
														ValaCCodeExpression* _tmp604_;
														ValaCCodeMemberAccess* _tmp605_;
														_tmp604_ = inst;
														_tmp605_ = vala_ccode_member_access_new_pointer (_tmp604_, "priv");
														_vala_ccode_node_unref0 (inst);
														inst = (ValaCCodeExpression*) _tmp605_;
													}
													_tmp606_ = inst;
													_tmp607_ = prop;
													_tmp608_ = vala_property_get_field (_tmp607_);
													_tmp609_ = _tmp608_;
													_tmp610_ = vala_get_ccode_name ((ValaCodeNode*) _tmp609_);
													_tmp611_ = _tmp610_;
													_tmp612_ = vala_ccode_member_access_new_pointer (_tmp606_, _tmp611_);
													_tmp613_ = _tmp612_;
													vala_set_cvalue ((ValaExpression*) expr, (ValaCCodeExpression*) _tmp613_);
													_vala_ccode_node_unref0 (_tmp613_);
													_g_free0 (_tmp611_);
													_vala_ccode_node_unref0 (inst);
												} else {
													gboolean _tmp614_ = FALSE;
													ValaProperty* _tmp615_;
													_tmp615_ = prop;
													if (!vala_get_ccode_no_accessor_method (_tmp615_)) {
														ValaProperty* _tmp616_;
														_tmp616_ = prop;
														_tmp614_ = !G_TYPE_CHECK_INSTANCE_TYPE (_tmp616_, VALA_TYPE_DYNAMIC_PROPERTY);
													} else {
														_tmp614_ = FALSE;
													}
													if (_tmp614_) {
														ValaCCodeFunctionCall* ccall = NULL;
														ValaProperty* _tmp617_;
														ValaPropertyAccessor* _tmp618_;
														ValaPropertyAccessor* _tmp619_;
														gchar* _tmp620_;
														gchar* _tmp621_;
														ValaCCodeIdentifier* _tmp622_;
														ValaCCodeIdentifier* _tmp623_;
														ValaCCodeFunctionCall* _tmp624_;
														ValaCCodeFunctionCall* _tmp625_;
														ValaProperty* _tmp626_;
														ValaMemberBinding _tmp627_;
														ValaMemberBinding _tmp628_;
														gboolean prop_is_real_non_null_struct_type = FALSE;
														ValaProperty* _tmp649_;
														ValaDataType* _tmp650_;
														ValaDataType* _tmp651_;
														gboolean _tmp652_ = FALSE;
														ValaProperty* _tmp653_;
														ValaDataType* _tmp654_;
														ValaDataType* _tmp655_;
														gboolean requires_init = FALSE;
														ValaGLibValue* temp_value = NULL;
														ValaProperty* _tmp656_;
														ValaPropertyAccessor* _tmp657_;
														ValaPropertyAccessor* _tmp658_;
														ValaDataType* _tmp659_;
														ValaDataType* _tmp660_;
														ValaTargetValue* _tmp661_;
														ValaGLibValue* _tmp662_;
														ValaTargetValue* _tmp663_;
														ValaTargetValue* _tmp664_;
														ValaCCodeExpression* ctemp = NULL;
														ValaGLibValue* _tmp665_;
														ValaCCodeExpression* _tmp666_;
														ValaCCodeExpression* _tmp667_;
														_tmp617_ = prop;
														_tmp618_ = vala_property_get_get_accessor (_tmp617_);
														_tmp619_ = _tmp618_;
														_tmp620_ = vala_get_ccode_name ((ValaCodeNode*) _tmp619_);
														_tmp621_ = _tmp620_;
														_tmp622_ = vala_ccode_identifier_new (_tmp621_);
														_tmp623_ = _tmp622_;
														_tmp624_ = vala_ccode_function_call_new ((ValaCCodeExpression*) _tmp623_);
														_tmp625_ = _tmp624_;
														_vala_ccode_node_unref0 (_tmp623_);
														_g_free0 (_tmp621_);
														ccall = _tmp625_;
														_tmp626_ = prop;
														_tmp627_ = vala_property_get_binding (_tmp626_);
														_tmp628_ = _tmp627_;
														if (_tmp628_ == VALA_MEMBER_BINDING_INSTANCE) {
															gboolean _tmp629_ = FALSE;
															ValaProperty* _tmp630_;
															ValaSymbol* _tmp631_;
															ValaSymbol* _tmp632_;
															ValaCCodeFunctionCall* _tmp647_;
															ValaCCodeExpression* _tmp648_;
															_tmp630_ = prop;
															_tmp631_ = vala_symbol_get_parent_symbol ((ValaSymbol*) _tmp630_);
															_tmp632_ = _tmp631_;
															if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp632_, VALA_TYPE_STRUCT)) {
																ValaProperty* _tmp633_;
																ValaSymbol* _tmp634_;
																ValaSymbol* _tmp635_;
																_tmp633_ = prop;
																_tmp634_ = vala_symbol_get_parent_symbol ((ValaSymbol*) _tmp633_);
																_tmp635_ = _tmp634_;
																_tmp629_ = !vala_struct_is_simple_type (G_TYPE_CHECK_INSTANCE_CAST (_tmp635_, VALA_TYPE_STRUCT, ValaStruct));
															} else {
																_tmp629_ = FALSE;
															}
															if (_tmp629_) {
																ValaTargetValue* instance = NULL;
																ValaExpression* _tmp636_;
																ValaExpression* _tmp637_;
																ValaTargetValue* _tmp638_;
																ValaTargetValue* _tmp639_;
																ValaTargetValue* _tmp640_;
																ValaTargetValue* _tmp641_;
																ValaTargetValue* _tmp644_;
																ValaCCodeExpression* _tmp645_;
																ValaCCodeUnaryExpression* _tmp646_;
																_tmp636_ = vala_member_access_get_inner (expr);
																_tmp637_ = _tmp636_;
																_tmp638_ = vala_expression_get_target_value (_tmp637_);
																_tmp639_ = _tmp638_;
																_tmp640_ = _vala_target_value_ref0 (_tmp639_);
																instance = _tmp640_;
																_tmp641_ = instance;
																if (!vala_get_lvalue (_tmp641_)) {
																	ValaTargetValue* _tmp642_;
																	ValaTargetValue* _tmp643_;
																	_tmp642_ = instance;
																	_tmp643_ = vala_ccode_base_module_store_temp_value ((ValaCCodeBaseModule*) self, _tmp642_, (ValaCodeNode*) expr, NULL);
																	_vala_target_value_unref0 (instance);
																	instance = _tmp643_;
																}
																_tmp644_ = instance;
																_tmp645_ = vala_get_cvalue_ (_tmp644_);
																_tmp646_ = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, _tmp645_);
																_vala_ccode_node_unref0 (pub_inst);
																pub_inst = (ValaCCodeExpression*) _tmp646_;
																_vala_target_value_unref0 (instance);
															}
															_tmp647_ = ccall;
															_tmp648_ = pub_inst;
															vala_ccode_function_call_add_argument (_tmp647_, _tmp648_);
														}
														_tmp649_ = prop;
														_tmp650_ = vala_property_get_property_type (_tmp649_);
														_tmp651_ = _tmp650_;
														prop_is_real_non_null_struct_type = vala_data_type_is_real_non_null_struct_type (_tmp651_);
														_tmp653_ = prop;
														_tmp654_ = vala_property_get_property_type (_tmp653_);
														_tmp655_ = _tmp654_;
														if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp655_, VALA_TYPE_DELEGATE_TYPE)) {
															_tmp652_ = TRUE;
														} else {
															_tmp652_ = prop_is_real_non_null_struct_type;
														}
														requires_init = _tmp652_;
														_tmp656_ = prop;
														_tmp657_ = vala_property_get_get_accessor (_tmp656_);
														_tmp658_ = _tmp657_;
														_tmp659_ = vala_property_accessor_get_value_type (_tmp658_);
														_tmp660_ = _tmp659_;
														_tmp661_ = vala_ccode_base_module_create_temp_value ((ValaCCodeBaseModule*) self, _tmp660_, requires_init, (ValaCodeNode*) expr, NULL);
														temp_value = G_TYPE_CHECK_INSTANCE_CAST (_tmp661_, VALA_TYPE_GLIB_VALUE, ValaGLibValue);
														_tmp662_ = temp_value;
														_tmp663_ = vala_ccode_base_module_load_temp_value ((ValaCCodeBaseModule*) self, (ValaTargetValue*) _tmp662_);
														_tmp664_ = _tmp663_;
														vala_expression_set_target_value ((ValaExpression*) expr, _tmp664_);
														_vala_target_value_unref0 (_tmp664_);
														_tmp665_ = temp_value;
														_tmp666_ = vala_get_cvalue_ ((ValaTargetValue*) _tmp665_);
														_tmp667_ = _vala_ccode_node_ref0 (_tmp666_);
														ctemp = _tmp667_;
														if (prop_is_real_non_null_struct_type) {
															ValaCCodeFunctionCall* _tmp668_;
															ValaCCodeExpression* _tmp669_;
															ValaCCodeUnaryExpression* _tmp670_;
															ValaCCodeUnaryExpression* _tmp671_;
															ValaCCodeFunction* _tmp672_;
															ValaCCodeFunction* _tmp673_;
															ValaCCodeFunctionCall* _tmp674_;
															_tmp668_ = ccall;
															_tmp669_ = ctemp;
															_tmp670_ = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, _tmp669_);
															_tmp671_ = _tmp670_;
															vala_ccode_function_call_add_argument (_tmp668_, (ValaCCodeExpression*) _tmp671_);
															_vala_ccode_node_unref0 (_tmp671_);
															_tmp672_ = vala_ccode_base_module_get_ccode ((ValaCCodeBaseModule*) self);
															_tmp673_ = _tmp672_;
															_tmp674_ = ccall;
															vala_ccode_function_add_expression (_tmp673_, (ValaCCodeExpression*) _tmp674_);
														} else {
															ValaProperty* _tmp675_;
															ValaDataType* _tmp676_;
															ValaDataType* _tmp677_;
															ValaArrayType* _tmp678_;
															ValaArrayType* _tmp679_;
															_tmp675_ = prop;
															_tmp676_ = vala_property_get_property_type (_tmp675_);
															_tmp677_ = _tmp676_;
															_tmp678_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp677_, VALA_TYPE_ARRAY_TYPE) ? ((ValaArrayType*) _tmp677_) : NULL);
															_vala_code_node_unref0 (array_type);
															array_type = _tmp678_;
															_tmp679_ = array_type;
															if (_tmp679_ != NULL) {
																ValaProperty* _tmp680_;
																_tmp680_ = prop;
																if (vala_get_ccode_array_null_terminated ((ValaCodeNode*) _tmp680_)) {
																	ValaCCodeFunctionCall* len_call = NULL;
																	ValaCCodeIdentifier* _tmp681_;
																	ValaCCodeIdentifier* _tmp682_;
																	ValaCCodeFunctionCall* _tmp683_;
																	ValaCCodeFunctionCall* _tmp684_;
																	ValaCCodeFunctionCall* _tmp685_;
																	ValaCCodeExpression* _tmp686_;
																	ValaCCodeFunction* _tmp687_;
																	ValaCCodeFunction* _tmp688_;
																	ValaCCodeExpression* _tmp689_;
																	ValaCCodeFunctionCall* _tmp690_;
																	ValaCCodeFunction* _tmp691_;
																	ValaCCodeFunction* _tmp692_;
																	ValaGLibValue* _tmp693_;
																	ValaList* _tmp694_;
																	gpointer _tmp695_;
																	ValaCCodeExpression* _tmp696_;
																	ValaCCodeFunctionCall* _tmp697_;
																	((ValaCCodeBaseModule*) self)->requires_array_length = TRUE;
																	_tmp681_ = vala_ccode_identifier_new ("_vala_array_length");
																	_tmp682_ = _tmp681_;
																	_tmp683_ = vala_ccode_function_call_new ((ValaCCodeExpression*) _tmp682_);
																	_tmp684_ = _tmp683_;
																	_vala_ccode_node_unref0 (_tmp682_);
																	len_call = _tmp684_;
																	_tmp685_ = len_call;
																	_tmp686_ = ctemp;
																	vala_ccode_function_call_add_argument (_tmp685_, _tmp686_);
																	_tmp687_ = vala_ccode_base_module_get_ccode ((ValaCCodeBaseModule*) self);
																	_tmp688_ = _tmp687_;
																	_tmp689_ = ctemp;
																	_tmp690_ = ccall;
																	vala_ccode_function_add_assignment (_tmp688_, _tmp689_, (ValaCCodeExpression*) _tmp690_);
																	_tmp691_ = vala_ccode_base_module_get_ccode ((ValaCCodeBaseModule*) self);
																	_tmp692_ = _tmp691_;
																	_tmp693_ = temp_value;
																	_tmp694_ = _tmp693_->array_length_cvalues;
																	_tmp695_ = vala_list_get (_tmp694_, 0);
																	_tmp696_ = (ValaCCodeExpression*) _tmp695_;
																	_tmp697_ = len_call;
																	vala_ccode_function_add_assignment (_tmp692_, _tmp696_, (ValaCCodeExpression*) _tmp697_);
																	_vala_ccode_node_unref0 (_tmp696_);
																	_vala_ccode_node_unref0 (len_call);
																} else {
																	ValaProperty* _tmp698_;
																	_tmp698_ = prop;
																	if (vala_get_ccode_array_length ((ValaCodeNode*) _tmp698_)) {
																		ValaArrayList* temp_refs = NULL;
																		GEqualFunc _tmp699_;
																		ValaArrayList* _tmp700_;
																		ValaCCodeFunction* _tmp724_;
																		ValaCCodeFunction* _tmp725_;
																		ValaCCodeExpression* _tmp726_;
																		ValaCCodeFunctionCall* _tmp727_;
																		_tmp699_ = g_direct_equal;
																		_tmp700_ = vala_array_list_new (VALA_TYPE_CCODE_EXPRESSION, (GBoxedCopyFunc) vala_ccode_node_ref, (GDestroyNotify) vala_ccode_node_unref, _tmp699_);
																		temp_refs = _tmp700_;
																		{
																			gint dim = 0;
																			dim = 1;
																			{
																				gboolean _tmp701_ = FALSE;
																				_tmp701_ = TRUE;
																				while (TRUE) {
																					ValaArrayType* _tmp703_;
																					gint _tmp704_;
																					gint _tmp705_;
																					gchar* length_ctype = NULL;
																					ValaProperty* _tmp706_;
																					gchar* _tmp707_;
																					ValaLocalVariable* temp_var = NULL;
																					const gchar* _tmp708_;
																					ValaCType* _tmp709_;
																					ValaCType* _tmp710_;
																					ValaLocalVariable* _tmp711_;
																					ValaLocalVariable* _tmp712_;
																					ValaCCodeExpression* temp_ref = NULL;
																					ValaLocalVariable* _tmp713_;
																					const gchar* _tmp714_;
																					const gchar* _tmp715_;
																					ValaCCodeExpression* _tmp716_;
																					ValaLocalVariable* _tmp717_;
																					ValaCCodeFunctionCall* _tmp718_;
																					ValaCCodeExpression* _tmp719_;
																					ValaCCodeUnaryExpression* _tmp720_;
																					ValaCCodeUnaryExpression* _tmp721_;
																					ValaArrayList* _tmp722_;
																					ValaCCodeExpression* _tmp723_;
																					if (!_tmp701_) {
																						gint _tmp702_;
																						_tmp702_ = dim;
																						dim = _tmp702_ + 1;
																					}
																					_tmp701_ = FALSE;
																					_tmp703_ = array_type;
																					_tmp704_ = vala_array_type_get_rank (_tmp703_);
																					_tmp705_ = _tmp704_;
																					if (!(dim <= _tmp705_)) {
																						break;
																					}
																					_tmp706_ = prop;
																					_tmp707_ = vala_get_ccode_array_length_type ((ValaCodeNode*) _tmp706_);
																					length_ctype = _tmp707_;
																					_tmp708_ = length_ctype;
																					_tmp709_ = vala_ctype_new (_tmp708_, "0");
																					_tmp710_ = _tmp709_;
																					_tmp711_ = vala_ccode_base_module_get_temp_variable ((ValaCCodeBaseModule*) self, (ValaDataType*) _tmp710_, TRUE, NULL, TRUE);
																					_tmp712_ = _tmp711_;
																					_vala_code_node_unref0 (_tmp710_);
																					temp_var = _tmp712_;
																					_tmp713_ = temp_var;
																					_tmp714_ = vala_symbol_get_name ((ValaSymbol*) _tmp713_);
																					_tmp715_ = _tmp714_;
																					_tmp716_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp715_);
																					temp_ref = _tmp716_;
																					_tmp717_ = temp_var;
																					vala_ccode_base_module_emit_temp_var ((ValaCCodeBaseModule*) self, _tmp717_, FALSE);
																					_tmp718_ = ccall;
																					_tmp719_ = temp_ref;
																					_tmp720_ = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, _tmp719_);
																					_tmp721_ = _tmp720_;
																					vala_ccode_function_call_add_argument (_tmp718_, (ValaCCodeExpression*) _tmp721_);
																					_vala_ccode_node_unref0 (_tmp721_);
																					_tmp722_ = temp_refs;
																					_tmp723_ = temp_ref;
																					vala_collection_add ((ValaCollection*) _tmp722_, _tmp723_);
																					_vala_ccode_node_unref0 (temp_ref);
																					_vala_code_node_unref0 (temp_var);
																					_g_free0 (length_ctype);
																				}
																			}
																		}
																		_tmp724_ = vala_ccode_base_module_get_ccode ((ValaCCodeBaseModule*) self);
																		_tmp725_ = _tmp724_;
																		_tmp726_ = ctemp;
																		_tmp727_ = ccall;
																		vala_ccode_function_add_assignment (_tmp725_, _tmp726_, (ValaCCodeExpression*) _tmp727_);
																		{
																			gint dim = 0;
																			dim = 1;
																			{
																				gboolean _tmp728_ = FALSE;
																				_tmp728_ = TRUE;
																				while (TRUE) {
																					ValaArrayType* _tmp730_;
																					gint _tmp731_;
																					gint _tmp732_;
																					ValaCCodeFunction* _tmp733_;
																					ValaCCodeFunction* _tmp734_;
																					ValaGLibValue* _tmp735_;
																					ValaList* _tmp736_;
																					gpointer _tmp737_;
																					ValaCCodeExpression* _tmp738_;
																					ValaArrayList* _tmp739_;
																					gpointer _tmp740_;
																					ValaCCodeExpression* _tmp741_;
																					if (!_tmp728_) {
																						gint _tmp729_;
																						_tmp729_ = dim;
																						dim = _tmp729_ + 1;
																					}
																					_tmp728_ = FALSE;
																					_tmp730_ = array_type;
																					_tmp731_ = vala_array_type_get_rank (_tmp730_);
																					_tmp732_ = _tmp731_;
																					if (!(dim <= _tmp732_)) {
																						break;
																					}
																					_tmp733_ = vala_ccode_base_module_get_ccode ((ValaCCodeBaseModule*) self);
																					_tmp734_ = _tmp733_;
																					_tmp735_ = temp_value;
																					_tmp736_ = _tmp735_->array_length_cvalues;
																					_tmp737_ = vala_list_get (_tmp736_, dim - 1);
																					_tmp738_ = (ValaCCodeExpression*) _tmp737_;
																					_tmp739_ = temp_refs;
																					_tmp740_ = vala_list_get ((ValaList*) _tmp739_, dim - 1);
																					_tmp741_ = (ValaCCodeExpression*) _tmp740_;
																					vala_ccode_function_add_assignment (_tmp734_, _tmp738_, _tmp741_);
																					_vala_ccode_node_unref0 (_tmp741_);
																					_vala_ccode_node_unref0 (_tmp738_);
																				}
																			}
																		}
																		_vala_iterable_unref0 (temp_refs);
																	} else {
																		ValaCCodeFunction* _tmp742_;
																		ValaCCodeFunction* _tmp743_;
																		ValaCCodeExpression* _tmp744_;
																		ValaCCodeFunctionCall* _tmp745_;
																		_tmp742_ = vala_ccode_base_module_get_ccode ((ValaCCodeBaseModule*) self);
																		_tmp743_ = _tmp742_;
																		_tmp744_ = ctemp;
																		_tmp745_ = ccall;
																		vala_ccode_function_add_assignment (_tmp743_, _tmp744_, (ValaCCodeExpression*) _tmp745_);
																	}
																}
															} else {
																ValaCCodeFunction* _tmp746_;
																ValaCCodeFunction* _tmp747_;
																ValaCCodeExpression* _tmp748_;
																ValaCCodeFunctionCall* _tmp749_;
																ValaProperty* _tmp750_;
																ValaDataType* _tmp751_;
																ValaDataType* _tmp752_;
																ValaDelegateType* _tmp753_;
																gboolean _tmp754_ = FALSE;
																gboolean _tmp755_ = FALSE;
																ValaDelegateType* _tmp756_;
																_tmp746_ = vala_ccode_base_module_get_ccode ((ValaCCodeBaseModule*) self);
																_tmp747_ = _tmp746_;
																_tmp748_ = ctemp;
																_tmp749_ = ccall;
																vala_ccode_function_add_assignment (_tmp747_, _tmp748_, (ValaCCodeExpression*) _tmp749_);
																_tmp750_ = prop;
																_tmp751_ = vala_property_get_property_type (_tmp750_);
																_tmp752_ = _tmp751_;
																_tmp753_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp752_, VALA_TYPE_DELEGATE_TYPE) ? ((ValaDelegateType*) _tmp752_) : NULL);
																_vala_code_node_unref0 (delegate_type);
																delegate_type = _tmp753_;
																_tmp756_ = delegate_type;
																if (_tmp756_ != NULL) {
																	ValaProperty* _tmp757_;
																	_tmp757_ = prop;
																	_tmp755_ = vala_get_ccode_delegate_target ((ValaCodeNode*) _tmp757_);
																} else {
																	_tmp755_ = FALSE;
																}
																if (_tmp755_) {
																	ValaDelegateType* _tmp758_;
																	ValaDelegate* _tmp759_;
																	ValaDelegate* _tmp760_;
																	gboolean _tmp761_;
																	gboolean _tmp762_;
																	_tmp758_ = delegate_type;
																	_tmp759_ = vala_delegate_type_get_delegate_symbol (_tmp758_);
																	_tmp760_ = _tmp759_;
																	_tmp761_ = vala_delegate_get_has_target (_tmp760_);
																	_tmp762_ = _tmp761_;
																	_tmp754_ = _tmp762_;
																} else {
																	_tmp754_ = FALSE;
																}
																if (_tmp754_) {
																	ValaCCodeFunctionCall* _tmp763_;
																	ValaGLibValue* _tmp764_;
																	ValaCCodeExpression* _tmp765_;
																	ValaCCodeExpression* _tmp766_;
																	ValaCCodeUnaryExpression* _tmp767_;
																	ValaCCodeUnaryExpression* _tmp768_;
																	_tmp763_ = ccall;
																	_tmp764_ = temp_value;
																	_tmp765_ = vala_ccode_base_module_get_delegate_target_cvalue ((ValaCCodeBaseModule*) self, (ValaTargetValue*) _tmp764_);
																	_tmp766_ = _tmp765_;
																	_tmp767_ = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, _tmp766_);
																	_tmp768_ = _tmp767_;
																	vala_ccode_function_call_add_argument (_tmp763_, (ValaCCodeExpression*) _tmp768_);
																	_vala_ccode_node_unref0 (_tmp768_);
																	_vala_ccode_node_unref0 (_tmp766_);
																} else {
																	ValaGLibValue* _tmp769_;
																	ValaCCodeExpression* _tmp770_;
																	ValaGLibValue* _tmp777_;
																	ValaCCodeExpression* _tmp778_;
																	_tmp769_ = temp_value;
																	_tmp770_ = _tmp769_->delegate_target_cvalue;
																	if (_tmp770_ != NULL) {
																		ValaCCodeFunction* _tmp771_;
																		ValaCCodeFunction* _tmp772_;
																		ValaGLibValue* _tmp773_;
																		ValaCCodeExpression* _tmp774_;
																		ValaCCodeConstant* _tmp775_;
																		ValaCCodeConstant* _tmp776_;
																		_tmp771_ = vala_ccode_base_module_get_ccode ((ValaCCodeBaseModule*) self);
																		_tmp772_ = _tmp771_;
																		_tmp773_ = temp_value;
																		_tmp774_ = _tmp773_->delegate_target_cvalue;
																		_tmp775_ = vala_ccode_constant_new ("NULL");
																		_tmp776_ = _tmp775_;
																		vala_ccode_function_add_assignment (_tmp772_, _tmp774_, (ValaCCodeExpression*) _tmp776_);
																		_vala_ccode_node_unref0 (_tmp776_);
																	}
																	_tmp777_ = temp_value;
																	_tmp778_ = _tmp777_->delegate_target_destroy_notify_cvalue;
																	if (_tmp778_ != NULL) {
																		ValaCCodeFunction* _tmp779_;
																		ValaCCodeFunction* _tmp780_;
																		ValaGLibValue* _tmp781_;
																		ValaCCodeExpression* _tmp782_;
																		ValaCCodeConstant* _tmp783_;
																		ValaCCodeConstant* _tmp784_;
																		_tmp779_ = vala_ccode_base_module_get_ccode ((ValaCCodeBaseModule*) self);
																		_tmp780_ = _tmp779_;
																		_tmp781_ = temp_value;
																		_tmp782_ = _tmp781_->delegate_target_destroy_notify_cvalue;
																		_tmp783_ = vala_ccode_constant_new ("NULL");
																		_tmp784_ = _tmp783_;
																		vala_ccode_function_add_assignment (_tmp780_, _tmp782_, (ValaCCodeExpression*) _tmp784_);
																		_vala_ccode_node_unref0 (_tmp784_);
																	}
																}
															}
														}
														_vala_ccode_node_unref0 (ctemp);
														_vala_target_value_unref0 (temp_value);
														_vala_ccode_node_unref0 (ccall);
													} else {
														ValaCCodeFunctionCall* ccall = NULL;
														ValaCCodeIdentifier* _tmp785_;
														ValaCCodeIdentifier* _tmp786_;
														ValaCCodeFunctionCall* _tmp787_;
														ValaCCodeFunctionCall* _tmp788_;
														ValaCCodeFunctionCall* _tmp789_;
														ValaCCodeExpression* _tmp790_;
														ValaCCodeFunctionCall* _tmp791_;
														ValaProperty* _tmp792_;
														ValaCCodeConstant* _tmp793_;
														ValaCCodeConstant* _tmp794_;
														gboolean _tmp795_ = FALSE;
														ValaProperty* _tmp796_;
														ValaDataType* _tmp820_;
														ValaDataType* _tmp821_;
														ValaLocalVariable* temp_var = NULL;
														ValaDataType* _tmp824_;
														ValaDataType* _tmp825_;
														ValaLocalVariable* _tmp826_;
														ValaCCodeExpression* ctemp = NULL;
														ValaLocalVariable* _tmp827_;
														const gchar* _tmp828_;
														const gchar* _tmp829_;
														ValaCCodeExpression* _tmp830_;
														ValaLocalVariable* _tmp831_;
														ValaCCodeFunctionCall* _tmp832_;
														ValaCCodeExpression* _tmp833_;
														ValaCCodeUnaryExpression* _tmp834_;
														ValaCCodeUnaryExpression* _tmp835_;
														ValaCCodeFunctionCall* _tmp836_;
														ValaCCodeConstant* _tmp837_;
														ValaCCodeConstant* _tmp838_;
														ValaCCodeFunction* _tmp839_;
														ValaCCodeFunction* _tmp840_;
														ValaCCodeFunctionCall* _tmp841_;
														ValaCCodeExpression* _tmp842_;
														ValaProperty* _tmp843_;
														_tmp785_ = vala_ccode_identifier_new ("g_object_get");
														_tmp786_ = _tmp785_;
														_tmp787_ = vala_ccode_function_call_new ((ValaCCodeExpression*) _tmp786_);
														_tmp788_ = _tmp787_;
														_vala_ccode_node_unref0 (_tmp786_);
														ccall = _tmp788_;
														_tmp789_ = ccall;
														_tmp790_ = pub_inst;
														vala_ccode_function_call_add_argument (_tmp789_, _tmp790_);
														_tmp791_ = ccall;
														_tmp792_ = prop;
														_tmp793_ = vala_ccode_base_module_get_property_canonical_cconstant ((ValaCCodeBaseModule*) self, _tmp792_);
														_tmp794_ = _tmp793_;
														vala_ccode_function_call_add_argument (_tmp791_, (ValaCCodeExpression*) _tmp794_);
														_vala_ccode_node_unref0 (_tmp794_);
														_tmp796_ = prop;
														if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp796_, VALA_TYPE_DYNAMIC_PROPERTY)) {
															ValaProperty* _tmp797_;
															ValaPropertyAccessor* _tmp798_;
															ValaPropertyAccessor* _tmp799_;
															ValaDataType* _tmp800_;
															ValaDataType* _tmp801_;
															gboolean _tmp802_;
															gboolean _tmp803_;
															_tmp797_ = prop;
															_tmp798_ = vala_property_get_get_accessor (_tmp797_);
															_tmp799_ = _tmp798_;
															_tmp800_ = vala_property_accessor_get_value_type (_tmp799_);
															_tmp801_ = _tmp800_;
															_tmp802_ = vala_data_type_get_value_owned (_tmp801_);
															_tmp803_ = _tmp802_;
															_tmp795_ = !_tmp803_;
														} else {
															_tmp795_ = FALSE;
														}
														if (_tmp795_) {
															ValaDataType* owned_value_type = NULL;
															ValaProperty* _tmp804_;
															ValaPropertyAccessor* _tmp805_;
															ValaPropertyAccessor* _tmp806_;
															ValaDataType* _tmp807_;
															ValaDataType* _tmp808_;
															ValaDataType* _tmp809_;
															ValaDataType* _tmp810_;
															ValaDataType* _tmp811_;
															_tmp804_ = prop;
															_tmp805_ = vala_property_get_get_accessor (_tmp804_);
															_tmp806_ = _tmp805_;
															_tmp807_ = vala_property_accessor_get_value_type (_tmp806_);
															_tmp808_ = _tmp807_;
															_tmp809_ = vala_data_type_copy (_tmp808_);
															owned_value_type = _tmp809_;
															_tmp810_ = owned_value_type;
															vala_data_type_set_value_owned (_tmp810_, TRUE);
															_tmp811_ = owned_value_type;
															if (vala_ccode_base_module_requires_copy (_tmp811_)) {
																ValaProperty* _tmp812_;
																ValaPropertyAccessor* _tmp813_;
																ValaPropertyAccessor* _tmp814_;
																ValaSourceReference* _tmp815_;
																ValaSourceReference* _tmp816_;
																ValaProperty* _tmp817_;
																gchar* _tmp818_;
																gchar* _tmp819_;
																_tmp812_ = prop;
																_tmp813_ = vala_property_get_get_accessor (_tmp812_);
																_tmp814_ = _tmp813_;
																_tmp815_ = vala_code_node_get_source_reference ((ValaCodeNode*) _tmp814_);
																_tmp816_ = _tmp815_;
																_tmp817_ = prop;
																_tmp818_ = vala_symbol_get_full_name ((ValaSymbol*) _tmp817_);
																_tmp819_ = _tmp818_;
																vala_report_error (_tmp816_, "unowned return value for getter of property `%s' not supported without" \
" accessor", _tmp819_);
																_g_free0 (_tmp819_);
															}
															_vala_code_node_unref0 (owned_value_type);
														}
														_tmp820_ = vala_expression_get_value_type ((ValaExpression*) expr);
														_tmp821_ = _tmp820_;
														if (vala_data_type_is_real_struct_type (_tmp821_)) {
															ValaDataType* _tmp822_;
															ValaDataType* _tmp823_;
															_tmp822_ = vala_expression_get_value_type ((ValaExpression*) expr);
															_tmp823_ = _tmp822_;
															vala_data_type_set_nullable (_tmp823_, TRUE);
														}
														_tmp824_ = vala_expression_get_value_type ((ValaExpression*) expr);
														_tmp825_ = _tmp824_;
														_tmp826_ = vala_ccode_base_module_get_temp_variable ((ValaCCodeBaseModule*) self, _tmp825_, TRUE, NULL, FALSE);
														temp_var = _tmp826_;
														_tmp827_ = temp_var;
														_tmp828_ = vala_symbol_get_name ((ValaSymbol*) _tmp827_);
														_tmp829_ = _tmp828_;
														_tmp830_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp829_);
														ctemp = _tmp830_;
														_tmp831_ = temp_var;
														vala_ccode_base_module_emit_temp_var ((ValaCCodeBaseModule*) self, _tmp831_, FALSE);
														_tmp832_ = ccall;
														_tmp833_ = ctemp;
														_tmp834_ = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, _tmp833_);
														_tmp835_ = _tmp834_;
														vala_ccode_function_call_add_argument (_tmp832_, (ValaCCodeExpression*) _tmp835_);
														_vala_ccode_node_unref0 (_tmp835_);
														_tmp836_ = ccall;
														_tmp837_ = vala_ccode_constant_new ("NULL");
														_tmp838_ = _tmp837_;
														vala_ccode_function_call_add_argument (_tmp836_, (ValaCCodeExpression*) _tmp838_);
														_vala_ccode_node_unref0 (_tmp838_);
														_tmp839_ = vala_ccode_base_module_get_ccode ((ValaCCodeBaseModule*) self);
														_tmp840_ = _tmp839_;
														_tmp841_ = ccall;
														vala_ccode_function_add_expression (_tmp840_, (ValaCCodeExpression*) _tmp841_);
														_tmp842_ = ctemp;
														vala_set_cvalue ((ValaExpression*) expr, _tmp842_);
														_tmp843_ = prop;
														if (vala_get_ccode_array_null_terminated ((ValaCodeNode*) _tmp843_)) {
															ValaCCodeFunctionCall* len_call = NULL;
															ValaCCodeIdentifier* _tmp844_;
															ValaCCodeIdentifier* _tmp845_;
															ValaCCodeFunctionCall* _tmp846_;
															ValaCCodeFunctionCall* _tmp847_;
															ValaCCodeFunctionCall* _tmp848_;
															ValaCCodeExpression* _tmp849_;
															ValaGLibValue* glib_value = NULL;
															ValaTargetValue* _tmp850_;
															ValaTargetValue* _tmp851_;
															ValaGLibValue* _tmp852_;
															ValaGLibValue* _tmp853_;
															ValaGLibValue* _tmp854_;
															ValaCCodeFunctionCall* _tmp855_;
															ValaGLibValue* _tmp856_;
															((ValaCCodeBaseModule*) self)->requires_array_length = TRUE;
															_tmp844_ = vala_ccode_identifier_new ("_vala_array_length");
															_tmp845_ = _tmp844_;
															_tmp846_ = vala_ccode_function_call_new ((ValaCCodeExpression*) _tmp845_);
															_tmp847_ = _tmp846_;
															_vala_ccode_node_unref0 (_tmp845_);
															len_call = _tmp847_;
															_tmp848_ = len_call;
															_tmp849_ = ctemp;
															vala_ccode_function_call_add_argument (_tmp848_, _tmp849_);
															_tmp850_ = vala_expression_get_target_value ((ValaExpression*) expr);
															_tmp851_ = _tmp850_;
															_tmp852_ = _vala_target_value_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp851_, VALA_TYPE_GLIB_VALUE, ValaGLibValue));
															glib_value = _tmp852_;
															_tmp853_ = glib_value;
															_vala_iterable_unref0 (_tmp853_->array_length_cvalues);
															_tmp853_->array_length_cvalues = NULL;
															_tmp854_ = glib_value;
															_tmp855_ = len_call;
															vala_glib_value_append_array_length_cvalue (_tmp854_, (ValaCCodeExpression*) _tmp855_);
															_tmp856_ = glib_value;
															_tmp856_->lvalue = FALSE;
															_vala_target_value_unref0 (glib_value);
															_vala_ccode_node_unref0 (len_call);
														}
														_vala_ccode_node_unref0 (ctemp);
														_vala_code_node_unref0 (temp_var);
														_vala_ccode_node_unref0 (ccall);
													}
												}
											}
											_tmp857_ = prop;
											_tmp858_ = vala_property_get_get_accessor (_tmp857_);
											_tmp859_ = _tmp858_;
											_tmp860_ = vala_property_accessor_get_value_type (_tmp859_);
											_tmp861_ = _tmp860_;
											if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp861_, VALA_TYPE_GENERIC_TYPE)) {
												ValaTargetValue* _tmp862_;
												ValaTargetValue* _tmp863_;
												ValaProperty* _tmp864_;
												ValaPropertyAccessor* _tmp865_;
												ValaPropertyAccessor* _tmp866_;
												ValaDataType* _tmp867_;
												ValaDataType* _tmp868_;
												ValaDataType* _tmp869_;
												ValaDataType* _tmp870_;
												_tmp862_ = vala_expression_get_target_value ((ValaExpression*) expr);
												_tmp863_ = _tmp862_;
												_tmp864_ = prop;
												_tmp865_ = vala_property_get_get_accessor (_tmp864_);
												_tmp866_ = _tmp865_;
												_tmp867_ = vala_property_accessor_get_value_type (_tmp866_);
												_tmp868_ = _tmp867_;
												_tmp869_ = vala_data_type_copy (_tmp868_);
												_tmp870_ = _tmp869_;
												vala_target_value_set_value_type (_tmp863_, _tmp870_);
												_vala_code_node_unref0 (_tmp870_);
											} else {
												ValaTargetValue* _tmp871_;
												ValaTargetValue* _tmp872_;
												ValaDataType* _tmp873_;
												ValaDataType* _tmp874_;
												ValaDataType* _tmp875_;
												ValaDataType* _tmp876_;
												_tmp871_ = vala_expression_get_target_value ((ValaExpression*) expr);
												_tmp872_ = _tmp871_;
												_tmp873_ = vala_expression_get_value_type ((ValaExpression*) expr);
												_tmp874_ = _tmp873_;
												_tmp875_ = vala_data_type_copy (_tmp874_);
												_tmp876_ = _tmp875_;
												vala_target_value_set_value_type (_tmp872_, _tmp876_);
												_vala_code_node_unref0 (_tmp876_);
											}
											_tmp877_ = vala_expression_get_target_value ((ValaExpression*) expr);
											_tmp878_ = _tmp877_;
											_tmp879_ = vala_ccode_base_module_store_temp_value ((ValaCCodeBaseModule*) self, _tmp878_, (ValaCodeNode*) expr, NULL);
											_tmp880_ = _tmp879_;
											vala_expression_set_target_value ((ValaExpression*) expr, _tmp880_);
											_vala_target_value_unref0 (_tmp880_);
											_vala_code_node_unref0 (prop);
										} else {
											ValaSymbol* _tmp881_;
											ValaSymbol* _tmp882_;
											_tmp881_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
											_tmp882_ = _tmp881_;
											if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp882_, VALA_TYPE_LOCAL_VARIABLE)) {
												ValaLocalVariable* local = NULL;
												ValaSymbol* _tmp883_;
												ValaSymbol* _tmp884_;
												ValaLocalVariable* _tmp885_;
												gboolean _tmp886_ = FALSE;
												gboolean _tmp887_ = FALSE;
												gboolean _tmp888_ = FALSE;
												gboolean _tmp889_ = FALSE;
												gboolean _tmp890_ = FALSE;
												ValaCodeNode* _tmp891_;
												ValaCodeNode* _tmp892_;
												_tmp883_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
												_tmp884_ = _tmp883_;
												_tmp885_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp884_, VALA_TYPE_LOCAL_VARIABLE, ValaLocalVariable));
												local = _tmp885_;
												_tmp891_ = vala_code_node_get_parent_node ((ValaCodeNode*) expr);
												_tmp892_ = _tmp891_;
												if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp892_, VALA_TYPE_RETURN_STATEMENT)) {
													ValaDataType* _tmp893_;
													ValaDataType* _tmp894_;
													gboolean _tmp895_;
													gboolean _tmp896_;
													_tmp893_ = vala_ccode_base_module_get_current_return_type ((ValaCCodeBaseModule*) self);
													_tmp894_ = _tmp893_;
													_tmp895_ = vala_data_type_get_value_owned (_tmp894_);
													_tmp896_ = _tmp895_;
													_tmp890_ = _tmp896_;
												} else {
													_tmp890_ = FALSE;
												}
												if (_tmp890_) {
													ValaLocalVariable* _tmp897_;
													ValaDataType* _tmp898_;
													ValaDataType* _tmp899_;
													gboolean _tmp900_;
													gboolean _tmp901_;
													_tmp897_ = local;
													_tmp898_ = vala_variable_get_variable_type ((ValaVariable*) _tmp897_);
													_tmp899_ = _tmp898_;
													_tmp900_ = vala_data_type_get_value_owned (_tmp899_);
													_tmp901_ = _tmp900_;
													_tmp889_ = _tmp901_;
												} else {
													_tmp889_ = FALSE;
												}
												if (_tmp889_) {
													ValaLocalVariable* _tmp902_;
													gboolean _tmp903_;
													gboolean _tmp904_;
													_tmp902_ = local;
													_tmp903_ = vala_local_variable_get_captured (_tmp902_);
													_tmp904_ = _tmp903_;
													_tmp888_ = !_tmp904_;
												} else {
													_tmp888_ = FALSE;
												}
												if (_tmp888_) {
													ValaLocalVariable* _tmp905_;
													_tmp905_ = local;
													_tmp887_ = !vala_ccode_base_module_variable_accessible_in_finally ((ValaCCodeBaseModule*) self, _tmp905_);
												} else {
													_tmp887_ = FALSE;
												}
												if (_tmp887_) {
													gboolean _tmp906_ = FALSE;
													ValaLocalVariable* _tmp907_;
													ValaDataType* _tmp908_;
													ValaDataType* _tmp909_;
													_tmp907_ = local;
													_tmp908_ = vala_variable_get_variable_type ((ValaVariable*) _tmp907_);
													_tmp909_ = _tmp908_;
													if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp909_, VALA_TYPE_ARRAY_TYPE)) {
														ValaLocalVariable* _tmp910_;
														ValaDataType* _tmp911_;
														ValaDataType* _tmp912_;
														gboolean _tmp913_;
														gboolean _tmp914_;
														_tmp910_ = local;
														_tmp911_ = vala_variable_get_variable_type ((ValaVariable*) _tmp910_);
														_tmp912_ = _tmp911_;
														_tmp913_ = vala_array_type_get_inline_allocated (G_TYPE_CHECK_INSTANCE_CAST (_tmp912_, VALA_TYPE_ARRAY_TYPE, ValaArrayType));
														_tmp914_ = _tmp913_;
														_tmp906_ = _tmp914_;
													} else {
														_tmp906_ = FALSE;
													}
													_tmp886_ = !_tmp906_;
												} else {
													_tmp886_ = FALSE;
												}
												if (_tmp886_) {
													ValaDataType* _tmp915_;
													ValaDataType* _tmp916_;
													ValaLocalVariable* _tmp917_;
													ValaGLibValue* glib_value = NULL;
													ValaLocalVariable* _tmp918_;
													ValaTargetValue* _tmp919_;
													ValaGLibValue* _tmp920_;
													ValaGLibValue* _tmp921_;
													ValaCCodeExpression* _tmp922_;
													ValaGLibValue* _tmp925_;
													ValaCCodeExpression* _tmp926_;
													_tmp915_ = vala_expression_get_value_type ((ValaExpression*) expr);
													_tmp916_ = _tmp915_;
													vala_data_type_set_value_owned (_tmp916_, TRUE);
													_tmp917_ = local;
													vala_symbol_set_active ((ValaSymbol*) _tmp917_, FALSE);
													_tmp918_ = local;
													_tmp919_ = vala_ccode_base_module_get_local_cvalue ((ValaCCodeBaseModule*) self, _tmp918_);
													glib_value = G_TYPE_CHECK_INSTANCE_CAST (_tmp919_, VALA_TYPE_GLIB_VALUE, ValaGLibValue);
													_tmp920_ = glib_value;
													vala_expression_set_target_value ((ValaExpression*) expr, (ValaTargetValue*) _tmp920_);
													_tmp921_ = glib_value;
													_tmp922_ = _tmp921_->delegate_target_cvalue;
													if (_tmp922_ == NULL) {
														ValaGLibValue* _tmp923_;
														ValaCCodeConstant* _tmp924_;
														_tmp923_ = glib_value;
														_tmp924_ = vala_ccode_constant_new ("NULL");
														_vala_ccode_node_unref0 (_tmp923_->delegate_target_cvalue);
														_tmp923_->delegate_target_cvalue = (ValaCCodeExpression*) _tmp924_;
													}
													_tmp925_ = glib_value;
													_tmp926_ = _tmp925_->delegate_target_destroy_notify_cvalue;
													if (_tmp926_ == NULL) {
														ValaGLibValue* _tmp927_;
														ValaCCodeConstant* _tmp928_;
														_tmp927_ = glib_value;
														_tmp928_ = vala_ccode_constant_new ("NULL");
														_vala_ccode_node_unref0 (_tmp927_->delegate_target_destroy_notify_cvalue);
														_tmp927_->delegate_target_destroy_notify_cvalue = (ValaCCodeExpression*) _tmp928_;
													}
													_vala_target_value_unref0 (glib_value);
												} else {
													gboolean _tmp929_;
													gboolean _tmp930_;
													_tmp929_ = vala_expression_get_lvalue ((ValaExpression*) expr);
													_tmp930_ = _tmp929_;
													if (_tmp930_) {
														ValaLocalVariable* _tmp931_;
														ValaTargetValue* _tmp932_;
														ValaTargetValue* _tmp933_;
														_tmp931_ = local;
														_tmp932_ = vala_ccode_base_module_get_local_cvalue ((ValaCCodeBaseModule*) self, _tmp931_);
														_tmp933_ = _tmp932_;
														vala_expression_set_target_value ((ValaExpression*) expr, _tmp933_);
														_vala_target_value_unref0 (_tmp933_);
													} else {
														ValaLocalVariable* _tmp934_;
														ValaTargetValue* _tmp935_;
														ValaTargetValue* _tmp936_;
														_tmp934_ = local;
														_tmp935_ = vala_code_generator_load_local ((ValaCodeGenerator*) self, _tmp934_, (ValaExpression*) expr);
														_tmp936_ = _tmp935_;
														vala_expression_set_target_value ((ValaExpression*) expr, _tmp936_);
														_vala_target_value_unref0 (_tmp936_);
													}
												}
												_vala_code_node_unref0 (local);
											} else {
												ValaSymbol* _tmp937_;
												ValaSymbol* _tmp938_;
												_tmp937_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
												_tmp938_ = _tmp937_;
												if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp938_, VALA_TYPE_PARAMETER)) {
													ValaParameter* param = NULL;
													ValaSymbol* _tmp939_;
													ValaSymbol* _tmp940_;
													ValaParameter* _tmp941_;
													gboolean _tmp942_;
													gboolean _tmp943_;
													_tmp939_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
													_tmp940_ = _tmp939_;
													_tmp941_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp940_, VALA_TYPE_PARAMETER, ValaParameter));
													param = _tmp941_;
													_tmp942_ = vala_expression_get_lvalue ((ValaExpression*) expr);
													_tmp943_ = _tmp942_;
													if (_tmp943_) {
														ValaParameter* _tmp944_;
														ValaTargetValue* _tmp945_;
														ValaTargetValue* _tmp946_;
														_tmp944_ = param;
														_tmp945_ = vala_ccode_base_module_get_parameter_cvalue ((ValaCCodeBaseModule*) self, _tmp944_);
														_tmp946_ = _tmp945_;
														vala_expression_set_target_value ((ValaExpression*) expr, _tmp946_);
														_vala_target_value_unref0 (_tmp946_);
													} else {
														ValaParameter* _tmp947_;
														ValaTargetValue* _tmp948_;
														ValaTargetValue* _tmp949_;
														_tmp947_ = param;
														_tmp948_ = vala_code_generator_load_parameter ((ValaCodeGenerator*) self, _tmp947_, (ValaExpression*) expr);
														_tmp949_ = _tmp948_;
														vala_expression_set_target_value ((ValaExpression*) expr, _tmp949_);
														_vala_target_value_unref0 (_tmp949_);
													}
													_vala_code_node_unref0 (param);
												}
											}
										}
									}
								}
							}
						}
					}
				}
			}
		}
	}
	_tmp950_ = vala_expression_get_symbol_reference ((ValaExpression*) expr);
	_tmp951_ = _tmp950_;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp951_, VALA_TYPE_VARIABLE)) {
		ValaGLibValue* cvalue = NULL;
		ValaTargetValue* _tmp952_;
		ValaTargetValue* _tmp953_;
		gboolean _tmp954_ = FALSE;
		gboolean _tmp955_ = FALSE;
		ValaGLibValue* _tmp956_;
		ValaDataType* _tmp957_;
		ValaDataType* _tmp958_;
		_tmp952_ = vala_expression_get_target_value ((ValaExpression*) expr);
		_tmp953_ = _tmp952_;
		cvalue = G_TYPE_CHECK_INSTANCE_CAST (_tmp953_, VALA_TYPE_GLIB_VALUE, ValaGLibValue);
		_tmp956_ = cvalue;
		_tmp957_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp956_);
		_tmp958_ = _tmp957_;
		if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp958_, VALA_TYPE_GENERIC_TYPE)) {
			ValaGLibValue* _tmp959_;
			ValaDataType* _tmp960_;
			ValaDataType* _tmp961_;
			ValaTypeSymbol* _tmp962_;
			ValaTypeSymbol* _tmp963_;
			_tmp959_ = cvalue;
			_tmp960_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp959_);
			_tmp961_ = _tmp960_;
			_tmp962_ = vala_data_type_get_type_symbol (_tmp961_);
			_tmp963_ = _tmp962_;
			_tmp955_ = _tmp963_ != NULL;
		} else {
			_tmp955_ = FALSE;
		}
		if (_tmp955_) {
			ValaGLibValue* _tmp964_;
			ValaDataType* _tmp965_;
			ValaDataType* _tmp966_;
			ValaTypeSymbol* _tmp967_;
			ValaTypeSymbol* _tmp968_;
			ValaDataType* _tmp969_;
			ValaDataType* _tmp970_;
			ValaTypeSymbol* _tmp971_;
			ValaTypeSymbol* _tmp972_;
			_tmp964_ = cvalue;
			_tmp965_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp964_);
			_tmp966_ = _tmp965_;
			_tmp967_ = vala_data_type_get_type_symbol (_tmp966_);
			_tmp968_ = _tmp967_;
			_tmp969_ = vala_expression_get_value_type ((ValaExpression*) expr);
			_tmp970_ = _tmp969_;
			_tmp971_ = vala_data_type_get_type_symbol (_tmp970_);
			_tmp972_ = _tmp971_;
			_tmp954_ = _tmp968_ != _tmp972_;
		} else {
			_tmp954_ = FALSE;
		}
		if (_tmp954_) {
			ValaGLibValue* _tmp973_;
			ValaGLibValue* _tmp974_;
			ValaCCodeExpression* _tmp975_;
			ValaDataType* _tmp976_;
			ValaDataType* _tmp977_;
			gchar* _tmp978_;
			gchar* _tmp979_;
			ValaCCodeCastExpression* _tmp980_;
			_tmp973_ = cvalue;
			_tmp974_ = cvalue;
			_tmp975_ = _tmp974_->cvalue;
			_tmp976_ = vala_expression_get_value_type ((ValaExpression*) expr);
			_tmp977_ = _tmp976_;
			_tmp978_ = vala_get_ccode_name ((ValaCodeNode*) _tmp977_);
			_tmp979_ = _tmp978_;
			_tmp980_ = vala_ccode_cast_expression_new (_tmp975_, _tmp979_);
			_vala_ccode_node_unref0 (_tmp973_->cvalue);
			_tmp973_->cvalue = (ValaCCodeExpression*) _tmp980_;
			_g_free0 (_tmp979_);
		}
	}
	_vala_code_node_unref0 (delegate_type);
	_vala_code_node_unref0 (array_type);
	_vala_ccode_node_unref0 (pub_inst);
}

static ValaTargetValue*
vala_ccode_member_access_module_real_get_local_cvalue (ValaCCodeBaseModule* base,
                                                       ValaLocalVariable* local)
{
	ValaCCodeMemberAccessModule * self;
	ValaGLibValue* _result_ = NULL;
	ValaDataType* _tmp0_;
	ValaDataType* _tmp1_;
	ValaDataType* _tmp2_;
	ValaDataType* _tmp3_;
	ValaGLibValue* _tmp4_;
	ValaGLibValue* _tmp5_;
	ValaGLibValue* _tmp6_;
	ValaArrayType* array_type = NULL;
	ValaDataType* _tmp7_;
	ValaDataType* _tmp8_;
	ValaArrayType* _tmp9_;
	ValaDelegateType* delegate_type = NULL;
	ValaDataType* _tmp10_;
	ValaDataType* _tmp11_;
	ValaDelegateType* _tmp12_;
	gboolean _tmp13_;
	gboolean _tmp14_;
	ValaTargetValue* result;
	self = (ValaCCodeMemberAccessModule*) base;
	g_return_val_if_fail (local != NULL, NULL);
	_tmp0_ = vala_variable_get_variable_type ((ValaVariable*) local);
	_tmp1_ = _tmp0_;
	_tmp2_ = vala_data_type_copy (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = vala_glib_value_new (_tmp3_, NULL, FALSE);
	_tmp5_ = _tmp4_;
	_vala_code_node_unref0 (_tmp3_);
	_result_ = _tmp5_;
	_tmp6_ = _result_;
	_tmp6_->lvalue = TRUE;
	_tmp7_ = vala_variable_get_variable_type ((ValaVariable*) local);
	_tmp8_ = _tmp7_;
	_tmp9_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, VALA_TYPE_ARRAY_TYPE) ? ((ValaArrayType*) _tmp8_) : NULL);
	array_type = _tmp9_;
	_tmp10_ = vala_variable_get_variable_type ((ValaVariable*) local);
	_tmp11_ = _tmp10_;
	_tmp12_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, VALA_TYPE_DELEGATE_TYPE) ? ((ValaDelegateType*) _tmp11_) : NULL);
	delegate_type = _tmp12_;
	_tmp13_ = vala_local_variable_get_is_result (local);
	_tmp14_ = _tmp13_;
	if (_tmp14_) {
		gboolean _tmp15_ = FALSE;
		ValaDataType* _tmp16_;
		ValaDataType* _tmp17_;
		gboolean _tmp26_ = FALSE;
		gboolean _tmp27_ = FALSE;
		ValaArrayType* _tmp28_;
		_tmp16_ = vala_variable_get_variable_type ((ValaVariable*) local);
		_tmp17_ = _tmp16_;
		if (_tmp17_ != NULL) {
			ValaDataType* _tmp18_;
			ValaDataType* _tmp19_;
			_tmp18_ = vala_variable_get_variable_type ((ValaVariable*) local);
			_tmp19_ = _tmp18_;
			_tmp15_ = vala_data_type_is_real_non_null_struct_type (_tmp19_);
		} else {
			_tmp15_ = FALSE;
		}
		if (_tmp15_) {
			ValaGLibValue* _tmp20_;
			ValaCCodeIdentifier* _tmp21_;
			ValaCCodeIdentifier* _tmp22_;
			ValaCCodeUnaryExpression* _tmp23_;
			_tmp20_ = _result_;
			_tmp21_ = vala_ccode_identifier_new ("result");
			_tmp22_ = _tmp21_;
			_tmp23_ = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_POINTER_INDIRECTION, (ValaCCodeExpression*) _tmp22_);
			_vala_ccode_node_unref0 (_tmp20_->cvalue);
			_tmp20_->cvalue = (ValaCCodeExpression*) _tmp23_;
			_vala_ccode_node_unref0 (_tmp22_);
		} else {
			ValaGLibValue* _tmp24_;
			ValaCCodeIdentifier* _tmp25_;
			_tmp24_ = _result_;
			_tmp25_ = vala_ccode_identifier_new ("result");
			_vala_ccode_node_unref0 (_tmp24_->cvalue);
			_tmp24_->cvalue = (ValaCCodeExpression*) _tmp25_;
		}
		_tmp28_ = array_type;
		if (_tmp28_ != NULL) {
			ValaArrayType* _tmp29_;
			gboolean _tmp30_;
			gboolean _tmp31_;
			_tmp29_ = array_type;
			_tmp30_ = vala_array_type_get_fixed_length (_tmp29_);
			_tmp31_ = _tmp30_;
			_tmp27_ = !_tmp31_;
		} else {
			_tmp27_ = FALSE;
		}
		if (_tmp27_) {
			gboolean _tmp32_ = FALSE;
			gboolean _tmp33_ = FALSE;
			ValaMethod* _tmp34_;
			ValaMethod* _tmp35_;
			_tmp34_ = vala_ccode_base_module_get_current_method ((ValaCCodeBaseModule*) self);
			_tmp35_ = _tmp34_;
			if (_tmp35_ != NULL) {
				ValaMethod* _tmp36_;
				ValaMethod* _tmp37_;
				_tmp36_ = vala_ccode_base_module_get_current_method ((ValaCCodeBaseModule*) self);
				_tmp37_ = _tmp36_;
				_tmp33_ = vala_get_ccode_array_length ((ValaCodeNode*) _tmp37_);
			} else {
				_tmp33_ = FALSE;
			}
			if (_tmp33_) {
				_tmp32_ = TRUE;
			} else {
				ValaPropertyAccessor* _tmp38_;
				ValaPropertyAccessor* _tmp39_;
				_tmp38_ = vala_ccode_base_module_get_current_property_accessor ((ValaCCodeBaseModule*) self);
				_tmp39_ = _tmp38_;
				_tmp32_ = _tmp39_ != NULL;
			}
			_tmp26_ = _tmp32_;
		} else {
			_tmp26_ = FALSE;
		}
		if (_tmp26_) {
			{
				gint dim = 0;
				dim = 1;
				{
					gboolean _tmp40_ = FALSE;
					_tmp40_ = TRUE;
					while (TRUE) {
						ValaArrayType* _tmp42_;
						gint _tmp43_;
						gint _tmp44_;
						ValaGLibValue* _tmp45_;
						gchar* _tmp46_;
						gchar* _tmp47_;
						ValaCCodeExpression* _tmp48_;
						ValaCCodeExpression* _tmp49_;
						ValaCCodeUnaryExpression* _tmp50_;
						ValaCCodeUnaryExpression* _tmp51_;
						if (!_tmp40_) {
							gint _tmp41_;
							_tmp41_ = dim;
							dim = _tmp41_ + 1;
						}
						_tmp40_ = FALSE;
						_tmp42_ = array_type;
						_tmp43_ = vala_array_type_get_rank (_tmp42_);
						_tmp44_ = _tmp43_;
						if (!(dim <= _tmp44_)) {
							break;
						}
						_tmp45_ = _result_;
						_tmp46_ = vala_ccode_base_module_get_array_length_cname ((ValaCCodeBaseModule*) self, "result", dim);
						_tmp47_ = _tmp46_;
						_tmp48_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp47_);
						_tmp49_ = _tmp48_;
						_tmp50_ = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_POINTER_INDIRECTION, _tmp49_);
						_tmp51_ = _tmp50_;
						vala_glib_value_append_array_length_cvalue (_tmp45_, (ValaCCodeExpression*) _tmp51_);
						_vala_ccode_node_unref0 (_tmp51_);
						_vala_ccode_node_unref0 (_tmp49_);
						_g_free0 (_tmp47_);
					}
				}
			}
		}
	} else {
		gboolean _tmp52_;
		gboolean _tmp53_;
		_tmp52_ = vala_local_variable_get_captured (local);
		_tmp53_ = _tmp52_;
		if (_tmp53_) {
			ValaBlock* block = NULL;
			ValaSymbol* _tmp54_;
			ValaSymbol* _tmp55_;
			ValaBlock* _tmp56_;
			ValaGLibValue* _tmp57_;
			ValaBlock* _tmp58_;
			gchar* _tmp59_;
			gchar* _tmp60_;
			ValaCCodeExpression* _tmp61_;
			ValaCCodeExpression* _tmp62_;
			gchar* _tmp63_;
			gchar* _tmp64_;
			ValaCCodeMemberAccess* _tmp65_;
			gboolean _tmp66_ = FALSE;
			ValaArrayType* _tmp67_;
			_tmp54_ = vala_symbol_get_parent_symbol ((ValaSymbol*) local);
			_tmp55_ = _tmp54_;
			_tmp56_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp55_, VALA_TYPE_BLOCK, ValaBlock));
			block = _tmp56_;
			_tmp57_ = _result_;
			_tmp58_ = block;
			_tmp59_ = g_strdup_printf ("_data%d_", vala_ccode_base_module_get_block_id ((ValaCCodeBaseModule*) self, _tmp58_));
			_tmp60_ = _tmp59_;
			_tmp61_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp60_);
			_tmp62_ = _tmp61_;
			_tmp63_ = vala_ccode_base_module_get_local_cname ((ValaCCodeBaseModule*) self, local);
			_tmp64_ = _tmp63_;
			_tmp65_ = vala_ccode_member_access_new_pointer (_tmp62_, _tmp64_);
			_vala_ccode_node_unref0 (_tmp57_->cvalue);
			_tmp57_->cvalue = (ValaCCodeExpression*) _tmp65_;
			_g_free0 (_tmp64_);
			_vala_ccode_node_unref0 (_tmp62_);
			_g_free0 (_tmp60_);
			_tmp67_ = array_type;
			if (_tmp67_ != NULL) {
				ValaArrayType* _tmp68_;
				gboolean _tmp69_;
				gboolean _tmp70_;
				_tmp68_ = array_type;
				_tmp69_ = vala_array_type_get_fixed_length (_tmp68_);
				_tmp70_ = _tmp69_;
				_tmp66_ = !_tmp70_;
			} else {
				_tmp66_ = FALSE;
			}
			if (_tmp66_) {
				ValaArrayType* _tmp88_;
				gint _tmp89_;
				gint _tmp90_;
				{
					gint dim = 0;
					dim = 1;
					{
						gboolean _tmp71_ = FALSE;
						_tmp71_ = TRUE;
						while (TRUE) {
							ValaArrayType* _tmp73_;
							gint _tmp74_;
							gint _tmp75_;
							ValaGLibValue* _tmp76_;
							ValaBlock* _tmp77_;
							gchar* _tmp78_;
							gchar* _tmp79_;
							ValaCCodeExpression* _tmp80_;
							ValaCCodeExpression* _tmp81_;
							gchar* _tmp82_;
							gchar* _tmp83_;
							gchar* _tmp84_;
							gchar* _tmp85_;
							ValaCCodeMemberAccess* _tmp86_;
							ValaCCodeMemberAccess* _tmp87_;
							if (!_tmp71_) {
								gint _tmp72_;
								_tmp72_ = dim;
								dim = _tmp72_ + 1;
							}
							_tmp71_ = FALSE;
							_tmp73_ = array_type;
							_tmp74_ = vala_array_type_get_rank (_tmp73_);
							_tmp75_ = _tmp74_;
							if (!(dim <= _tmp75_)) {
								break;
							}
							_tmp76_ = _result_;
							_tmp77_ = block;
							_tmp78_ = g_strdup_printf ("_data%d_", vala_ccode_base_module_get_block_id ((ValaCCodeBaseModule*) self, _tmp77_));
							_tmp79_ = _tmp78_;
							_tmp80_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp79_);
							_tmp81_ = _tmp80_;
							_tmp82_ = vala_ccode_base_module_get_local_cname ((ValaCCodeBaseModule*) self, local);
							_tmp83_ = _tmp82_;
							_tmp84_ = vala_ccode_base_module_get_array_length_cname ((ValaCCodeBaseModule*) self, _tmp83_, dim);
							_tmp85_ = _tmp84_;
							_tmp86_ = vala_ccode_member_access_new_pointer (_tmp81_, _tmp85_);
							_tmp87_ = _tmp86_;
							vala_glib_value_append_array_length_cvalue (_tmp76_, (ValaCCodeExpression*) _tmp87_);
							_vala_ccode_node_unref0 (_tmp87_);
							_g_free0 (_tmp85_);
							_g_free0 (_tmp83_);
							_vala_ccode_node_unref0 (_tmp81_);
							_g_free0 (_tmp79_);
						}
					}
				}
				_tmp88_ = array_type;
				_tmp89_ = vala_array_type_get_rank (_tmp88_);
				_tmp90_ = _tmp89_;
				if (_tmp90_ == 1) {
					ValaGLibValue* _tmp91_;
					ValaBlock* _tmp92_;
					gchar* _tmp93_;
					gchar* _tmp94_;
					ValaCCodeExpression* _tmp95_;
					ValaCCodeExpression* _tmp96_;
					gchar* _tmp97_;
					gchar* _tmp98_;
					gchar* _tmp99_;
					gchar* _tmp100_;
					ValaCCodeMemberAccess* _tmp101_;
					_tmp91_ = _result_;
					_tmp92_ = block;
					_tmp93_ = g_strdup_printf ("_data%d_", vala_ccode_base_module_get_block_id ((ValaCCodeBaseModule*) self, _tmp92_));
					_tmp94_ = _tmp93_;
					_tmp95_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp94_);
					_tmp96_ = _tmp95_;
					_tmp97_ = vala_ccode_base_module_get_local_cname ((ValaCCodeBaseModule*) self, local);
					_tmp98_ = _tmp97_;
					_tmp99_ = vala_ccode_base_module_get_array_size_cname ((ValaCCodeBaseModule*) self, _tmp98_);
					_tmp100_ = _tmp99_;
					_tmp101_ = vala_ccode_member_access_new_pointer (_tmp96_, _tmp100_);
					_vala_ccode_node_unref0 (_tmp91_->array_size_cvalue);
					_tmp91_->array_size_cvalue = (ValaCCodeExpression*) _tmp101_;
					_g_free0 (_tmp100_);
					_g_free0 (_tmp98_);
					_vala_ccode_node_unref0 (_tmp96_);
					_g_free0 (_tmp94_);
				}
			} else {
				gboolean _tmp102_ = FALSE;
				ValaDelegateType* _tmp103_;
				_tmp103_ = delegate_type;
				if (_tmp103_ != NULL) {
					ValaDelegateType* _tmp104_;
					ValaDelegate* _tmp105_;
					ValaDelegate* _tmp106_;
					gboolean _tmp107_;
					gboolean _tmp108_;
					_tmp104_ = delegate_type;
					_tmp105_ = vala_delegate_type_get_delegate_symbol (_tmp104_);
					_tmp106_ = _tmp105_;
					_tmp107_ = vala_delegate_get_has_target (_tmp106_);
					_tmp108_ = _tmp107_;
					_tmp102_ = _tmp108_;
				} else {
					_tmp102_ = FALSE;
				}
				if (_tmp102_) {
					ValaGLibValue* _tmp109_;
					ValaBlock* _tmp110_;
					gchar* _tmp111_;
					gchar* _tmp112_;
					ValaCCodeExpression* _tmp113_;
					ValaCCodeExpression* _tmp114_;
					gchar* _tmp115_;
					gchar* _tmp116_;
					gchar* _tmp117_;
					gchar* _tmp118_;
					ValaCCodeMemberAccess* _tmp119_;
					ValaDelegateType* _tmp120_;
					_tmp109_ = _result_;
					_tmp110_ = block;
					_tmp111_ = g_strdup_printf ("_data%d_", vala_ccode_base_module_get_block_id ((ValaCCodeBaseModule*) self, _tmp110_));
					_tmp112_ = _tmp111_;
					_tmp113_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp112_);
					_tmp114_ = _tmp113_;
					_tmp115_ = vala_ccode_base_module_get_local_cname ((ValaCCodeBaseModule*) self, local);
					_tmp116_ = _tmp115_;
					_tmp117_ = vala_ccode_base_module_get_delegate_target_cname ((ValaCCodeBaseModule*) self, _tmp116_);
					_tmp118_ = _tmp117_;
					_tmp119_ = vala_ccode_member_access_new_pointer (_tmp114_, _tmp118_);
					_vala_ccode_node_unref0 (_tmp109_->delegate_target_cvalue);
					_tmp109_->delegate_target_cvalue = (ValaCCodeExpression*) _tmp119_;
					_g_free0 (_tmp118_);
					_g_free0 (_tmp116_);
					_vala_ccode_node_unref0 (_tmp114_);
					_g_free0 (_tmp112_);
					_tmp120_ = delegate_type;
					if (vala_data_type_is_disposable ((ValaDataType*) _tmp120_)) {
						ValaGLibValue* _tmp121_;
						ValaBlock* _tmp122_;
						gchar* _tmp123_;
						gchar* _tmp124_;
						ValaCCodeExpression* _tmp125_;
						ValaCCodeExpression* _tmp126_;
						gchar* _tmp127_;
						gchar* _tmp128_;
						gchar* _tmp129_;
						gchar* _tmp130_;
						ValaCCodeMemberAccess* _tmp131_;
						_tmp121_ = _result_;
						_tmp122_ = block;
						_tmp123_ = g_strdup_printf ("_data%d_", vala_ccode_base_module_get_block_id ((ValaCCodeBaseModule*) self, _tmp122_));
						_tmp124_ = _tmp123_;
						_tmp125_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp124_);
						_tmp126_ = _tmp125_;
						_tmp127_ = vala_ccode_base_module_get_local_cname ((ValaCCodeBaseModule*) self, local);
						_tmp128_ = _tmp127_;
						_tmp129_ = vala_ccode_base_module_get_delegate_target_destroy_notify_cname ((ValaCCodeBaseModule*) self, _tmp128_);
						_tmp130_ = _tmp129_;
						_tmp131_ = vala_ccode_member_access_new_pointer (_tmp126_, _tmp130_);
						_vala_ccode_node_unref0 (_tmp121_->delegate_target_destroy_notify_cvalue);
						_tmp121_->delegate_target_destroy_notify_cvalue = (ValaCCodeExpression*) _tmp131_;
						_g_free0 (_tmp130_);
						_g_free0 (_tmp128_);
						_vala_ccode_node_unref0 (_tmp126_);
						_g_free0 (_tmp124_);
					}
				}
			}
			_vala_code_node_unref0 (block);
		} else {
			ValaGLibValue* _tmp132_;
			ValaCCodeExpression* _tmp133_;
			gboolean _tmp134_ = FALSE;
			ValaArrayType* _tmp135_;
			_tmp132_ = _result_;
			_tmp133_ = vala_ccode_base_module_get_local_cexpression ((ValaCCodeBaseModule*) self, local);
			_vala_ccode_node_unref0 (_tmp132_->cvalue);
			_tmp132_->cvalue = _tmp133_;
			_tmp135_ = array_type;
			if (_tmp135_ != NULL) {
				ValaArrayType* _tmp136_;
				gboolean _tmp137_;
				gboolean _tmp138_;
				_tmp136_ = array_type;
				_tmp137_ = vala_array_type_get_fixed_length (_tmp136_);
				_tmp138_ = _tmp137_;
				_tmp134_ = !_tmp138_;
			} else {
				_tmp134_ = FALSE;
			}
			if (_tmp134_) {
				ValaArrayType* _tmp151_;
				gint _tmp152_;
				gint _tmp153_;
				{
					gint dim = 0;
					dim = 1;
					{
						gboolean _tmp139_ = FALSE;
						_tmp139_ = TRUE;
						while (TRUE) {
							ValaArrayType* _tmp141_;
							gint _tmp142_;
							gint _tmp143_;
							ValaGLibValue* _tmp144_;
							gchar* _tmp145_;
							gchar* _tmp146_;
							gchar* _tmp147_;
							gchar* _tmp148_;
							ValaCCodeExpression* _tmp149_;
							ValaCCodeExpression* _tmp150_;
							if (!_tmp139_) {
								gint _tmp140_;
								_tmp140_ = dim;
								dim = _tmp140_ + 1;
							}
							_tmp139_ = FALSE;
							_tmp141_ = array_type;
							_tmp142_ = vala_array_type_get_rank (_tmp141_);
							_tmp143_ = _tmp142_;
							if (!(dim <= _tmp143_)) {
								break;
							}
							_tmp144_ = _result_;
							_tmp145_ = vala_ccode_base_module_get_local_cname ((ValaCCodeBaseModule*) self, local);
							_tmp146_ = _tmp145_;
							_tmp147_ = vala_ccode_base_module_get_array_length_cname ((ValaCCodeBaseModule*) self, _tmp146_, dim);
							_tmp148_ = _tmp147_;
							_tmp149_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp148_);
							_tmp150_ = _tmp149_;
							vala_glib_value_append_array_length_cvalue (_tmp144_, _tmp150_);
							_vala_ccode_node_unref0 (_tmp150_);
							_g_free0 (_tmp148_);
							_g_free0 (_tmp146_);
						}
					}
				}
				_tmp151_ = array_type;
				_tmp152_ = vala_array_type_get_rank (_tmp151_);
				_tmp153_ = _tmp152_;
				if (_tmp153_ == 1) {
					ValaGLibValue* _tmp154_;
					gchar* _tmp155_;
					gchar* _tmp156_;
					gchar* _tmp157_;
					gchar* _tmp158_;
					ValaCCodeExpression* _tmp159_;
					_tmp154_ = _result_;
					_tmp155_ = vala_ccode_base_module_get_local_cname ((ValaCCodeBaseModule*) self, local);
					_tmp156_ = _tmp155_;
					_tmp157_ = vala_ccode_base_module_get_array_size_cname ((ValaCCodeBaseModule*) self, _tmp156_);
					_tmp158_ = _tmp157_;
					_tmp159_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp158_);
					_vala_ccode_node_unref0 (_tmp154_->array_size_cvalue);
					_tmp154_->array_size_cvalue = _tmp159_;
					_g_free0 (_tmp158_);
					_g_free0 (_tmp156_);
				}
			} else {
				gboolean _tmp160_ = FALSE;
				ValaDelegateType* _tmp161_;
				_tmp161_ = delegate_type;
				if (_tmp161_ != NULL) {
					ValaDelegateType* _tmp162_;
					ValaDelegate* _tmp163_;
					ValaDelegate* _tmp164_;
					gboolean _tmp165_;
					gboolean _tmp166_;
					_tmp162_ = delegate_type;
					_tmp163_ = vala_delegate_type_get_delegate_symbol (_tmp162_);
					_tmp164_ = _tmp163_;
					_tmp165_ = vala_delegate_get_has_target (_tmp164_);
					_tmp166_ = _tmp165_;
					_tmp160_ = _tmp166_;
				} else {
					_tmp160_ = FALSE;
				}
				if (_tmp160_) {
					if (vala_ccode_base_module_is_in_coroutine ((ValaCCodeBaseModule*) self)) {
						ValaGLibValue* _tmp167_;
						gchar* _tmp168_;
						gchar* _tmp169_;
						gchar* _tmp170_;
						gchar* _tmp171_;
						ValaCCodeExpression* _tmp172_;
						ValaDataType* _tmp173_;
						ValaDataType* _tmp174_;
						_tmp167_ = _result_;
						_tmp168_ = vala_ccode_base_module_get_local_cname ((ValaCCodeBaseModule*) self, local);
						_tmp169_ = _tmp168_;
						_tmp170_ = vala_ccode_base_module_get_delegate_target_cname ((ValaCCodeBaseModule*) self, _tmp169_);
						_tmp171_ = _tmp170_;
						_tmp172_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp171_);
						_vala_ccode_node_unref0 (_tmp167_->delegate_target_cvalue);
						_tmp167_->delegate_target_cvalue = _tmp172_;
						_g_free0 (_tmp171_);
						_g_free0 (_tmp169_);
						_tmp173_ = vala_variable_get_variable_type ((ValaVariable*) local);
						_tmp174_ = _tmp173_;
						if (vala_data_type_is_disposable (_tmp174_)) {
							ValaGLibValue* _tmp175_;
							gchar* _tmp176_;
							gchar* _tmp177_;
							gchar* _tmp178_;
							gchar* _tmp179_;
							ValaCCodeExpression* _tmp180_;
							_tmp175_ = _result_;
							_tmp176_ = vala_ccode_base_module_get_local_cname ((ValaCCodeBaseModule*) self, local);
							_tmp177_ = _tmp176_;
							_tmp178_ = vala_ccode_base_module_get_delegate_target_destroy_notify_cname ((ValaCCodeBaseModule*) self, _tmp177_);
							_tmp179_ = _tmp178_;
							_tmp180_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp179_);
							_vala_ccode_node_unref0 (_tmp175_->delegate_target_destroy_notify_cvalue);
							_tmp175_->delegate_target_destroy_notify_cvalue = _tmp180_;
							_g_free0 (_tmp179_);
							_g_free0 (_tmp177_);
						}
					} else {
						ValaGLibValue* _tmp181_;
						gchar* _tmp182_;
						gchar* _tmp183_;
						gchar* _tmp184_;
						gchar* _tmp185_;
						ValaCCodeIdentifier* _tmp186_;
						ValaDataType* _tmp187_;
						ValaDataType* _tmp188_;
						_tmp181_ = _result_;
						_tmp182_ = vala_ccode_base_module_get_local_cname ((ValaCCodeBaseModule*) self, local);
						_tmp183_ = _tmp182_;
						_tmp184_ = vala_ccode_base_module_get_delegate_target_cname ((ValaCCodeBaseModule*) self, _tmp183_);
						_tmp185_ = _tmp184_;
						_tmp186_ = vala_ccode_identifier_new (_tmp185_);
						_vala_ccode_node_unref0 (_tmp181_->delegate_target_cvalue);
						_tmp181_->delegate_target_cvalue = (ValaCCodeExpression*) _tmp186_;
						_g_free0 (_tmp185_);
						_g_free0 (_tmp183_);
						_tmp187_ = vala_variable_get_variable_type ((ValaVariable*) local);
						_tmp188_ = _tmp187_;
						if (vala_data_type_is_disposable (_tmp188_)) {
							ValaGLibValue* _tmp189_;
							gchar* _tmp190_;
							gchar* _tmp191_;
							gchar* _tmp192_;
							gchar* _tmp193_;
							ValaCCodeIdentifier* _tmp194_;
							_tmp189_ = _result_;
							_tmp190_ = vala_ccode_base_module_get_local_cname ((ValaCCodeBaseModule*) self, local);
							_tmp191_ = _tmp190_;
							_tmp192_ = vala_ccode_base_module_get_delegate_target_destroy_notify_cname ((ValaCCodeBaseModule*) self, _tmp191_);
							_tmp193_ = _tmp192_;
							_tmp194_ = vala_ccode_identifier_new (_tmp193_);
							_vala_ccode_node_unref0 (_tmp189_->delegate_target_destroy_notify_cvalue);
							_tmp189_->delegate_target_destroy_notify_cvalue = (ValaCCodeExpression*) _tmp194_;
							_g_free0 (_tmp193_);
							_g_free0 (_tmp191_);
						}
					}
				}
			}
		}
	}
	result = (ValaTargetValue*) _result_;
	_vala_code_node_unref0 (delegate_type);
	_vala_code_node_unref0 (array_type);
	return result;
}

static ValaTargetValue*
vala_ccode_member_access_module_real_get_parameter_cvalue (ValaCCodeBaseModule* base,
                                                           ValaParameter* param)
{
	ValaCCodeMemberAccessModule * self;
	ValaGLibValue* _result_ = NULL;
	ValaDataType* _tmp0_;
	ValaDataType* _tmp1_;
	ValaDataType* _tmp2_;
	ValaDataType* _tmp3_;
	ValaGLibValue* _tmp4_;
	ValaGLibValue* _tmp5_;
	ValaGLibValue* _tmp6_;
	ValaGLibValue* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gboolean _tmp10_;
	ValaGLibValue* _tmp15_;
	gchar* _tmp16_;
	ValaArrayType* array_type = NULL;
	ValaGLibValue* _tmp17_;
	ValaDataType* _tmp18_;
	ValaDataType* _tmp19_;
	ValaArrayType* _tmp20_;
	ValaDelegateType* delegate_type = NULL;
	ValaGLibValue* _tmp21_;
	ValaDataType* _tmp22_;
	ValaDataType* _tmp23_;
	ValaDelegateType* _tmp24_;
	gboolean _tmp25_ = FALSE;
	ValaDelegateType* _tmp26_;
	gboolean is_unowned_delegate = FALSE;
	gboolean _tmp31_ = FALSE;
	gboolean _tmp32_ = FALSE;
	gboolean _tmp33_;
	gboolean _tmp34_;
	const gchar* _tmp38_;
	const gchar* _tmp39_;
	ValaTargetValue* result;
	self = (ValaCCodeMemberAccessModule*) base;
	g_return_val_if_fail (param != NULL, NULL);
	_tmp0_ = vala_variable_get_variable_type ((ValaVariable*) param);
	_tmp1_ = _tmp0_;
	_tmp2_ = vala_data_type_copy (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = vala_glib_value_new (_tmp3_, NULL, FALSE);
	_tmp5_ = _tmp4_;
	_vala_code_node_unref0 (_tmp3_);
	_result_ = _tmp5_;
	_tmp6_ = _result_;
	_tmp6_->lvalue = TRUE;
	_tmp7_ = _result_;
	_tmp7_->array_null_terminated = vala_get_ccode_array_null_terminated ((ValaCodeNode*) param);
	_tmp8_ = vala_get_ccode_array_length_expr ((ValaCodeNode*) param);
	_tmp9_ = _tmp8_;
	_tmp10_ = _tmp9_ != NULL;
	_g_free0 (_tmp9_);
	if (_tmp10_) {
		ValaGLibValue* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		ValaCCodeConstant* _tmp14_;
		_tmp11_ = _result_;
		_tmp12_ = vala_get_ccode_array_length_expr ((ValaCodeNode*) param);
		_tmp13_ = _tmp12_;
		_tmp14_ = vala_ccode_constant_new (_tmp13_);
		_vala_ccode_node_unref0 (_tmp11_->array_length_cexpr);
		_tmp11_->array_length_cexpr = (ValaCCodeExpression*) _tmp14_;
		_g_free0 (_tmp13_);
	}
	_tmp15_ = _result_;
	_tmp16_ = vala_get_ccode_type ((ValaCodeNode*) param);
	_g_free0 (_tmp15_->ctype);
	_tmp15_->ctype = _tmp16_;
	_tmp17_ = _result_;
	_tmp18_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp17_);
	_tmp19_ = _tmp18_;
	_tmp20_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, VALA_TYPE_ARRAY_TYPE) ? ((ValaArrayType*) _tmp19_) : NULL);
	array_type = _tmp20_;
	_tmp21_ = _result_;
	_tmp22_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp21_);
	_tmp23_ = _tmp22_;
	_tmp24_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, VALA_TYPE_DELEGATE_TYPE) ? ((ValaDelegateType*) _tmp23_) : NULL);
	delegate_type = _tmp24_;
	_tmp26_ = delegate_type;
	if (_tmp26_ != NULL) {
		ValaDataType* _tmp27_;
		ValaDataType* _tmp28_;
		gboolean _tmp29_;
		gboolean _tmp30_;
		_tmp27_ = vala_variable_get_variable_type ((ValaVariable*) param);
		_tmp28_ = _tmp27_;
		_tmp29_ = vala_data_type_get_value_owned (_tmp28_);
		_tmp30_ = _tmp29_;
		_tmp25_ = !_tmp30_;
	} else {
		_tmp25_ = FALSE;
	}
	is_unowned_delegate = _tmp25_;
	_tmp33_ = vala_parameter_get_captured (param);
	_tmp34_ = _tmp33_;
	if (_tmp34_) {
		_tmp32_ = TRUE;
	} else {
		_tmp32_ = vala_ccode_base_module_is_in_coroutine ((ValaCCodeBaseModule*) self);
	}
	if (_tmp32_) {
		_tmp31_ = !is_unowned_delegate;
	} else {
		_tmp31_ = FALSE;
	}
	if (_tmp31_) {
		ValaGLibValue* _tmp35_;
		ValaDataType* _tmp36_;
		ValaDataType* _tmp37_;
		_tmp35_ = _result_;
		_tmp36_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp35_);
		_tmp37_ = _tmp36_;
		vala_data_type_set_value_owned (_tmp37_, TRUE);
	}
	_tmp38_ = vala_symbol_get_name ((ValaSymbol*) param);
	_tmp39_ = _tmp38_;
	if (g_strcmp0 (_tmp39_, "this") == 0) {
		if (vala_ccode_base_module_is_in_coroutine ((ValaCCodeBaseModule*) self)) {
			ValaGLibValue* _tmp40_;
			ValaCCodeExpression* _tmp41_;
			_tmp40_ = _result_;
			_tmp41_ = vala_ccode_base_module_get_this_cexpression ((ValaCCodeBaseModule*) self);
			_vala_ccode_node_unref0 (_tmp40_->cvalue);
			_tmp40_->cvalue = _tmp41_;
		} else {
			ValaStruct* st = NULL;
			ValaGLibValue* _tmp42_;
			ValaDataType* _tmp43_;
			ValaDataType* _tmp44_;
			ValaTypeSymbol* _tmp45_;
			ValaTypeSymbol* _tmp46_;
			gboolean _tmp47_ = FALSE;
			ValaStruct* _tmp48_;
			_tmp42_ = _result_;
			_tmp43_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp42_);
			_tmp44_ = _tmp43_;
			_tmp45_ = vala_data_type_get_type_symbol (_tmp44_);
			_tmp46_ = _tmp45_;
			st = G_TYPE_CHECK_INSTANCE_TYPE (_tmp46_, VALA_TYPE_STRUCT) ? ((ValaStruct*) _tmp46_) : NULL;
			_tmp48_ = st;
			if (_tmp48_ != NULL) {
				ValaStruct* _tmp49_;
				_tmp49_ = st;
				_tmp47_ = !vala_struct_is_simple_type (_tmp49_);
			} else {
				_tmp47_ = FALSE;
			}
			if (_tmp47_) {
				ValaGLibValue* _tmp50_;
				ValaCCodeIdentifier* _tmp51_;
				_tmp50_ = _result_;
				_tmp51_ = vala_ccode_identifier_new ("(*self)");
				_vala_ccode_node_unref0 (_tmp50_->cvalue);
				_tmp50_->cvalue = (ValaCCodeExpression*) _tmp51_;
			} else {
				ValaGLibValue* _tmp52_;
				ValaCCodeIdentifier* _tmp53_;
				_tmp52_ = _result_;
				_tmp53_ = vala_ccode_identifier_new ("self");
				_vala_ccode_node_unref0 (_tmp52_->cvalue);
				_tmp52_->cvalue = (ValaCCodeExpression*) _tmp53_;
			}
		}
	} else {
		gchar* name = NULL;
		gchar* _tmp54_;
		gboolean _tmp55_ = FALSE;
		gboolean _tmp56_;
		gboolean _tmp57_;
		gboolean _tmp208_ = FALSE;
		gboolean _tmp209_;
		gboolean _tmp210_;
		_tmp54_ = vala_get_ccode_name ((ValaCodeNode*) param);
		name = _tmp54_;
		_tmp56_ = vala_parameter_get_captured (param);
		_tmp57_ = _tmp56_;
		if (_tmp57_) {
			gboolean _tmp58_;
			gboolean _tmp59_;
			_tmp58_ = vala_ccode_base_module_get_is_in_method_precondition ((ValaCCodeBaseModule*) self);
			_tmp59_ = _tmp58_;
			_tmp55_ = !_tmp59_;
		} else {
			_tmp55_ = FALSE;
		}
		if (_tmp55_) {
			ValaBlock* block = NULL;
			ValaSymbol* _tmp60_;
			ValaSymbol* _tmp61_;
			ValaBlock* _tmp62_;
			ValaBlock* _tmp63_;
			ValaGLibValue* _tmp69_;
			ValaBlock* _tmp70_;
			gchar* _tmp71_;
			gchar* _tmp72_;
			ValaCCodeExpression* _tmp73_;
			ValaCCodeExpression* _tmp74_;
			gchar* _tmp75_;
			gchar* _tmp76_;
			ValaCCodeMemberAccess* _tmp77_;
			gboolean _tmp78_ = FALSE;
			ValaArrayType* _tmp79_;
			_tmp60_ = vala_symbol_get_parent_symbol ((ValaSymbol*) param);
			_tmp61_ = _tmp60_;
			_tmp62_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp61_, VALA_TYPE_BLOCK) ? ((ValaBlock*) _tmp61_) : NULL);
			block = _tmp62_;
			_tmp63_ = block;
			if (_tmp63_ == NULL) {
				ValaSymbol* _tmp64_;
				ValaSymbol* _tmp65_;
				ValaBlock* _tmp66_;
				ValaBlock* _tmp67_;
				ValaBlock* _tmp68_;
				_tmp64_ = vala_symbol_get_parent_symbol ((ValaSymbol*) param);
				_tmp65_ = _tmp64_;
				_tmp66_ = vala_subroutine_get_body ((ValaSubroutine*) G_TYPE_CHECK_INSTANCE_CAST (_tmp65_, VALA_TYPE_METHOD, ValaMethod));
				_tmp67_ = _tmp66_;
				_tmp68_ = _vala_code_node_ref0 (_tmp67_);
				_vala_code_node_unref0 (block);
				block = _tmp68_;
			}
			_tmp69_ = _result_;
			_tmp70_ = block;
			_tmp71_ = g_strdup_printf ("_data%d_", vala_ccode_base_module_get_block_id ((ValaCCodeBaseModule*) self, _tmp70_));
			_tmp72_ = _tmp71_;
			_tmp73_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp72_);
			_tmp74_ = _tmp73_;
			_tmp75_ = vala_get_ccode_name ((ValaCodeNode*) param);
			_tmp76_ = _tmp75_;
			_tmp77_ = vala_ccode_member_access_new_pointer (_tmp74_, _tmp76_);
			_vala_ccode_node_unref0 (_tmp69_->cvalue);
			_tmp69_->cvalue = (ValaCCodeExpression*) _tmp77_;
			_g_free0 (_tmp76_);
			_vala_ccode_node_unref0 (_tmp74_);
			_g_free0 (_tmp72_);
			_tmp79_ = array_type;
			if (_tmp79_ != NULL) {
				_tmp78_ = vala_get_ccode_array_length ((ValaCodeNode*) param);
			} else {
				_tmp78_ = FALSE;
			}
			if (_tmp78_) {
				{
					gint dim = 0;
					dim = 1;
					{
						gboolean _tmp80_ = FALSE;
						_tmp80_ = TRUE;
						while (TRUE) {
							ValaArrayType* _tmp82_;
							gint _tmp83_;
							gint _tmp84_;
							ValaGLibValue* _tmp85_;
							ValaBlock* _tmp86_;
							gchar* _tmp87_;
							gchar* _tmp88_;
							ValaCCodeExpression* _tmp89_;
							ValaCCodeExpression* _tmp90_;
							gchar* _tmp91_;
							gchar* _tmp92_;
							ValaCCodeMemberAccess* _tmp93_;
							ValaCCodeMemberAccess* _tmp94_;
							if (!_tmp80_) {
								gint _tmp81_;
								_tmp81_ = dim;
								dim = _tmp81_ + 1;
							}
							_tmp80_ = FALSE;
							_tmp82_ = array_type;
							_tmp83_ = vala_array_type_get_rank (_tmp82_);
							_tmp84_ = _tmp83_;
							if (!(dim <= _tmp84_)) {
								break;
							}
							_tmp85_ = _result_;
							_tmp86_ = block;
							_tmp87_ = g_strdup_printf ("_data%d_", vala_ccode_base_module_get_block_id ((ValaCCodeBaseModule*) self, _tmp86_));
							_tmp88_ = _tmp87_;
							_tmp89_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp88_);
							_tmp90_ = _tmp89_;
							_tmp91_ = vala_ccode_base_module_get_variable_array_length_cname ((ValaCCodeBaseModule*) self, (ValaVariable*) param, dim);
							_tmp92_ = _tmp91_;
							_tmp93_ = vala_ccode_member_access_new_pointer (_tmp90_, _tmp92_);
							_tmp94_ = _tmp93_;
							vala_glib_value_append_array_length_cvalue (_tmp85_, (ValaCCodeExpression*) _tmp94_);
							_vala_ccode_node_unref0 (_tmp94_);
							_g_free0 (_tmp92_);
							_vala_ccode_node_unref0 (_tmp90_);
							_g_free0 (_tmp88_);
						}
					}
				}
			} else {
				gboolean _tmp95_ = FALSE;
				ValaDelegateType* _tmp96_;
				_tmp96_ = delegate_type;
				if (_tmp96_ != NULL) {
					ValaDelegateType* _tmp97_;
					ValaDelegate* _tmp98_;
					ValaDelegate* _tmp99_;
					gboolean _tmp100_;
					gboolean _tmp101_;
					_tmp97_ = delegate_type;
					_tmp98_ = vala_delegate_type_get_delegate_symbol (_tmp97_);
					_tmp99_ = _tmp98_;
					_tmp100_ = vala_delegate_get_has_target (_tmp99_);
					_tmp101_ = _tmp100_;
					_tmp95_ = _tmp101_;
				} else {
					_tmp95_ = FALSE;
				}
				if (_tmp95_) {
					ValaGLibValue* _tmp102_;
					ValaBlock* _tmp103_;
					gchar* _tmp104_;
					gchar* _tmp105_;
					ValaCCodeExpression* _tmp106_;
					ValaCCodeExpression* _tmp107_;
					gchar* _tmp108_;
					gchar* _tmp109_;
					ValaCCodeMemberAccess* _tmp110_;
					ValaGLibValue* _tmp111_;
					ValaDataType* _tmp112_;
					ValaDataType* _tmp113_;
					_tmp102_ = _result_;
					_tmp103_ = block;
					_tmp104_ = g_strdup_printf ("_data%d_", vala_ccode_base_module_get_block_id ((ValaCCodeBaseModule*) self, _tmp103_));
					_tmp105_ = _tmp104_;
					_tmp106_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp105_);
					_tmp107_ = _tmp106_;
					_tmp108_ = vala_get_ccode_delegate_target_name ((ValaVariable*) param);
					_tmp109_ = _tmp108_;
					_tmp110_ = vala_ccode_member_access_new_pointer (_tmp107_, _tmp109_);
					_vala_ccode_node_unref0 (_tmp102_->delegate_target_cvalue);
					_tmp102_->delegate_target_cvalue = (ValaCCodeExpression*) _tmp110_;
					_g_free0 (_tmp109_);
					_vala_ccode_node_unref0 (_tmp107_);
					_g_free0 (_tmp105_);
					_tmp111_ = _result_;
					_tmp112_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp111_);
					_tmp113_ = _tmp112_;
					if (vala_data_type_is_disposable (_tmp113_)) {
						ValaGLibValue* _tmp114_;
						ValaBlock* _tmp115_;
						gchar* _tmp116_;
						gchar* _tmp117_;
						ValaCCodeExpression* _tmp118_;
						ValaCCodeExpression* _tmp119_;
						gchar* _tmp120_;
						gchar* _tmp121_;
						ValaCCodeMemberAccess* _tmp122_;
						_tmp114_ = _result_;
						_tmp115_ = block;
						_tmp116_ = g_strdup_printf ("_data%d_", vala_ccode_base_module_get_block_id ((ValaCCodeBaseModule*) self, _tmp115_));
						_tmp117_ = _tmp116_;
						_tmp118_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp117_);
						_tmp119_ = _tmp118_;
						_tmp120_ = vala_get_ccode_delegate_target_destroy_notify_name ((ValaVariable*) param);
						_tmp121_ = _tmp120_;
						_tmp122_ = vala_ccode_member_access_new_pointer (_tmp119_, _tmp121_);
						_vala_ccode_node_unref0 (_tmp114_->delegate_target_destroy_notify_cvalue);
						_tmp114_->delegate_target_destroy_notify_cvalue = (ValaCCodeExpression*) _tmp122_;
						_g_free0 (_tmp121_);
						_vala_ccode_node_unref0 (_tmp119_);
						_g_free0 (_tmp117_);
					}
				}
			}
			_vala_code_node_unref0 (block);
		} else {
			if (vala_ccode_base_module_is_in_coroutine ((ValaCCodeBaseModule*) self)) {
				ValaGLibValue* _tmp123_;
				ValaCCodeExpression* _tmp124_;
				gboolean _tmp125_ = FALSE;
				ValaDelegateType* _tmp126_;
				_tmp123_ = _result_;
				_tmp124_ = vala_ccode_base_module_get_parameter_cexpression ((ValaCCodeBaseModule*) self, param);
				_vala_ccode_node_unref0 (_tmp123_->cvalue);
				_tmp123_->cvalue = _tmp124_;
				_tmp126_ = delegate_type;
				if (_tmp126_ != NULL) {
					ValaDelegateType* _tmp127_;
					ValaDelegate* _tmp128_;
					ValaDelegate* _tmp129_;
					gboolean _tmp130_;
					gboolean _tmp131_;
					_tmp127_ = delegate_type;
					_tmp128_ = vala_delegate_type_get_delegate_symbol (_tmp127_);
					_tmp129_ = _tmp128_;
					_tmp130_ = vala_delegate_get_has_target (_tmp129_);
					_tmp131_ = _tmp130_;
					_tmp125_ = _tmp131_;
				} else {
					_tmp125_ = FALSE;
				}
				if (_tmp125_) {
					ValaGLibValue* _tmp132_;
					gchar* _tmp133_;
					gchar* _tmp134_;
					ValaCCodeExpression* _tmp135_;
					ValaDelegateType* _tmp136_;
					_tmp132_ = _result_;
					_tmp133_ = vala_get_ccode_delegate_target_name ((ValaVariable*) param);
					_tmp134_ = _tmp133_;
					_tmp135_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp134_);
					_vala_ccode_node_unref0 (_tmp132_->delegate_target_cvalue);
					_tmp132_->delegate_target_cvalue = _tmp135_;
					_g_free0 (_tmp134_);
					_tmp136_ = delegate_type;
					if (vala_data_type_is_disposable ((ValaDataType*) _tmp136_)) {
						ValaGLibValue* _tmp137_;
						gchar* _tmp138_;
						gchar* _tmp139_;
						ValaCCodeExpression* _tmp140_;
						_tmp137_ = _result_;
						_tmp138_ = vala_get_ccode_delegate_target_destroy_notify_name ((ValaVariable*) param);
						_tmp139_ = _tmp138_;
						_tmp140_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp139_);
						_vala_ccode_node_unref0 (_tmp137_->delegate_target_destroy_notify_cvalue);
						_tmp137_->delegate_target_destroy_notify_cvalue = _tmp140_;
						_g_free0 (_tmp139_);
					}
				}
			} else {
				ValaStruct* type_as_struct = NULL;
				ValaGLibValue* _tmp141_;
				ValaDataType* _tmp142_;
				ValaDataType* _tmp143_;
				ValaTypeSymbol* _tmp144_;
				ValaTypeSymbol* _tmp145_;
				ValaParameterDirection _tmp146_;
				ValaParameterDirection _tmp147_;
				gboolean _tmp150_ = FALSE;
				ValaParameterDirection _tmp151_;
				ValaParameterDirection _tmp152_;
				gboolean _tmp173_ = FALSE;
				gboolean _tmp174_ = FALSE;
				_tmp141_ = _result_;
				_tmp142_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp141_);
				_tmp143_ = _tmp142_;
				_tmp144_ = vala_data_type_get_type_symbol (_tmp143_);
				_tmp145_ = _tmp144_;
				type_as_struct = G_TYPE_CHECK_INSTANCE_TYPE (_tmp145_, VALA_TYPE_STRUCT) ? ((ValaStruct*) _tmp145_) : NULL;
				_tmp146_ = vala_parameter_get_direction (param);
				_tmp147_ = _tmp146_;
				if (_tmp147_ == VALA_PARAMETER_DIRECTION_OUT) {
					const gchar* _tmp148_;
					gchar* _tmp149_;
					_tmp148_ = name;
					_tmp149_ = g_strdup_printf ("_vala_%s", _tmp148_);
					_g_free0 (name);
					name = _tmp149_;
				}
				_tmp151_ = vala_parameter_get_direction (param);
				_tmp152_ = _tmp151_;
				if (_tmp152_ == VALA_PARAMETER_DIRECTION_REF) {
					_tmp150_ = TRUE;
				} else {
					gboolean _tmp153_ = FALSE;
					gboolean _tmp154_ = FALSE;
					gboolean _tmp155_ = FALSE;
					ValaParameterDirection _tmp156_;
					ValaParameterDirection _tmp157_;
					_tmp156_ = vala_parameter_get_direction (param);
					_tmp157_ = _tmp156_;
					if (_tmp157_ == VALA_PARAMETER_DIRECTION_IN) {
						ValaStruct* _tmp158_;
						_tmp158_ = type_as_struct;
						_tmp155_ = _tmp158_ != NULL;
					} else {
						_tmp155_ = FALSE;
					}
					if (_tmp155_) {
						ValaStruct* _tmp159_;
						_tmp159_ = type_as_struct;
						_tmp154_ = !vala_struct_is_simple_type (_tmp159_);
					} else {
						_tmp154_ = FALSE;
					}
					if (_tmp154_) {
						ValaGLibValue* _tmp160_;
						ValaDataType* _tmp161_;
						ValaDataType* _tmp162_;
						gboolean _tmp163_;
						gboolean _tmp164_;
						_tmp160_ = _result_;
						_tmp161_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp160_);
						_tmp162_ = _tmp161_;
						_tmp163_ = vala_data_type_get_nullable (_tmp162_);
						_tmp164_ = _tmp163_;
						_tmp153_ = !_tmp164_;
					} else {
						_tmp153_ = FALSE;
					}
					_tmp150_ = _tmp153_;
				}
				if (_tmp150_) {
					ValaGLibValue* _tmp165_;
					const gchar* _tmp166_;
					ValaCCodeIdentifier* _tmp167_;
					ValaCCodeIdentifier* _tmp168_;
					ValaCCodeUnaryExpression* _tmp169_;
					_tmp165_ = _result_;
					_tmp166_ = name;
					_tmp167_ = vala_ccode_identifier_new (_tmp166_);
					_tmp168_ = _tmp167_;
					_tmp169_ = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_POINTER_INDIRECTION, (ValaCCodeExpression*) _tmp168_);
					_vala_ccode_node_unref0 (_tmp165_->cvalue);
					_tmp165_->cvalue = (ValaCCodeExpression*) _tmp169_;
					_vala_ccode_node_unref0 (_tmp168_);
				} else {
					ValaGLibValue* _tmp170_;
					const gchar* _tmp171_;
					ValaCCodeExpression* _tmp172_;
					_tmp170_ = _result_;
					_tmp171_ = name;
					_tmp172_ = vala_ccode_base_module_get_variable_cexpression ((ValaCCodeBaseModule*) self, _tmp171_);
					_vala_ccode_node_unref0 (_tmp170_->cvalue);
					_tmp170_->cvalue = _tmp172_;
				}
				if (vala_get_ccode_delegate_target ((ValaCodeNode*) param)) {
					ValaDelegateType* _tmp175_;
					_tmp175_ = delegate_type;
					_tmp174_ = _tmp175_ != NULL;
				} else {
					_tmp174_ = FALSE;
				}
				if (_tmp174_) {
					ValaDelegateType* _tmp176_;
					ValaDelegate* _tmp177_;
					ValaDelegate* _tmp178_;
					gboolean _tmp179_;
					gboolean _tmp180_;
					_tmp176_ = delegate_type;
					_tmp177_ = vala_delegate_type_get_delegate_symbol (_tmp176_);
					_tmp178_ = _tmp177_;
					_tmp179_ = vala_delegate_get_has_target (_tmp178_);
					_tmp180_ = _tmp179_;
					_tmp173_ = _tmp180_;
				} else {
					_tmp173_ = FALSE;
				}
				if (_tmp173_) {
					gchar* target_cname = NULL;
					gchar* _tmp181_;
					gchar* destroy_cname = NULL;
					gchar* _tmp182_;
					ValaParameterDirection _tmp183_;
					ValaParameterDirection _tmp184_;
					ValaCCodeExpression* target_expr = NULL;
					const gchar* _tmp189_;
					ValaCCodeIdentifier* _tmp190_;
					ValaCCodeExpression* delegate_target_destroy_notify = NULL;
					const gchar* _tmp191_;
					ValaCCodeIdentifier* _tmp192_;
					ValaParameterDirection _tmp193_;
					ValaParameterDirection _tmp194_;
					ValaGLibValue* _tmp199_;
					ValaCCodeExpression* _tmp200_;
					ValaCCodeExpression* _tmp201_;
					ValaGLibValue* _tmp202_;
					ValaDataType* _tmp203_;
					ValaDataType* _tmp204_;
					_tmp181_ = vala_get_ccode_delegate_target_name ((ValaVariable*) param);
					target_cname = _tmp181_;
					_tmp182_ = vala_get_ccode_delegate_target_destroy_notify_name ((ValaVariable*) param);
					destroy_cname = _tmp182_;
					_tmp183_ = vala_parameter_get_direction (param);
					_tmp184_ = _tmp183_;
					if (_tmp184_ == VALA_PARAMETER_DIRECTION_OUT) {
						const gchar* _tmp185_;
						gchar* _tmp186_;
						const gchar* _tmp187_;
						gchar* _tmp188_;
						_tmp185_ = target_cname;
						_tmp186_ = g_strdup_printf ("_vala_%s", _tmp185_);
						_g_free0 (target_cname);
						target_cname = _tmp186_;
						_tmp187_ = destroy_cname;
						_tmp188_ = g_strdup_printf ("_vala_%s", _tmp187_);
						_g_free0 (destroy_cname);
						destroy_cname = _tmp188_;
					}
					_tmp189_ = target_cname;
					_tmp190_ = vala_ccode_identifier_new (_tmp189_);
					target_expr = (ValaCCodeExpression*) _tmp190_;
					_tmp191_ = destroy_cname;
					_tmp192_ = vala_ccode_identifier_new (_tmp191_);
					delegate_target_destroy_notify = (ValaCCodeExpression*) _tmp192_;
					_tmp193_ = vala_parameter_get_direction (param);
					_tmp194_ = _tmp193_;
					if (_tmp194_ == VALA_PARAMETER_DIRECTION_REF) {
						ValaCCodeExpression* _tmp195_;
						ValaCCodeUnaryExpression* _tmp196_;
						ValaCCodeExpression* _tmp197_;
						ValaCCodeUnaryExpression* _tmp198_;
						_tmp195_ = target_expr;
						_tmp196_ = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_POINTER_INDIRECTION, _tmp195_);
						_vala_ccode_node_unref0 (target_expr);
						target_expr = (ValaCCodeExpression*) _tmp196_;
						_tmp197_ = delegate_target_destroy_notify;
						_tmp198_ = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_POINTER_INDIRECTION, _tmp197_);
						_vala_ccode_node_unref0 (delegate_target_destroy_notify);
						delegate_target_destroy_notify = (ValaCCodeExpression*) _tmp198_;
					}
					_tmp199_ = _result_;
					_tmp200_ = target_expr;
					_tmp201_ = _vala_ccode_node_ref0 (_tmp200_);
					_vala_ccode_node_unref0 (_tmp199_->delegate_target_cvalue);
					_tmp199_->delegate_target_cvalue = _tmp201_;
					_tmp202_ = _result_;
					_tmp203_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp202_);
					_tmp204_ = _tmp203_;
					if (vala_data_type_is_disposable (_tmp204_)) {
						ValaGLibValue* _tmp205_;
						ValaCCodeExpression* _tmp206_;
						ValaCCodeExpression* _tmp207_;
						_tmp205_ = _result_;
						_tmp206_ = delegate_target_destroy_notify;
						_tmp207_ = _vala_ccode_node_ref0 (_tmp206_);
						_vala_ccode_node_unref0 (_tmp205_->delegate_target_destroy_notify_cvalue);
						_tmp205_->delegate_target_destroy_notify_cvalue = _tmp207_;
					}
					_vala_ccode_node_unref0 (delegate_target_destroy_notify);
					_vala_ccode_node_unref0 (target_expr);
					_g_free0 (destroy_cname);
					_g_free0 (target_cname);
				}
			}
		}
		_tmp209_ = vala_parameter_get_captured (param);
		_tmp210_ = _tmp209_;
		if (!_tmp210_) {
			ValaArrayType* _tmp211_;
			_tmp211_ = array_type;
			_tmp208_ = _tmp211_ != NULL;
		} else {
			_tmp208_ = FALSE;
		}
		if (_tmp208_) {
			gboolean _tmp212_ = FALSE;
			if (vala_get_ccode_array_length ((ValaCodeNode*) param)) {
				_tmp212_ = !vala_get_ccode_array_null_terminated ((ValaCodeNode*) param);
			} else {
				_tmp212_ = FALSE;
			}
			if (_tmp212_) {
				{
					gint dim = 0;
					dim = 1;
					{
						gboolean _tmp213_ = FALSE;
						_tmp213_ = TRUE;
						while (TRUE) {
							ValaArrayType* _tmp215_;
							gint _tmp216_;
							gint _tmp217_;
							ValaCCodeExpression* length_expr = NULL;
							gchar* _tmp218_;
							gchar* _tmp219_;
							ValaCCodeExpression* _tmp220_;
							ValaCCodeExpression* _tmp221_;
							ValaParameterDirection _tmp222_;
							ValaParameterDirection _tmp223_;
							ValaGLibValue* _tmp232_;
							ValaCCodeExpression* _tmp233_;
							if (!_tmp213_) {
								gint _tmp214_;
								_tmp214_ = dim;
								dim = _tmp214_ + 1;
							}
							_tmp213_ = FALSE;
							_tmp215_ = array_type;
							_tmp216_ = vala_array_type_get_rank (_tmp215_);
							_tmp217_ = _tmp216_;
							if (!(dim <= _tmp217_)) {
								break;
							}
							_tmp218_ = vala_ccode_base_module_get_variable_array_length_cname ((ValaCCodeBaseModule*) self, (ValaVariable*) param, dim);
							_tmp219_ = _tmp218_;
							_tmp220_ = vala_ccode_base_module_get_cexpression ((ValaCCodeBaseModule*) self, _tmp219_);
							_tmp221_ = _tmp220_;
							_g_free0 (_tmp219_);
							length_expr = _tmp221_;
							_tmp222_ = vala_parameter_get_direction (param);
							_tmp223_ = _tmp222_;
							if (_tmp223_ == VALA_PARAMETER_DIRECTION_OUT) {
								const gchar* _tmp224_;
								gchar* _tmp225_;
								gchar* _tmp226_;
								ValaCCodeExpression* _tmp227_;
								_tmp224_ = name;
								_tmp225_ = vala_ccode_base_module_get_array_length_cname ((ValaCCodeBaseModule*) self, _tmp224_, dim);
								_tmp226_ = _tmp225_;
								_tmp227_ = vala_ccode_base_module_get_cexpression ((ValaCCodeBaseModule*) self, _tmp226_);
								_vala_ccode_node_unref0 (length_expr);
								length_expr = _tmp227_;
								_g_free0 (_tmp226_);
							} else {
								ValaParameterDirection _tmp228_;
								ValaParameterDirection _tmp229_;
								_tmp228_ = vala_parameter_get_direction (param);
								_tmp229_ = _tmp228_;
								if (_tmp229_ == VALA_PARAMETER_DIRECTION_REF) {
									ValaCCodeExpression* _tmp230_;
									ValaCCodeUnaryExpression* _tmp231_;
									_tmp230_ = length_expr;
									_tmp231_ = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_POINTER_INDIRECTION, _tmp230_);
									_vala_ccode_node_unref0 (length_expr);
									length_expr = (ValaCCodeExpression*) _tmp231_;
								}
							}
							_tmp232_ = _result_;
							_tmp233_ = length_expr;
							vala_glib_value_append_array_length_cvalue (_tmp232_, _tmp233_);
							_vala_ccode_node_unref0 (length_expr);
						}
					}
				}
			}
		}
		_g_free0 (name);
	}
	result = (ValaTargetValue*) _result_;
	_vala_code_node_unref0 (delegate_type);
	_vala_code_node_unref0 (array_type);
	return result;
}

static ValaTargetValue*
vala_ccode_member_access_module_real_get_field_cvalue (ValaCCodeBaseModule* base,
                                                       ValaField* field,
                                                       ValaTargetValue* instance)
{
	ValaCCodeMemberAccessModule * self;
	ValaDataType* value_type = NULL;
	ValaDataType* _tmp0_;
	ValaDataType* _tmp1_;
	ValaDataType* _tmp2_;
	ValaGLibValue* _result_ = NULL;
	ValaDataType* _tmp3_;
	ValaGLibValue* _tmp4_;
	ValaGLibValue* _tmp12_;
	ValaGLibValue* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	gboolean _tmp16_;
	ValaGLibValue* _tmp21_;
	gchar* _tmp22_;
	ValaArrayType* array_type = NULL;
	ValaGLibValue* _tmp23_;
	ValaDataType* _tmp24_;
	ValaDataType* _tmp25_;
	ValaArrayType* _tmp26_;
	ValaMemberBinding _tmp27_;
	ValaMemberBinding _tmp28_;
	ValaTargetValue* result;
	self = (ValaCCodeMemberAccessModule*) base;
	g_return_val_if_fail (field != NULL, NULL);
	_tmp0_ = vala_variable_get_variable_type ((ValaVariable*) field);
	_tmp1_ = _tmp0_;
	_tmp2_ = vala_data_type_copy (_tmp1_);
	value_type = _tmp2_;
	_tmp3_ = value_type;
	_tmp4_ = vala_glib_value_new (_tmp3_, NULL, FALSE);
	_result_ = _tmp4_;
	if (instance != NULL) {
		ValaGLibValue* _tmp5_;
		ValaDataType* _tmp6_;
		ValaDataType* _tmp7_;
		ValaDataType* _tmp8_;
		ValaDataType* _tmp9_;
		ValaDataType* _tmp10_;
		ValaDataType* _tmp11_;
		_tmp5_ = _result_;
		_tmp6_ = vala_variable_get_variable_type ((ValaVariable*) field);
		_tmp7_ = _tmp6_;
		_tmp8_ = vala_target_value_get_value_type (instance);
		_tmp9_ = _tmp8_;
		_tmp10_ = vala_data_type_get_actual_type (_tmp7_, _tmp9_, NULL, (ValaCodeNode*) field);
		_tmp11_ = _tmp10_;
		vala_target_value_set_actual_value_type ((ValaTargetValue*) _tmp5_, _tmp11_);
		_vala_code_node_unref0 (_tmp11_);
	}
	_tmp12_ = _result_;
	_tmp12_->lvalue = TRUE;
	_tmp13_ = _result_;
	_tmp13_->array_null_terminated = vala_get_ccode_array_null_terminated ((ValaCodeNode*) field);
	_tmp14_ = vala_get_ccode_array_length_expr ((ValaCodeNode*) field);
	_tmp15_ = _tmp14_;
	_tmp16_ = _tmp15_ != NULL;
	_g_free0 (_tmp15_);
	if (_tmp16_) {
		ValaGLibValue* _tmp17_;
		gchar* _tmp18_;
		gchar* _tmp19_;
		ValaCCodeConstant* _tmp20_;
		_tmp17_ = _result_;
		_tmp18_ = vala_get_ccode_array_length_expr ((ValaCodeNode*) field);
		_tmp19_ = _tmp18_;
		_tmp20_ = vala_ccode_constant_new (_tmp19_);
		_vala_ccode_node_unref0 (_tmp17_->array_length_cexpr);
		_tmp17_->array_length_cexpr = (ValaCCodeExpression*) _tmp20_;
		_g_free0 (_tmp19_);
	}
	_tmp21_ = _result_;
	_tmp22_ = vala_get_ccode_type ((ValaCodeNode*) field);
	_g_free0 (_tmp21_->ctype);
	_tmp21_->ctype = _tmp22_;
	_tmp23_ = _result_;
	_tmp24_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp23_);
	_tmp25_ = _tmp24_;
	_tmp26_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp25_, VALA_TYPE_ARRAY_TYPE) ? ((ValaArrayType*) _tmp25_) : NULL);
	array_type = _tmp26_;
	_tmp27_ = vala_field_get_binding (field);
	_tmp28_ = _tmp27_;
	if (_tmp28_ == VALA_MEMBER_BINDING_INSTANCE) {
		ValaCCodeExpression* pub_inst = NULL;
		ValaDataType* instance_target_type = NULL;
		ValaSymbol* _tmp31_;
		ValaSymbol* _tmp32_;
		ValaDataType* _tmp33_;
		ValaClass* cl = NULL;
		ValaDataType* _tmp34_;
		ValaTypeSymbol* _tmp35_;
		ValaTypeSymbol* _tmp36_;
		gboolean _tmp37_ = FALSE;
		ValaDataType* _tmp38_;
		ValaTypeSymbol* _tmp39_;
		ValaTypeSymbol* _tmp40_;
		ValaClass* _tmp41_;
		gboolean is_gtypeinstance = FALSE;
		ValaCCodeExpression* inst = NULL;
		gboolean _tmp47_ = FALSE;
		ValaCCodeExpression* _tmp57_;
		gboolean _tmp64_ = FALSE;
		ValaDataType* _tmp65_;
		ValaTypeSymbol* _tmp66_;
		ValaTypeSymbol* _tmp67_;
		gboolean _tmp81_ = FALSE;
		ValaArrayType* _tmp82_;
		pub_inst = NULL;
		if (instance != NULL) {
			ValaCCodeExpression* _tmp29_;
			ValaCCodeExpression* _tmp30_;
			_tmp29_ = vala_get_cvalue_ (instance);
			_tmp30_ = _vala_ccode_node_ref0 (_tmp29_);
			_vala_ccode_node_unref0 (pub_inst);
			pub_inst = _tmp30_;
		}
		_tmp31_ = vala_symbol_get_parent_symbol ((ValaSymbol*) field);
		_tmp32_ = _tmp31_;
		_tmp33_ = vala_semantic_analyzer_get_data_type_for_symbol (_tmp32_);
		instance_target_type = _tmp33_;
		_tmp34_ = instance_target_type;
		_tmp35_ = vala_data_type_get_type_symbol (_tmp34_);
		_tmp36_ = _tmp35_;
		cl = G_TYPE_CHECK_INSTANCE_TYPE (_tmp36_, VALA_TYPE_CLASS) ? ((ValaClass*) _tmp36_) : NULL;
		_tmp38_ = instance_target_type;
		_tmp39_ = vala_data_type_get_type_symbol (_tmp38_);
		_tmp40_ = _tmp39_;
		_tmp41_ = cl;
		if (_tmp40_ == G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, VALA_TYPE_TYPESYMBOL, ValaTypeSymbol)) {
			gboolean _tmp42_ = FALSE;
			ValaClass* _tmp43_;
			_tmp43_ = cl;
			if (_tmp43_ == NULL) {
				_tmp42_ = TRUE;
			} else {
				ValaClass* _tmp44_;
				gboolean _tmp45_;
				gboolean _tmp46_;
				_tmp44_ = cl;
				_tmp45_ = vala_class_get_is_compact (_tmp44_);
				_tmp46_ = _tmp45_;
				_tmp42_ = !_tmp46_;
			}
			_tmp37_ = _tmp42_;
		} else {
			_tmp37_ = FALSE;
		}
		is_gtypeinstance = _tmp37_;
		if (is_gtypeinstance) {
			ValaSymbolAccessibility _tmp48_;
			ValaSymbolAccessibility _tmp49_;
			_tmp48_ = vala_symbol_get_access ((ValaSymbol*) field);
			_tmp49_ = _tmp48_;
			_tmp47_ = _tmp49_ == VALA_SYMBOL_ACCESSIBILITY_PRIVATE;
		} else {
			_tmp47_ = FALSE;
		}
		if (_tmp47_) {
			ValaCCodeExpression* _tmp50_;
			ValaCCodeMemberAccess* _tmp51_;
			_tmp50_ = pub_inst;
			_tmp51_ = vala_ccode_member_access_new_pointer (_tmp50_, "priv");
			_vala_ccode_node_unref0 (inst);
			inst = (ValaCCodeExpression*) _tmp51_;
		} else {
			ValaClass* _tmp52_;
			ValaCCodeExpression* _tmp55_;
			ValaCCodeExpression* _tmp56_;
			_tmp52_ = cl;
			if (_tmp52_ != NULL) {
				ValaClass* _tmp53_;
				ValaCCodeFile* _tmp54_;
				_tmp53_ = cl;
				_tmp54_ = ((ValaCCodeBaseModule*) self)->cfile;
				vala_ccode_base_module_generate_class_struct_declaration ((ValaCCodeBaseModule*) self, _tmp53_, _tmp54_);
			}
			_tmp55_ = pub_inst;
			_tmp56_ = _vala_ccode_node_ref0 (_tmp55_);
			_vala_ccode_node_unref0 (inst);
			inst = _tmp56_;
		}
		_tmp57_ = inst;
		if (_tmp57_ == NULL) {
			ValaSourceReference* _tmp58_;
			ValaSourceReference* _tmp59_;
			gchar* _tmp60_;
			gchar* _tmp61_;
			ValaGLibValue* _tmp62_;
			ValaCCodeInvalidExpression* _tmp63_;
			_tmp58_ = vala_code_node_get_source_reference ((ValaCodeNode*) field);
			_tmp59_ = _tmp58_;
			_tmp60_ = vala_symbol_get_full_name ((ValaSymbol*) field);
			_tmp61_ = _tmp60_;
			vala_report_error (_tmp59_, "Invalid access to instance member `%s'", _tmp61_);
			_g_free0 (_tmp61_);
			_tmp62_ = _result_;
			_tmp63_ = vala_ccode_invalid_expression_new ();
			_vala_ccode_node_unref0 (_tmp62_->cvalue);
			_tmp62_->cvalue = (ValaCCodeExpression*) _tmp63_;
			result = (ValaTargetValue*) _result_;
			_vala_ccode_node_unref0 (inst);
			_vala_code_node_unref0 (instance_target_type);
			_vala_ccode_node_unref0 (pub_inst);
			_vala_code_node_unref0 (array_type);
			_vala_code_node_unref0 (value_type);
			return result;
		}
		_tmp65_ = instance_target_type;
		_tmp66_ = vala_data_type_get_type_symbol (_tmp65_);
		_tmp67_ = _tmp66_;
		if (vala_typesymbol_is_reference_type (_tmp67_)) {
			_tmp64_ = TRUE;
		} else {
			gboolean _tmp68_ = FALSE;
			if (instance != NULL) {
				ValaDataType* _tmp69_;
				ValaDataType* _tmp70_;
				_tmp69_ = vala_target_value_get_value_type (instance);
				_tmp70_ = _tmp69_;
				_tmp68_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp70_, VALA_TYPE_POINTER_TYPE);
			} else {
				_tmp68_ = FALSE;
			}
			_tmp64_ = _tmp68_;
		}
		if (_tmp64_) {
			ValaGLibValue* _tmp71_;
			ValaCCodeExpression* _tmp72_;
			gchar* _tmp73_;
			gchar* _tmp74_;
			ValaCCodeMemberAccess* _tmp75_;
			_tmp71_ = _result_;
			_tmp72_ = inst;
			_tmp73_ = vala_get_ccode_name ((ValaCodeNode*) field);
			_tmp74_ = _tmp73_;
			_tmp75_ = vala_ccode_member_access_new_pointer (_tmp72_, _tmp74_);
			_vala_ccode_node_unref0 (_tmp71_->cvalue);
			_tmp71_->cvalue = (ValaCCodeExpression*) _tmp75_;
			_g_free0 (_tmp74_);
		} else {
			ValaGLibValue* _tmp76_;
			ValaCCodeExpression* _tmp77_;
			gchar* _tmp78_;
			gchar* _tmp79_;
			ValaCCodeMemberAccess* _tmp80_;
			_tmp76_ = _result_;
			_tmp77_ = inst;
			_tmp78_ = vala_get_ccode_name ((ValaCodeNode*) field);
			_tmp79_ = _tmp78_;
			_tmp80_ = vala_ccode_member_access_new (_tmp77_, _tmp79_, FALSE);
			_vala_ccode_node_unref0 (_tmp76_->cvalue);
			_tmp76_->cvalue = (ValaCCodeExpression*) _tmp80_;
			_g_free0 (_tmp79_);
		}
		_tmp82_ = array_type;
		if (_tmp82_ != NULL) {
			_tmp81_ = vala_get_ccode_array_length ((ValaCodeNode*) field);
		} else {
			_tmp81_ = FALSE;
		}
		if (_tmp81_) {
			gboolean _tmp99_ = FALSE;
			ValaArrayType* _tmp100_;
			gint _tmp101_;
			gint _tmp102_;
			{
				gint dim = 0;
				dim = 1;
				{
					gboolean _tmp83_ = FALSE;
					_tmp83_ = TRUE;
					while (TRUE) {
						ValaArrayType* _tmp85_;
						gint _tmp86_;
						gint _tmp87_;
						ValaCCodeExpression* length_expr = NULL;
						gchar* length_cname = NULL;
						gchar* _tmp88_;
						ValaSymbol* _tmp89_;
						ValaSymbol* _tmp90_;
						ValaGLibValue* _tmp97_;
						ValaCCodeExpression* _tmp98_;
						if (!_tmp83_) {
							gint _tmp84_;
							_tmp84_ = dim;
							dim = _tmp84_ + 1;
						}
						_tmp83_ = FALSE;
						_tmp85_ = array_type;
						_tmp86_ = vala_array_type_get_rank (_tmp85_);
						_tmp87_ = _tmp86_;
						if (!(dim <= _tmp87_)) {
							break;
						}
						length_expr = NULL;
						_tmp88_ = vala_ccode_base_module_get_variable_array_length_cname ((ValaCCodeBaseModule*) self, (ValaVariable*) field, dim);
						length_cname = _tmp88_;
						_tmp89_ = vala_symbol_get_parent_symbol ((ValaSymbol*) field);
						_tmp90_ = _tmp89_;
						if (vala_typesymbol_is_reference_type (G_TYPE_CHECK_INSTANCE_CAST (_tmp90_, VALA_TYPE_TYPESYMBOL, ValaTypeSymbol))) {
							ValaCCodeExpression* _tmp91_;
							const gchar* _tmp92_;
							ValaCCodeMemberAccess* _tmp93_;
							_tmp91_ = inst;
							_tmp92_ = length_cname;
							_tmp93_ = vala_ccode_member_access_new_pointer (_tmp91_, _tmp92_);
							_vala_ccode_node_unref0 (length_expr);
							length_expr = (ValaCCodeExpression*) _tmp93_;
						} else {
							ValaCCodeExpression* _tmp94_;
							const gchar* _tmp95_;
							ValaCCodeMemberAccess* _tmp96_;
							_tmp94_ = inst;
							_tmp95_ = length_cname;
							_tmp96_ = vala_ccode_member_access_new (_tmp94_, _tmp95_, FALSE);
							_vala_ccode_node_unref0 (length_expr);
							length_expr = (ValaCCodeExpression*) _tmp96_;
						}
						_tmp97_ = _result_;
						_tmp98_ = length_expr;
						vala_glib_value_append_array_length_cvalue (_tmp97_, _tmp98_);
						_g_free0 (length_cname);
						_vala_ccode_node_unref0 (length_expr);
					}
				}
			}
			_tmp100_ = array_type;
			_tmp101_ = vala_array_type_get_rank (_tmp100_);
			_tmp102_ = _tmp101_;
			if (_tmp102_ == 1) {
				_tmp99_ = vala_symbol_is_internal_symbol ((ValaSymbol*) field);
			} else {
				_tmp99_ = FALSE;
			}
			if (_tmp99_) {
				gchar* size_cname = NULL;
				gchar* _tmp103_;
				gchar* _tmp104_;
				gchar* _tmp105_;
				gchar* _tmp106_;
				ValaSymbol* _tmp107_;
				ValaSymbol* _tmp108_;
				_tmp103_ = vala_get_ccode_name ((ValaCodeNode*) field);
				_tmp104_ = _tmp103_;
				_tmp105_ = vala_ccode_base_module_get_array_size_cname ((ValaCCodeBaseModule*) self, _tmp104_);
				_tmp106_ = _tmp105_;
				_g_free0 (_tmp104_);
				size_cname = _tmp106_;
				_tmp107_ = vala_symbol_get_parent_symbol ((ValaSymbol*) field);
				_tmp108_ = _tmp107_;
				if (vala_typesymbol_is_reference_type (G_TYPE_CHECK_INSTANCE_CAST (_tmp108_, VALA_TYPE_TYPESYMBOL, ValaTypeSymbol))) {
					ValaGLibValue* _tmp109_;
					ValaCCodeExpression* _tmp110_;
					const gchar* _tmp111_;
					ValaCCodeMemberAccess* _tmp112_;
					ValaCCodeMemberAccess* _tmp113_;
					_tmp109_ = _result_;
					_tmp110_ = inst;
					_tmp111_ = size_cname;
					_tmp112_ = vala_ccode_member_access_new_pointer (_tmp110_, _tmp111_);
					_tmp113_ = _tmp112_;
					vala_set_array_size_cvalue ((ValaTargetValue*) _tmp109_, (ValaCCodeExpression*) _tmp113_);
					_vala_ccode_node_unref0 (_tmp113_);
				} else {
					ValaGLibValue* _tmp114_;
					ValaCCodeExpression* _tmp115_;
					const gchar* _tmp116_;
					ValaCCodeMemberAccess* _tmp117_;
					ValaCCodeMemberAccess* _tmp118_;
					_tmp114_ = _result_;
					_tmp115_ = inst;
					_tmp116_ = size_cname;
					_tmp117_ = vala_ccode_member_access_new (_tmp115_, _tmp116_, FALSE);
					_tmp118_ = _tmp117_;
					vala_set_array_size_cvalue ((ValaTargetValue*) _tmp114_, (ValaCCodeExpression*) _tmp118_);
					_vala_ccode_node_unref0 (_tmp118_);
				}
				_g_free0 (size_cname);
			}
		} else {
			if (vala_get_ccode_delegate_target ((ValaCodeNode*) field)) {
				gchar* target_cname = NULL;
				gchar* _tmp119_;
				gchar* target_destroy_notify_cname = NULL;
				gchar* _tmp120_;
				ValaSymbol* _tmp121_;
				ValaSymbol* _tmp122_;
				_tmp119_ = vala_get_ccode_delegate_target_name ((ValaVariable*) field);
				target_cname = _tmp119_;
				_tmp120_ = vala_get_ccode_delegate_target_destroy_notify_name ((ValaVariable*) field);
				target_destroy_notify_cname = _tmp120_;
				_tmp121_ = vala_symbol_get_parent_symbol ((ValaSymbol*) field);
				_tmp122_ = _tmp121_;
				if (vala_typesymbol_is_reference_type (G_TYPE_CHECK_INSTANCE_CAST (_tmp122_, VALA_TYPE_TYPESYMBOL, ValaTypeSymbol))) {
					ValaGLibValue* _tmp123_;
					ValaCCodeExpression* _tmp124_;
					const gchar* _tmp125_;
					ValaCCodeMemberAccess* _tmp126_;
					ValaGLibValue* _tmp127_;
					ValaDataType* _tmp128_;
					ValaDataType* _tmp129_;
					_tmp123_ = _result_;
					_tmp124_ = inst;
					_tmp125_ = target_cname;
					_tmp126_ = vala_ccode_member_access_new_pointer (_tmp124_, _tmp125_);
					_vala_ccode_node_unref0 (_tmp123_->delegate_target_cvalue);
					_tmp123_->delegate_target_cvalue = (ValaCCodeExpression*) _tmp126_;
					_tmp127_ = _result_;
					_tmp128_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp127_);
					_tmp129_ = _tmp128_;
					if (vala_data_type_is_disposable (_tmp129_)) {
						ValaGLibValue* _tmp130_;
						ValaCCodeExpression* _tmp131_;
						const gchar* _tmp132_;
						ValaCCodeMemberAccess* _tmp133_;
						_tmp130_ = _result_;
						_tmp131_ = inst;
						_tmp132_ = target_destroy_notify_cname;
						_tmp133_ = vala_ccode_member_access_new_pointer (_tmp131_, _tmp132_);
						_vala_ccode_node_unref0 (_tmp130_->delegate_target_destroy_notify_cvalue);
						_tmp130_->delegate_target_destroy_notify_cvalue = (ValaCCodeExpression*) _tmp133_;
					}
				} else {
					ValaGLibValue* _tmp134_;
					ValaCCodeExpression* _tmp135_;
					const gchar* _tmp136_;
					ValaCCodeMemberAccess* _tmp137_;
					ValaGLibValue* _tmp138_;
					ValaDataType* _tmp139_;
					ValaDataType* _tmp140_;
					_tmp134_ = _result_;
					_tmp135_ = inst;
					_tmp136_ = target_cname;
					_tmp137_ = vala_ccode_member_access_new (_tmp135_, _tmp136_, FALSE);
					_vala_ccode_node_unref0 (_tmp134_->delegate_target_cvalue);
					_tmp134_->delegate_target_cvalue = (ValaCCodeExpression*) _tmp137_;
					_tmp138_ = _result_;
					_tmp139_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp138_);
					_tmp140_ = _tmp139_;
					if (vala_data_type_is_disposable (_tmp140_)) {
						ValaGLibValue* _tmp141_;
						ValaCCodeExpression* _tmp142_;
						const gchar* _tmp143_;
						ValaCCodeMemberAccess* _tmp144_;
						_tmp141_ = _result_;
						_tmp142_ = inst;
						_tmp143_ = target_destroy_notify_cname;
						_tmp144_ = vala_ccode_member_access_new (_tmp142_, _tmp143_, FALSE);
						_vala_ccode_node_unref0 (_tmp141_->delegate_target_destroy_notify_cvalue);
						_tmp141_->delegate_target_destroy_notify_cvalue = (ValaCCodeExpression*) _tmp144_;
					}
				}
				_g_free0 (target_destroy_notify_cname);
				_g_free0 (target_cname);
			}
		}
		_vala_ccode_node_unref0 (inst);
		_vala_code_node_unref0 (instance_target_type);
		_vala_ccode_node_unref0 (pub_inst);
	} else {
		ValaMemberBinding _tmp145_;
		ValaMemberBinding _tmp146_;
		_tmp145_ = vala_field_get_binding (field);
		_tmp146_ = _tmp145_;
		if (_tmp146_ == VALA_MEMBER_BINDING_CLASS) {
			ValaClass* cl = NULL;
			ValaSymbol* _tmp147_;
			ValaSymbol* _tmp148_;
			ValaCCodeExpression* cast = NULL;
			ValaClass* _tmp149_;
			ValaCCodeExpression* _tmp150_;
			ValaSymbolAccessibility _tmp151_;
			ValaSymbolAccessibility _tmp152_;
			_tmp147_ = vala_symbol_get_parent_symbol ((ValaSymbol*) field);
			_tmp148_ = _tmp147_;
			cl = G_TYPE_CHECK_INSTANCE_CAST (_tmp148_, VALA_TYPE_CLASS, ValaClass);
			_tmp149_ = cl;
			_tmp150_ = vala_ccode_base_module_get_this_class_cexpression ((ValaCCodeBaseModule*) self, _tmp149_, instance);
			cast = _tmp150_;
			_tmp151_ = vala_symbol_get_access ((ValaSymbol*) field);
			_tmp152_ = _tmp151_;
			if (_tmp152_ == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
				ValaCCodeFunctionCall* ccall = NULL;
				ValaClass* _tmp153_;
				gchar* _tmp154_;
				gchar* _tmp155_;
				ValaCCodeIdentifier* _tmp156_;
				ValaCCodeIdentifier* _tmp157_;
				ValaCCodeFunctionCall* _tmp158_;
				ValaCCodeFunctionCall* _tmp159_;
				ValaCCodeFunctionCall* _tmp160_;
				ValaCCodeExpression* _tmp161_;
				ValaGLibValue* _tmp162_;
				ValaCCodeFunctionCall* _tmp163_;
				gchar* _tmp164_;
				gchar* _tmp165_;
				ValaCCodeMemberAccess* _tmp166_;
				_tmp153_ = cl;
				_tmp154_ = vala_get_ccode_class_get_private_function (_tmp153_);
				_tmp155_ = _tmp154_;
				_tmp156_ = vala_ccode_identifier_new (_tmp155_);
				_tmp157_ = _tmp156_;
				_tmp158_ = vala_ccode_function_call_new ((ValaCCodeExpression*) _tmp157_);
				_tmp159_ = _tmp158_;
				_vala_ccode_node_unref0 (_tmp157_);
				_g_free0 (_tmp155_);
				ccall = _tmp159_;
				_tmp160_ = ccall;
				_tmp161_ = cast;
				vala_ccode_function_call_add_argument (_tmp160_, _tmp161_);
				_tmp162_ = _result_;
				_tmp163_ = ccall;
				_tmp164_ = vala_get_ccode_name ((ValaCodeNode*) field);
				_tmp165_ = _tmp164_;
				_tmp166_ = vala_ccode_member_access_new_pointer ((ValaCCodeExpression*) _tmp163_, _tmp165_);
				_vala_ccode_node_unref0 (_tmp162_->cvalue);
				_tmp162_->cvalue = (ValaCCodeExpression*) _tmp166_;
				_g_free0 (_tmp165_);
				_vala_ccode_node_unref0 (ccall);
			} else {
				ValaGLibValue* _tmp167_;
				ValaCCodeExpression* _tmp168_;
				gchar* _tmp169_;
				gchar* _tmp170_;
				ValaCCodeMemberAccess* _tmp171_;
				_tmp167_ = _result_;
				_tmp168_ = cast;
				_tmp169_ = vala_get_ccode_name ((ValaCodeNode*) field);
				_tmp170_ = _tmp169_;
				_tmp171_ = vala_ccode_member_access_new_pointer (_tmp168_, _tmp170_);
				_vala_ccode_node_unref0 (_tmp167_->cvalue);
				_tmp167_->cvalue = (ValaCCodeExpression*) _tmp171_;
				_g_free0 (_tmp170_);
			}
			_vala_ccode_node_unref0 (cast);
		} else {
			ValaCCodeFile* _tmp172_;
			ValaGLibValue* _tmp173_;
			gchar* _tmp174_;
			gchar* _tmp175_;
			ValaCCodeIdentifier* _tmp176_;
			gboolean _tmp177_ = FALSE;
			ValaArrayType* _tmp178_;
			_tmp172_ = ((ValaCCodeBaseModule*) self)->cfile;
			vala_ccode_base_module_generate_field_declaration ((ValaCCodeBaseModule*) self, field, _tmp172_);
			_tmp173_ = _result_;
			_tmp174_ = vala_get_ccode_name ((ValaCodeNode*) field);
			_tmp175_ = _tmp174_;
			_tmp176_ = vala_ccode_identifier_new (_tmp175_);
			_vala_ccode_node_unref0 (_tmp173_->cvalue);
			_tmp173_->cvalue = (ValaCCodeExpression*) _tmp176_;
			_g_free0 (_tmp175_);
			_tmp178_ = array_type;
			if (_tmp178_ != NULL) {
				_tmp177_ = vala_get_ccode_array_length ((ValaCodeNode*) field);
			} else {
				_tmp177_ = FALSE;
			}
			if (_tmp177_) {
				gboolean _tmp189_ = FALSE;
				ValaArrayType* _tmp190_;
				gint _tmp191_;
				gint _tmp192_;
				{
					gint dim = 0;
					dim = 1;
					{
						gboolean _tmp179_ = FALSE;
						_tmp179_ = TRUE;
						while (TRUE) {
							ValaArrayType* _tmp181_;
							gint _tmp182_;
							gint _tmp183_;
							gchar* length_cname = NULL;
							gchar* _tmp184_;
							ValaGLibValue* _tmp185_;
							const gchar* _tmp186_;
							ValaCCodeIdentifier* _tmp187_;
							ValaCCodeIdentifier* _tmp188_;
							if (!_tmp179_) {
								gint _tmp180_;
								_tmp180_ = dim;
								dim = _tmp180_ + 1;
							}
							_tmp179_ = FALSE;
							_tmp181_ = array_type;
							_tmp182_ = vala_array_type_get_rank (_tmp181_);
							_tmp183_ = _tmp182_;
							if (!(dim <= _tmp183_)) {
								break;
							}
							_tmp184_ = vala_ccode_base_module_get_variable_array_length_cname ((ValaCCodeBaseModule*) self, (ValaVariable*) field, dim);
							length_cname = _tmp184_;
							_tmp185_ = _result_;
							_tmp186_ = length_cname;
							_tmp187_ = vala_ccode_identifier_new (_tmp186_);
							_tmp188_ = _tmp187_;
							vala_glib_value_append_array_length_cvalue (_tmp185_, (ValaCCodeExpression*) _tmp188_);
							_vala_ccode_node_unref0 (_tmp188_);
							_g_free0 (length_cname);
						}
					}
				}
				_tmp190_ = array_type;
				_tmp191_ = vala_array_type_get_rank (_tmp190_);
				_tmp192_ = _tmp191_;
				if (_tmp192_ == 1) {
					_tmp189_ = vala_symbol_is_internal_symbol ((ValaSymbol*) field);
				} else {
					_tmp189_ = FALSE;
				}
				if (_tmp189_) {
					ValaGLibValue* _tmp193_;
					gchar* _tmp194_;
					gchar* _tmp195_;
					gchar* _tmp196_;
					gchar* _tmp197_;
					ValaCCodeIdentifier* _tmp198_;
					ValaCCodeIdentifier* _tmp199_;
					_tmp193_ = _result_;
					_tmp194_ = vala_get_ccode_name ((ValaCodeNode*) field);
					_tmp195_ = _tmp194_;
					_tmp196_ = vala_ccode_base_module_get_array_size_cname ((ValaCCodeBaseModule*) self, _tmp195_);
					_tmp197_ = _tmp196_;
					_tmp198_ = vala_ccode_identifier_new (_tmp197_);
					_tmp199_ = _tmp198_;
					vala_set_array_size_cvalue ((ValaTargetValue*) _tmp193_, (ValaCCodeExpression*) _tmp199_);
					_vala_ccode_node_unref0 (_tmp199_);
					_g_free0 (_tmp197_);
					_g_free0 (_tmp195_);
				}
			} else {
				if (vala_get_ccode_delegate_target ((ValaCodeNode*) field)) {
					ValaGLibValue* _tmp200_;
					gchar* _tmp201_;
					gchar* _tmp202_;
					ValaCCodeIdentifier* _tmp203_;
					ValaGLibValue* _tmp204_;
					ValaDataType* _tmp205_;
					ValaDataType* _tmp206_;
					_tmp200_ = _result_;
					_tmp201_ = vala_get_ccode_delegate_target_name ((ValaVariable*) field);
					_tmp202_ = _tmp201_;
					_tmp203_ = vala_ccode_identifier_new (_tmp202_);
					_vala_ccode_node_unref0 (_tmp200_->delegate_target_cvalue);
					_tmp200_->delegate_target_cvalue = (ValaCCodeExpression*) _tmp203_;
					_g_free0 (_tmp202_);
					_tmp204_ = _result_;
					_tmp205_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp204_);
					_tmp206_ = _tmp205_;
					if (vala_data_type_is_disposable (_tmp206_)) {
						ValaGLibValue* _tmp207_;
						gchar* _tmp208_;
						gchar* _tmp209_;
						ValaCCodeIdentifier* _tmp210_;
						_tmp207_ = _result_;
						_tmp208_ = vala_get_ccode_delegate_target_destroy_notify_name ((ValaVariable*) field);
						_tmp209_ = _tmp208_;
						_tmp210_ = vala_ccode_identifier_new (_tmp209_);
						_vala_ccode_node_unref0 (_tmp207_->delegate_target_destroy_notify_cvalue);
						_tmp207_->delegate_target_destroy_notify_cvalue = (ValaCCodeExpression*) _tmp210_;
						_g_free0 (_tmp209_);
					}
				}
			}
		}
	}
	result = (ValaTargetValue*) _result_;
	_vala_code_node_unref0 (array_type);
	_vala_code_node_unref0 (value_type);
	return result;
}

static gchar
string_get (const gchar* self,
            glong index)
{
	gchar _tmp0_;
	gchar result;
	g_return_val_if_fail (self != NULL, '\0');
	_tmp0_ = ((gchar*) self)[index];
	result = _tmp0_;
	return result;
}

static ValaTargetValue*
vala_ccode_member_access_module_real_load_variable (ValaCCodeBaseModule* base,
                                                    ValaVariable* variable,
                                                    ValaTargetValue* value,
                                                    ValaExpression* expr)
{
	ValaCCodeMemberAccessModule * self;
	ValaGLibValue* _result_ = NULL;
	ValaGLibValue* _tmp0_;
	ValaArrayType* array_type = NULL;
	ValaGLibValue* _tmp1_;
	ValaDataType* _tmp2_;
	ValaDataType* _tmp3_;
	ValaArrayType* _tmp4_;
	ValaDelegateType* delegate_type = NULL;
	ValaGLibValue* _tmp5_;
	ValaDataType* _tmp6_;
	ValaDataType* _tmp7_;
	ValaDelegateType* _tmp8_;
	ValaArrayType* _tmp9_;
	ValaGLibValue* _tmp89_;
	ValaDataType* _tmp90_;
	ValaDataType* _tmp91_;
	gboolean use_temp = FALSE;
	ValaGLibValue* _tmp92_;
	ValaDataType* _tmp93_;
	ValaDataType* _tmp94_;
	gboolean _tmp105_ = FALSE;
	gboolean _tmp106_;
	gboolean _tmp107_;
	ValaGLibValue* _tmp111_;
	ValaDataType* _tmp112_;
	ValaDataType* _tmp113_;
	gboolean _tmp114_ = FALSE;
	ValaLocalVariable* local = NULL;
	ValaLocalVariable* _tmp117_;
	gboolean _tmp118_ = FALSE;
	ValaLocalVariable* _tmp119_;
	ValaTargetValue* result;
	self = (ValaCCodeMemberAccessModule*) base;
	g_return_val_if_fail (variable != NULL, NULL);
	g_return_val_if_fail (value != NULL, NULL);
	_tmp0_ = _vala_target_value_ref0 (G_TYPE_CHECK_INSTANCE_CAST (value, VALA_TYPE_GLIB_VALUE, ValaGLibValue));
	_result_ = _tmp0_;
	_tmp1_ = _result_;
	_tmp2_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, VALA_TYPE_ARRAY_TYPE) ? ((ValaArrayType*) _tmp3_) : NULL);
	array_type = _tmp4_;
	_tmp5_ = _result_;
	_tmp6_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, VALA_TYPE_DELEGATE_TYPE) ? ((ValaDelegateType*) _tmp7_) : NULL);
	delegate_type = _tmp8_;
	_tmp9_ = array_type;
	if (_tmp9_ != NULL) {
		ValaArrayType* _tmp10_;
		gboolean _tmp11_;
		gboolean _tmp12_;
		ValaGLibValue* _tmp78_;
		ValaGLibValue* _tmp79_;
		ValaArrayType* _tmp80_;
		gboolean _tmp81_;
		gboolean _tmp82_;
		_tmp10_ = array_type;
		_tmp11_ = vala_array_type_get_fixed_length (_tmp10_);
		_tmp12_ = _tmp11_;
		if (_tmp12_) {
			ValaGLibValue* _tmp13_;
			ValaGLibValue* _tmp14_;
			ValaArrayType* _tmp15_;
			ValaExpression* _tmp16_;
			ValaExpression* _tmp17_;
			ValaCCodeExpression* _tmp18_;
			ValaCCodeExpression* _tmp19_;
			ValaGLibValue* _tmp20_;
			_tmp13_ = _result_;
			_vala_iterable_unref0 (_tmp13_->array_length_cvalues);
			_tmp13_->array_length_cvalues = NULL;
			_tmp14_ = _result_;
			_tmp15_ = array_type;
			_tmp16_ = vala_array_type_get_length (_tmp15_);
			_tmp17_ = _tmp16_;
			_tmp18_ = vala_ccode_base_module_get_ccodenode ((ValaCCodeBaseModule*) self, _tmp17_);
			_tmp19_ = _tmp18_;
			vala_glib_value_append_array_length_cvalue (_tmp14_, _tmp19_);
			_vala_ccode_node_unref0 (_tmp19_);
			_tmp20_ = _result_;
			_tmp20_->lvalue = FALSE;
		} else {
			if (vala_get_ccode_array_null_terminated ((ValaCodeNode*) variable)) {
				ValaCCodeFunctionCall* len_call = NULL;
				ValaCCodeIdentifier* _tmp21_;
				ValaCCodeIdentifier* _tmp22_;
				ValaCCodeFunctionCall* _tmp23_;
				ValaCCodeFunctionCall* _tmp24_;
				ValaCCodeFunctionCall* _tmp25_;
				ValaGLibValue* _tmp26_;
				ValaCCodeExpression* _tmp27_;
				ValaGLibValue* _tmp28_;
				ValaGLibValue* _tmp29_;
				ValaCCodeFunctionCall* _tmp30_;
				ValaGLibValue* _tmp31_;
				((ValaCCodeBaseModule*) self)->requires_array_length = TRUE;
				_tmp21_ = vala_ccode_identifier_new ("_vala_array_length");
				_tmp22_ = _tmp21_;
				_tmp23_ = vala_ccode_function_call_new ((ValaCCodeExpression*) _tmp22_);
				_tmp24_ = _tmp23_;
				_vala_ccode_node_unref0 (_tmp22_);
				len_call = _tmp24_;
				_tmp25_ = len_call;
				_tmp26_ = _result_;
				_tmp27_ = _tmp26_->cvalue;
				vala_ccode_function_call_add_argument (_tmp25_, _tmp27_);
				_tmp28_ = _result_;
				_vala_iterable_unref0 (_tmp28_->array_length_cvalues);
				_tmp28_->array_length_cvalues = NULL;
				_tmp29_ = _result_;
				_tmp30_ = len_call;
				vala_glib_value_append_array_length_cvalue (_tmp29_, (ValaCCodeExpression*) _tmp30_);
				_tmp31_ = _result_;
				_tmp31_->lvalue = FALSE;
				_vala_ccode_node_unref0 (len_call);
			} else {
				gchar* _tmp32_;
				gchar* _tmp33_;
				gboolean _tmp34_;
				_tmp32_ = vala_get_ccode_array_length_expr ((ValaCodeNode*) variable);
				_tmp33_ = _tmp32_;
				_tmp34_ = _tmp33_ != NULL;
				_g_free0 (_tmp33_);
				if (_tmp34_) {
					ValaCCodeConstant* length_expr = NULL;
					gchar* _tmp35_;
					gchar* _tmp36_;
					ValaCCodeConstant* _tmp37_;
					ValaCCodeConstant* _tmp38_;
					ValaGLibValue* _tmp39_;
					ValaGLibValue* _tmp40_;
					ValaCCodeConstant* _tmp41_;
					ValaGLibValue* _tmp42_;
					_tmp35_ = vala_get_ccode_array_length_expr ((ValaCodeNode*) variable);
					_tmp36_ = _tmp35_;
					_tmp37_ = vala_ccode_constant_new (_tmp36_);
					_tmp38_ = _tmp37_;
					_g_free0 (_tmp36_);
					length_expr = _tmp38_;
					_tmp39_ = _result_;
					_vala_iterable_unref0 (_tmp39_->array_length_cvalues);
					_tmp39_->array_length_cvalues = NULL;
					_tmp40_ = _result_;
					_tmp41_ = length_expr;
					vala_glib_value_append_array_length_cvalue (_tmp40_, (ValaCCodeExpression*) _tmp41_);
					_tmp42_ = _result_;
					_tmp42_->lvalue = FALSE;
					_vala_ccode_node_unref0 (length_expr);
				} else {
					if (!vala_get_ccode_array_length ((ValaCodeNode*) variable)) {
						ValaGLibValue* _tmp43_;
						ValaGLibValue* _tmp52_;
						_tmp43_ = _result_;
						_vala_iterable_unref0 (_tmp43_->array_length_cvalues);
						_tmp43_->array_length_cvalues = NULL;
						{
							gint dim = 0;
							dim = 1;
							{
								gboolean _tmp44_ = FALSE;
								_tmp44_ = TRUE;
								while (TRUE) {
									ValaArrayType* _tmp46_;
									gint _tmp47_;
									gint _tmp48_;
									ValaGLibValue* _tmp49_;
									ValaCCodeConstant* _tmp50_;
									ValaCCodeConstant* _tmp51_;
									if (!_tmp44_) {
										gint _tmp45_;
										_tmp45_ = dim;
										dim = _tmp45_ + 1;
									}
									_tmp44_ = FALSE;
									_tmp46_ = array_type;
									_tmp47_ = vala_array_type_get_rank (_tmp46_);
									_tmp48_ = _tmp47_;
									if (!(dim <= _tmp48_)) {
										break;
									}
									_tmp49_ = _result_;
									_tmp50_ = vala_ccode_constant_new ("-1");
									_tmp51_ = _tmp50_;
									vala_glib_value_append_array_length_cvalue (_tmp49_, (ValaCCodeExpression*) _tmp51_);
									_vala_ccode_node_unref0 (_tmp51_);
								}
							}
						}
						_tmp52_ = _result_;
						_tmp52_->lvalue = FALSE;
					} else {
						ValaDataType* _tmp53_;
						ValaDataType* _tmp54_;
						gchar* _tmp55_;
						gchar* _tmp56_;
						ValaArrayType* _tmp57_;
						gchar* _tmp58_;
						gchar* _tmp59_;
						gboolean _tmp60_;
						_tmp53_ = vala_variable_get_variable_type (variable);
						_tmp54_ = _tmp53_;
						_tmp55_ = vala_get_ccode_array_length_type ((ValaCodeNode*) _tmp54_);
						_tmp56_ = _tmp55_;
						_tmp57_ = array_type;
						_tmp58_ = vala_get_ccode_array_length_type ((ValaCodeNode*) _tmp57_);
						_tmp59_ = _tmp58_;
						_tmp60_ = g_strcmp0 (_tmp56_, _tmp59_) != 0;
						_g_free0 (_tmp59_);
						_g_free0 (_tmp56_);
						if (_tmp60_) {
							ValaGLibValue* _tmp77_;
							{
								gint dim = 0;
								dim = 1;
								{
									gboolean _tmp61_ = FALSE;
									_tmp61_ = TRUE;
									while (TRUE) {
										ValaArrayType* _tmp63_;
										gint _tmp64_;
										gint _tmp65_;
										ValaGLibValue* _tmp66_;
										ValaList* _tmp67_;
										ValaGLibValue* _tmp68_;
										ValaList* _tmp69_;
										gpointer _tmp70_;
										ValaCCodeExpression* _tmp71_;
										ValaArrayType* _tmp72_;
										gchar* _tmp73_;
										gchar* _tmp74_;
										ValaCCodeCastExpression* _tmp75_;
										ValaCCodeCastExpression* _tmp76_;
										if (!_tmp61_) {
											gint _tmp62_;
											_tmp62_ = dim;
											dim = _tmp62_ + 1;
										}
										_tmp61_ = FALSE;
										_tmp63_ = array_type;
										_tmp64_ = vala_array_type_get_rank (_tmp63_);
										_tmp65_ = _tmp64_;
										if (!(dim <= _tmp65_)) {
											break;
										}
										_tmp66_ = _result_;
										_tmp67_ = _tmp66_->array_length_cvalues;
										_tmp68_ = _result_;
										_tmp69_ = _tmp68_->array_length_cvalues;
										_tmp70_ = vala_list_get (_tmp69_, dim - 1);
										_tmp71_ = (ValaCCodeExpression*) _tmp70_;
										_tmp72_ = array_type;
										_tmp73_ = vala_get_ccode_array_length_type ((ValaCodeNode*) _tmp72_);
										_tmp74_ = _tmp73_;
										_tmp75_ = vala_ccode_cast_expression_new (_tmp71_, _tmp74_);
										_tmp76_ = _tmp75_;
										vala_list_set (_tmp67_, dim - 1, (ValaCCodeExpression*) _tmp76_);
										_vala_ccode_node_unref0 (_tmp76_);
										_g_free0 (_tmp74_);
										_vala_ccode_node_unref0 (_tmp71_);
									}
								}
							}
							_tmp77_ = _result_;
							_tmp77_->lvalue = FALSE;
						}
					}
				}
			}
		}
		_tmp78_ = _result_;
		_vala_ccode_node_unref0 (_tmp78_->array_size_cvalue);
		_tmp78_->array_size_cvalue = NULL;
		_tmp79_ = _result_;
		_tmp80_ = array_type;
		_tmp81_ = vala_array_type_get_inline_allocated (_tmp80_);
		_tmp82_ = _tmp81_;
		_tmp79_->non_null = _tmp82_;
	} else {
		ValaDelegateType* _tmp83_;
		_tmp83_ = delegate_type;
		if (_tmp83_ != NULL) {
			ValaGLibValue* _tmp88_;
			if (!vala_get_ccode_delegate_target ((ValaCodeNode*) variable)) {
				ValaGLibValue* _tmp84_;
				ValaCCodeConstant* _tmp85_;
				ValaGLibValue* _tmp86_;
				ValaCCodeConstant* _tmp87_;
				_tmp84_ = _result_;
				_tmp85_ = vala_ccode_constant_new ("NULL");
				_vala_ccode_node_unref0 (_tmp84_->delegate_target_cvalue);
				_tmp84_->delegate_target_cvalue = (ValaCCodeExpression*) _tmp85_;
				_tmp86_ = _result_;
				_tmp87_ = vala_ccode_constant_new ("NULL");
				_vala_ccode_node_unref0 (_tmp86_->delegate_target_destroy_notify_cvalue);
				_tmp86_->delegate_target_destroy_notify_cvalue = (ValaCCodeExpression*) _tmp87_;
			}
			_tmp88_ = _result_;
			_tmp88_->lvalue = FALSE;
		}
	}
	_tmp89_ = _result_;
	_tmp90_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp89_);
	_tmp91_ = _tmp90_;
	vala_data_type_set_value_owned (_tmp91_, FALSE);
	use_temp = TRUE;
	_tmp92_ = _result_;
	_tmp93_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp92_);
	_tmp94_ = _tmp93_;
	if (!vala_ccode_base_module_is_lvalue_access_allowed ((ValaCCodeBaseModule*) self, _tmp94_)) {
		use_temp = FALSE;
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (variable, VALA_TYPE_PARAMETER)) {
		ValaParameter* param = NULL;
		ValaParameter* _tmp95_;
		const gchar* _tmp96_;
		const gchar* _tmp97_;
		_tmp95_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_CAST (variable, VALA_TYPE_PARAMETER, ValaParameter));
		param = _tmp95_;
		_tmp96_ = vala_symbol_get_name ((ValaSymbol*) variable);
		_tmp97_ = _tmp96_;
		if (g_strcmp0 (_tmp97_, "this") == 0) {
			use_temp = FALSE;
		} else {
			gboolean _tmp98_ = FALSE;
			ValaParameter* _tmp99_;
			ValaParameterDirection _tmp100_;
			ValaParameterDirection _tmp101_;
			_tmp99_ = param;
			_tmp100_ = vala_parameter_get_direction (_tmp99_);
			_tmp101_ = _tmp100_;
			if (_tmp101_ != VALA_PARAMETER_DIRECTION_OUT) {
				ValaParameter* _tmp102_;
				ValaDataType* _tmp103_;
				ValaDataType* _tmp104_;
				_tmp102_ = param;
				_tmp103_ = vala_variable_get_variable_type ((ValaVariable*) _tmp102_);
				_tmp104_ = _tmp103_;
				_tmp98_ = !vala_data_type_is_real_non_null_struct_type (_tmp104_);
			} else {
				_tmp98_ = FALSE;
			}
			if (_tmp98_) {
				use_temp = FALSE;
			}
		}
		_vala_code_node_unref0 (param);
	}
	_tmp106_ = vala_variable_get_single_assignment (variable);
	_tmp107_ = _tmp106_;
	if (_tmp107_) {
		ValaGLibValue* _tmp108_;
		ValaDataType* _tmp109_;
		ValaDataType* _tmp110_;
		_tmp108_ = _result_;
		_tmp109_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp108_);
		_tmp110_ = _tmp109_;
		_tmp105_ = !vala_data_type_is_real_non_null_struct_type (_tmp110_);
	} else {
		_tmp105_ = FALSE;
	}
	if (_tmp105_) {
		use_temp = FALSE;
	}
	_tmp111_ = _result_;
	_tmp112_ = vala_target_value_get_value_type ((ValaTargetValue*) _tmp111_);
	_tmp113_ = _tmp112_;
	if (vala_data_type_is_non_null_simple_type (_tmp113_)) {
		use_temp = FALSE;
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (expr, VALA_TYPE_MEMBER_ACCESS)) {
		gboolean _tmp115_;
		gboolean _tmp116_;
		_tmp115_ = vala_member_access_get_tainted_access (G_TYPE_CHECK_INSTANCE_CAST (expr, VALA_TYPE_MEMBER_ACCESS, ValaMemberAccess));
		_tmp116_ = _tmp115_;
		_tmp114_ = _tmp116_;
	} else {
		_tmp114_ = FALSE;
	}
	if (_tmp114_) {
		use_temp = TRUE;
	}
	_tmp117_ = _vala_code_node_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (variable, VALA_TYPE_LOCAL_VARIABLE) ? ((ValaLocalVariable*) variable) : NULL);
	local = _tmp117_;
	_tmp119_ = local;
	if (_tmp119_ != NULL) {
		ValaLocalVariable* _tmp120_;
		const gchar* _tmp121_;
		const gchar* _tmp122_;
		_tmp120_ = local;
		_tmp121_ = vala_symbol_get_name ((ValaSymbol*) _tmp120_);
		_tmp122_ = _tmp121_;
		_tmp118_ = string_get (_tmp122_, (glong) 0) == '.';
	} else {
		_tmp118_ = FALSE;
	}
	if (_tmp118_) {
		use_temp = FALSE;
	}
	if (use_temp) {
		ValaGLibValue* _tmp123_;
		ValaTargetValue* _tmp124_;
		_tmp123_ = _result_;
		_tmp124_ = vala_ccode_base_module_store_temp_value ((ValaCCodeBaseModule*) self, (ValaTargetValue*) _tmp123_, (ValaCodeNode*) variable, NULL);
		_vala_target_value_unref0 (_result_);
		_result_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp124_, VALA_TYPE_GLIB_VALUE, ValaGLibValue);
	}
	result = (ValaTargetValue*) _result_;
	_vala_code_node_unref0 (local);
	_vala_code_node_unref0 (delegate_type);
	_vala_code_node_unref0 (array_type);
	return result;
}

static ValaTargetValue*
vala_ccode_member_access_module_real_load_local (ValaCodeGenerator* base,
                                                 ValaLocalVariable* local,
                                                 ValaExpression* expr)
{
	ValaCCodeMemberAccessModule * self;
	ValaTargetValue* _tmp0_;
	ValaTargetValue* _tmp1_;
	ValaTargetValue* _tmp2_;
	ValaTargetValue* _tmp3_;
	ValaTargetValue* result;
	self = (ValaCCodeMemberAccessModule*) base;
	g_return_val_if_fail (local != NULL, NULL);
	_tmp0_ = vala_ccode_base_module_get_local_cvalue ((ValaCCodeBaseModule*) self, local);
	_tmp1_ = _tmp0_;
	_tmp2_ = vala_ccode_base_module_load_variable ((ValaCCodeBaseModule*) self, (ValaVariable*) local, _tmp1_, expr);
	_tmp3_ = _tmp2_;
	_vala_target_value_unref0 (_tmp1_);
	result = _tmp3_;
	return result;
}

static ValaTargetValue*
vala_ccode_member_access_module_real_load_parameter (ValaCodeGenerator* base,
                                                     ValaParameter* param,
                                                     ValaExpression* expr)
{
	ValaCCodeMemberAccessModule * self;
	ValaTargetValue* _tmp0_;
	ValaTargetValue* _tmp1_;
	ValaTargetValue* _tmp2_;
	ValaTargetValue* _tmp3_;
	ValaTargetValue* result;
	self = (ValaCCodeMemberAccessModule*) base;
	g_return_val_if_fail (param != NULL, NULL);
	_tmp0_ = vala_ccode_base_module_get_parameter_cvalue ((ValaCCodeBaseModule*) self, param);
	_tmp1_ = _tmp0_;
	_tmp2_ = vala_ccode_base_module_load_variable ((ValaCCodeBaseModule*) self, (ValaVariable*) param, _tmp1_, expr);
	_tmp3_ = _tmp2_;
	_vala_target_value_unref0 (_tmp1_);
	result = _tmp3_;
	return result;
}

static ValaTargetValue*
vala_ccode_member_access_module_real_load_this_parameter (ValaCCodeBaseModule* base,
                                                          ValaTypeSymbol* sym)
{
	ValaCCodeMemberAccessModule * self;
	ValaParameter* param = NULL;
	ValaDataType* _tmp0_;
	ValaDataType* _tmp1_;
	ValaParameter* _tmp2_;
	ValaParameter* _tmp3_;
	ValaTargetValue* _tmp4_;
	ValaTargetValue* result;
	self = (ValaCCodeMemberAccessModule*) base;
	g_return_val_if_fail (sym != NULL, NULL);
	_tmp0_ = vala_semantic_analyzer_get_data_type_for_symbol ((ValaSymbol*) sym);
	_tmp1_ = _tmp0_;
	_tmp2_ = vala_parameter_new ("this", _tmp1_, NULL);
	_tmp3_ = _tmp2_;
	_vala_code_node_unref0 (_tmp1_);
	param = _tmp3_;
	_tmp4_ = vala_code_generator_load_parameter ((ValaCodeGenerator*) self, param, NULL);
	result = _tmp4_;
	_vala_code_node_unref0 (param);
	return result;
}

static ValaTargetValue*
vala_ccode_member_access_module_real_load_field (ValaCodeGenerator* base,
                                                 ValaField* field,
                                                 ValaTargetValue* instance,
                                                 ValaExpression* expr)
{
	ValaCCodeMemberAccessModule * self;
	ValaTargetValue* _tmp0_;
	ValaTargetValue* _tmp1_;
	ValaTargetValue* _tmp2_;
	ValaTargetValue* _tmp3_;
	ValaTargetValue* result;
	self = (ValaCCodeMemberAccessModule*) base;
	g_return_val_if_fail (field != NULL, NULL);
	_tmp0_ = vala_ccode_base_module_get_field_cvalue ((ValaCCodeBaseModule*) self, field, instance);
	_tmp1_ = _tmp0_;
	_tmp2_ = vala_ccode_base_module_load_variable ((ValaCCodeBaseModule*) self, (ValaVariable*) field, _tmp1_, expr);
	_tmp3_ = _tmp2_;
	_vala_target_value_unref0 (_tmp1_);
	result = _tmp3_;
	return result;
}

ValaCCodeMemberAccessModule*
vala_ccode_member_access_module_construct (GType object_type)
{
	ValaCCodeMemberAccessModule* self = NULL;
	self = (ValaCCodeMemberAccessModule*) vala_ccode_control_flow_module_construct (object_type);
	return self;
}

static void
vala_ccode_member_access_module_class_init (ValaCCodeMemberAccessModuleClass * klass,
                                            gpointer klass_data)
{
	vala_ccode_member_access_module_parent_class = g_type_class_peek_parent (klass);
	((ValaCodeVisitorClass *) klass)->visit_member_access = (void (*) (ValaCodeVisitor*, ValaMemberAccess*)) vala_ccode_member_access_module_real_visit_member_access;
	((ValaCCodeBaseModuleClass *) klass)->get_local_cvalue = (ValaTargetValue* (*) (ValaCCodeBaseModule*, ValaLocalVariable*)) vala_ccode_member_access_module_real_get_local_cvalue;
	((ValaCCodeBaseModuleClass *) klass)->get_parameter_cvalue = (ValaTargetValue* (*) (ValaCCodeBaseModule*, ValaParameter*)) vala_ccode_member_access_module_real_get_parameter_cvalue;
	((ValaCCodeBaseModuleClass *) klass)->get_field_cvalue = (ValaTargetValue* (*) (ValaCCodeBaseModule*, ValaField*, ValaTargetValue*)) vala_ccode_member_access_module_real_get_field_cvalue;
	((ValaCCodeBaseModuleClass *) klass)->load_variable = (ValaTargetValue* (*) (ValaCCodeBaseModule*, ValaVariable*, ValaTargetValue*, ValaExpression*)) vala_ccode_member_access_module_real_load_variable;
	((ValaCodeGeneratorClass *) klass)->load_local = (ValaTargetValue* (*) (ValaCodeGenerator*, ValaLocalVariable*, ValaExpression*)) vala_ccode_member_access_module_real_load_local;
	((ValaCodeGeneratorClass *) klass)->load_parameter = (ValaTargetValue* (*) (ValaCodeGenerator*, ValaParameter*, ValaExpression*)) vala_ccode_member_access_module_real_load_parameter;
	((ValaCCodeBaseModuleClass *) klass)->load_this_parameter = (ValaTargetValue* (*) (ValaCCodeBaseModule*, ValaTypeSymbol*)) vala_ccode_member_access_module_real_load_this_parameter;
	((ValaCodeGeneratorClass *) klass)->load_field = (ValaTargetValue* (*) (ValaCodeGenerator*, ValaField*, ValaTargetValue*, ValaExpression*)) vala_ccode_member_access_module_real_load_field;
}

static void
vala_ccode_member_access_module_instance_init (ValaCCodeMemberAccessModule * self,
                                               gpointer klass)
{
}

static GType
vala_ccode_member_access_module_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeMemberAccessModuleClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_member_access_module_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeMemberAccessModule), 0, (GInstanceInitFunc) vala_ccode_member_access_module_instance_init, NULL };
	GType vala_ccode_member_access_module_type_id;
	vala_ccode_member_access_module_type_id = g_type_register_static (VALA_TYPE_CCODE_CONTROL_FLOW_MODULE, "ValaCCodeMemberAccessModule", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
	return vala_ccode_member_access_module_type_id;
}

GType
vala_ccode_member_access_module_get_type (void)
{
	static volatile gsize vala_ccode_member_access_module_type_id__once = 0;
	if (g_once_init_enter (&vala_ccode_member_access_module_type_id__once)) {
		GType vala_ccode_member_access_module_type_id;
		vala_ccode_member_access_module_type_id = vala_ccode_member_access_module_get_type_once ();
		g_once_init_leave (&vala_ccode_member_access_module_type_id__once, vala_ccode_member_access_module_type_id);
	}
	return vala_ccode_member_access_module_type_id__once;
}

